@@ -50,26 +50,26 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
 
-#include <sys/types.h>
-#include <sys/stat.h>
 #include <errno.h>
+#include <libgen.h>
 #include <limits.h>
 #include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 #include <unistd.h>
-#include <libgen.h>
 
-#include <atalk/ftw.h>
 #include <atalk/adouble.h>
-#include <atalk/vfs.h>
-#include <atalk/util.h>
-#include <atalk/unix.h>
-#include <atalk/volume.h>
-#include <atalk/bstrlib.h>
 #include <atalk/bstradd.h>
+#include <atalk/bstrlib.h>
+#include <atalk/ftw.h>
 #include <atalk/queue.h>
+#include <atalk/unix.h>
+#include <atalk/util.h>
+#include <atalk/vfs.h>
+#include <atalk/volume.h>
 
 #include "ad.h"
 
@@ -114,7 +114,7 @@ static void upfunc(void)
   catch SIGINT and SIGTERM which cause clean exit. Ignore anything else.
 */
 
-static void sig_handler(int signo)
+static void sig_handler(int signo _U_)
 {
     alarmed = 1;
     return;
@@ -350,7 +350,7 @@ int ad_cp(int argc, char *argv[], AFPObj *obj)
 
 static int copy(const char *path,
                 const struct stat *statp,
-                int tflag,
+                int tflag _U_,
                 struct FTW *ftw)
 {
     static int base = 0;
@@ -619,10 +619,12 @@ static int copy(const char *path,
 #define BUFSIZE_MAX (2*1024*1024)
 
 /* Small (default) buffer size in bytes. It's inefficient for this to be smaller than MAXPHYS */
-#define MAXPHYS (64 * 1024)
+#if ! defined __APPLE__ && ! defined __FreeBSD__
+    #define MAXPHYS (64 * 1024)
+#endif
 #define BUFSIZE_SMALL (MAXPHYS)
 
-static int ftw_copy_file(const struct FTW *entp,
+static int ftw_copy_file(const struct FTW *entp _U_,
                          const char *spath,
                          const struct stat *sp,
                          int dne)
@@ -638,7 +640,7 @@ static int ftw_copy_file(const struct FTW *entp,
 
     if ((from_fd = open(spath, O_RDONLY, 0)) == -1) {
         SLOG("%s: %s", spath, strerror(errno));
-        return (1);
+        return 1;
     }
 
     /*
@@ -655,7 +657,7 @@ static int ftw_copy_file(const struct FTW *entp,
             if (vflag)
                 printf("%s not overwritten\n", to.p_path);
             (void)close(from_fd);
-            return (0);
+            return 0;
         } else if (iflag) {
             (void)fprintf(stderr, "overwrite %s? %s",
                           to.p_path, YESNO);
@@ -665,7 +667,7 @@ static int ftw_copy_file(const struct FTW *entp,
             if (checkch != 'y' && checkch != 'Y') {
                 (void)close(from_fd);
                 (void)fprintf(stderr, "not overwritten\n");
-                return (1);
+                return 1;
             }
         }
 
@@ -688,7 +690,7 @@ static int ftw_copy_file(const struct FTW *entp,
     if (to_fd == -1) {
         SLOG("%s: %s", to.p_path, strerror(errno));
         (void)close(from_fd);
-        return (1);
+        return 1;
     }
 
     rval = 0;
@@ -782,10 +784,10 @@ static int ftw_copy_file(const struct FTW *entp,
 
     (void)close(from_fd);
 
-    return (rval);
+    return rval;
 }
 
-static int ftw_copy_link(const struct FTW *p,
+static int ftw_copy_link(const struct FTW *p _U_,
                          const char *spath,
                          const struct stat *sstp,
                          int exists)
@@ -795,16 +797,20 @@ static int ftw_copy_link(const struct FTW *p,
 
     if ((len = readlink(spath, llink, sizeof(llink) - 1)) == -1) {
         SLOG("readlink: %s: %s", spath, strerror(errno));
-        return (1);
+        return 1;
+    }
+    if (len < 0 || len >= sizeof(llink)) {
+        SLOG("readlink: %s: invalid link length", spath);
+        return 1;
     }
     llink[len] = '\0';
     if (exists && unlink(to.p_path)) {
         SLOG("unlink: %s: %s", to.p_path, strerror(errno));
-        return (1);
+        return 1;
     }
     if (symlink(llink, to.p_path)) {
         SLOG("symlink: %s: %s", llink, strerror(errno));
-        return (1);
+        return 1;
     }
     return (pflag ? setfile(sstp, -1) : 0);
 }
@@ -875,10 +881,10 @@ static int setfile(const struct stat *fs, int fd)
         }
 #endif
 
-    return (rval);
+    return rval;
 }
 
-static int preserve_fd_acls(int source_fd, int dest_fd)
+static int preserve_fd_acls(int source_fd _U_, int dest_fd _U_)
 {
 #if 0
     acl_t acl;
@@ -891,7 +897,7 @@ static int preserve_fd_acls(int source_fd, int dest_fd)
         acl_type = ACL_TYPE_NFS4;
     } else if (ret < 0 && errno != EINVAL) {
         warn("fpathconf(..., _PC_ACL_NFS4) failed for %s", to.p_path);
-        return (1);
+        return 1;
     }
     if (acl_supported == 0) {
         ret = fpathconf(source_fd, _PC_ACL_EXTENDED);
@@ -901,34 +907,34 @@ static int preserve_fd_acls(int source_fd, int dest_fd)
         } else if (ret < 0 && errno != EINVAL) {
             warn("fpathconf(..., _PC_ACL_EXTENDED) failed for %s",
                  to.p_path);
-            return (1);
+            return 1;
         }
     }
     if (acl_supported == 0)
-        return (0);
+        return 0;
 
     acl = acl_get_fd_np(source_fd, acl_type);
     if (acl == NULL) {
         warn("failed to get acl entries while setting %s", to.p_path);
-        return (1);
+        return 1;
     }
     if (acl_is_trivial_np(acl, &trivial)) {
         warn("acl_is_trivial() failed for %s", to.p_path);
         acl_free(acl);
-        return (1);
+        return 1;
     }
     if (trivial) {
         acl_free(acl);
-        return (0);
+        return 0;
     }
     if (acl_set_fd_np(dest_fd, acl, acl_type) < 0) {
         warn("failed to set acl entries for %s", to.p_path);
         acl_free(acl);
-        return (1);
+        return 1;
     }
     acl_free(acl);
 #endif
-    return (0);
+    return 0;
 }
 
 #if 0
@@ -947,7 +953,7 @@ static int preserve_dir_acls(const struct stat *fs, char *source_dir, char *dest
         acl_type = ACL_TYPE_NFS4;
     } else if (ret < 0 && errno != EINVAL) {
         warn("fpathconf(..., _PC_ACL_NFS4) failed for %s", source_dir);
-        return (1);
+        return 1;
     }
     if (acl_supported == 0) {
         ret = pathconf(source_dir, _PC_ACL_EXTENDED);
@@ -957,11 +963,11 @@ static int preserve_dir_acls(const struct stat *fs, char *source_dir, char *dest
         } else if (ret < 0 && errno != EINVAL) {
             warn("fpathconf(..., _PC_ACL_EXTENDED) failed for %s",
                  source_dir);
-            return (1);
+            return 1;
         }
     }
     if (acl_supported == 0)
-        return (0);
+        return 0;
 
     /*
      * If the file is a link we will not follow it
@@ -983,7 +989,7 @@ static int preserve_dir_acls(const struct stat *fs, char *source_dir, char *dest
         if (acl == NULL) {
             warn("failed to get default acl entries on %s",
                  source_dir);
-            return (1);
+            return 1;
         }
         aclp = &acl->ats_acl;
         if (aclp->acl_cnt != 0 && aclsetf(dest_dir,
@@ -991,30 +997,30 @@ static int preserve_dir_acls(const struct stat *fs, char *source_dir, char *dest
             warn("failed to set default acl entries on %s",
                  dest_dir);
             acl_free(acl);
-            return (1);
+            return 1;
         }
         acl_free(acl);
     }
     acl = aclgetf(source_dir, acl_type);
     if (acl == NULL) {
         warn("failed to get acl entries on %s", source_dir);
-        return (1);
+        return 1;
     }
     if (acl_is_trivial_np(acl, &trivial)) {
         warn("acl_is_trivial() failed on %s", source_dir);
         acl_free(acl);
-        return (1);
+        return 1;
     }
     if (trivial) {
         acl_free(acl);
-        return (0);
+        return 0;
     }
     if (aclsetf(dest_dir, acl_type, acl) < 0) {
         warn("failed to set acl entries on %s", dest_dir);
         acl_free(acl);
-        return (1);
+        return 1;
     }
     acl_free(acl);
-    return (0);
+    return 0;
 }
 #endif
