@@ -16,19 +16,15 @@
 #include <stdlib.h>
 #include <string.h>
 #include <signal.h>
-#include <atalk/logger.h>
 #include <errno.h>
-#ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
-#endif /* HAVE_SYS_TIME_H */
-#ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
-#endif /* HAVE_SYS_STAT_H */
 
 #include <netatalk/endian.h>
 #include <atalk/atp.h>
 #include <atalk/asp.h>
 #include <atalk/compat.h>
+#include <atalk/logger.h>
 #include <atalk/util.h>
 #include <atalk/globals.h>
 #include <atalk/netatalk_conf.h>
