@@ -32,6 +32,7 @@
 #include <atalk/fce_api.h>
 #include <atalk/globals.h>
 #include <atalk/nbp.h>
+#include <atalk/zip.h>
 
 #ifdef HAVE_LDAP
 #include <atalk/ldapconfig.h>
@@ -132,8 +133,9 @@ int configinit(AFPObj *dsi_obj, AFPObj *asp_obj)
     {
         ATP atp;
         ASP asp;
-        char* Obj, * Type = "AFPServer", * Zone = "*";
-        char* convname = NULL;
+        char* Obj = NULL;
+        char* Type = "AFPServer";
+        char* Zone = strdup("*");
 
         if ((atp = atp_open(ATADDR_ANYPORT, &asp_obj->options.ddpaddr)) == NULL) {
             LOG(log_error, logtype_afpd, "main: atp_open: %s", strerror(errno));
@@ -147,25 +149,32 @@ int configinit(AFPObj *dsi_obj, AFPObj *asp_obj)
         }
 
         /* register asp server */
-        Obj = (char*)asp_obj->options.hostname;
-
-        if (asp_obj->options.zone && (size_t)-1 == (convert_string_allocate(asp_obj->options.unixcharset, asp_obj->options.maccharset,
-            asp_obj->options.zone, strlen(asp_obj->options.zone), &convname))) {
-            if ((convname = strdup(asp_obj->options.zone)) == NULL) {
-                LOG(log_error, logtype_afpd, "malloc: %s", strerror(errno));
-                asp_close(asp);
-                goto serv_free_return;
-            }
-        }
+        Obj = asp_obj->options.servername ? asp_obj->options.servername : asp_obj->options.hostname;
+        char tmpnam[32];
+        convert_string(asp_obj->options.unixcharset,
+                        asp_obj->options.maccharset,
+                        Obj, strnlen(Obj, PATH_MAX),
+                        tmpnam, sizeof(tmpnam)-1);
+        tmpnam[31] = '\0';
+        Obj = tmpnam;
 
         /* set a custom zone if user requested one */
         if (asp_obj->options.zone) {
-            Zone = strdup(convname);
+            size_t zone_len = strnlen(asp_obj->options.zone, MAX_ZONE_LENGTH);
+            if ((size_t)-1 == (convert_string_allocate(asp_obj->options.unixcharset, 
+                asp_obj->options.maccharset,
+                asp_obj->options.zone,
+                zone_len,
+                &Zone))) {
+                if ((Zone = strdup(asp_obj->options.zone)) == NULL) {
+                    LOG(log_error, logtype_afpd, "malloc: %s", strerror(errno));
+                    asp_close(asp);
+                    goto serv_free_return;
+                }
+                LOG(log_debug, logtype_afpd, "Using AppleTalk zone: %s", Zone);
+            }
         }
 
-        if (convname)
-            free(convname);
-
         /* dup Obj, Type and Zone as they get assigned to a single internal
          * buffer by nbp_name */
         if ((asp_obj->Obj = strdup(Obj)) == NULL) {
@@ -215,6 +224,8 @@ int configinit(AFPObj *dsi_obj, AFPObj *asp_obj)
             LOG(log_note, logtype_afpd, "AppleTalk support disabled. Is atalkd running?");
         }
 
+        free((void *)Zone);
+
     }
 #endif /* no afp/asp */
 
@@ -326,35 +337,34 @@ int configinit(AFPObj *dsi_obj, AFPObj *asp_obj)
     acl_ldap_readconfig(dsi_obj->iniconfig);
 #endif /* HAVE_LDAP */
 
-    if ((r = atalk_iniparser_getstring(dsi_obj->iniconfig, INISEC_GLOBAL, "fce listener", NULL))) {
+    if ((r = INIPARSER_GETSTR(dsi_obj->iniconfig, INISEC_GLOBAL, "fce listener", NULL))) {
 		LOG(log_note, logtype_afpd, "Adding FCE listener: %s", r);
 		fce_add_udp_socket(r);
     }
-    if ((r = atalk_iniparser_getstring(dsi_obj->iniconfig, INISEC_GLOBAL, "fce coalesce", NULL))) {
+    if ((r = INIPARSER_GETSTR(dsi_obj->iniconfig, INISEC_GLOBAL, "fce coalesce", NULL))) {
 		LOG(log_note, logtype_afpd, "Fce coalesce: %s", r);
 		fce_set_coalesce(r);
     }
-    if ((r = atalk_iniparser_getstring(dsi_obj->iniconfig, INISEC_GLOBAL, "fce events", NULL))) {
+    if ((r = INIPARSER_GETSTR(dsi_obj->iniconfig, INISEC_GLOBAL, "fce events", NULL))) {
 		LOG(log_note, logtype_afpd, "Fce events: %s", r);
 		fce_set_events(r);
     }
-    r = atalk_iniparser_getstring(dsi_obj->iniconfig, INISEC_GLOBAL, "fce version", "1");
+    r = INIPARSER_GETSTR(dsi_obj->iniconfig, INISEC_GLOBAL, "fce version", "1");
     LOG(log_debug, logtype_afpd, "Fce version: %s", r);
     dsi_obj->fce_version = atoi(r);
 
-    if ((r = atalk_iniparser_getstring(dsi_obj->iniconfig, INISEC_GLOBAL, "fce ignore names", ".DS_Store"))) {
+    if ((r = INIPARSER_GETSTR(dsi_obj->iniconfig, INISEC_GLOBAL, "fce ignore names", ".DS_Store"))) {
         dsi_obj->fce_ign_names = strdup(r);
     }
-    if ((r = atalk_iniparser_getstring(dsi_obj->iniconfig, INISEC_GLOBAL, "fce ignore directories", NULL))) {
+    if ((r = INIPARSER_GETSTR(dsi_obj->iniconfig, INISEC_GLOBAL, "fce ignore directories", NULL))) {
             dsi_obj->fce_ign_directories = strdup(r);
     }
 
-    if ((r = atalk_iniparser_getstring(dsi_obj->iniconfig, INISEC_GLOBAL, "fce notify script", NULL))) {
+    if ((r = INIPARSER_GETSTR(dsi_obj->iniconfig, INISEC_GLOBAL, "fce notify script", NULL))) {
         dsi_obj->fce_notify_script = strdup(r);
     }
 
 
-
 EC_CLEANUP:
     if (q)
         free(q);
