@@ -21,10 +21,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <sys/socket.h>
-
-#ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
-#endif /* HAVE_SYS_STAT_H */
 
 #include <sys/time.h>
 #include <sys/types.h>
@@ -282,7 +279,7 @@ static void alarm_handler(int sig _U_)
     setitimer(ITIMER_REAL, &dsi->timer, NULL);
 
     /* we got some traffic from the client since the previous timer tick. */
-    if ((dsi->flags & DSI_DATA)) {
+    if (dsi->flags & DSI_DATA) {
         dsi->flags &= ~DSI_DATA;
         return;
     }
@@ -569,9 +566,9 @@ void afp_over_dsi(AFPObj *obj)
                     setuplog("default:note", NULL, true);
                 debugging = 0;
             } else {
-                char logstr[50];
+                char logstr[MAXPATHLEN + 1];
                 debugging = 1;
-                sprintf(logstr, "/tmp/afpd.%u.XXXXXX", getpid());
+                snprintf(logstr, sizeof(logstr)-1, "%s/afpd.%u.XXXXXX", tmpdir(), getpid());
                 setuplog("default:maxdebug", logstr, true);
             }
         }
@@ -592,7 +589,7 @@ void afp_over_dsi(AFPObj *obj)
             dsi->flags &= ~DSI_DATA; /* thats no data in the sense we use it in alarm_handler */
             LOG(log_debug, logtype_afpd, "DSI: client tickle");
             /* timer is not every 30 seconds anymore, so we don't get killed on the client side. */
-            if ((dsi->flags & DSI_DIE))
+            if (dsi->flags & DSI_DIE)
                 dsi_tickle(dsi);
             break;
 
