@@ -16,9 +16,11 @@ struct afp_versions {
 };
 
 static const struct afp_versions  afp_versions[] = {
+#ifndef NO_DDP
     { "AFPVersion 1.1", 11 },
     { "AFPVersion 2.0", 20 },
     { "AFPVersion 2.1", 21 },
+#endif /* ! NO_DDP */
     { "AFP2.2", 22 },
     { "AFPX03", 30 },
     { "AFP3.1", 31 },
