@@ -52,20 +52,25 @@ struct savedir {
 static int enumerate_loop(struct dirent *de, char *mname _U_, void *data)
 {
     struct savedir *sd = data;
-    char *start, *end;
-    int  len,lenm;
+    char *start;
+    const char *end;
+    int len;
+    int bytes_needed;
 
     end = sd->sd_buf + sd->sd_buflen;
-    len = strlen(de->d_name);
+    len = (int) strnlen(de->d_name, UTF8FILELEN_EARLY);
+    bytes_needed = 1 + len + 1;
     *(sd->sd_last)++ = len;
-    lenm = 0; /* strlen(mname);*/
-    if ( sd->sd_last + len +lenm + 4 > end ) {
+
+    if (sd->sd_last + bytes_needed > end) {
+        start = sd->sd_buf;
         char *buf;
 
-        start = sd->sd_buf;
         if (!(buf = realloc( sd->sd_buf, sd->sd_buflen +SDBUFBRK )) ) {
             LOG(log_error, logtype_afpd, "afp_enumerate: realloc: %s",
                         strerror(errno) );
+            /* Restore position to avoid invalid data */
+            sd->sd_last--;
             errno = ENOMEM;
             return -1;
         }
@@ -188,7 +193,7 @@ static int enumerate(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_,
 
     if (NULL == ( vol = getvolbyvid( vid )) ) {
         *rbuflen = 0;
-        return( AFPERR_PARAM );
+        return AFPERR_PARAM;
     }
 
     memcpy( &did, ibuf, sizeof( did ));
@@ -247,7 +252,7 @@ static int enumerate(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_,
         ibuf += sizeof( temp16 );
     }
 
-    header = (ext)?4:2;
+    header = ext?4:2;
     header *=sizeof( uint8_t );
 
     maxsz = min(maxsz, *rbuflen - REPLY_PARAM_MAXLEN);
@@ -312,10 +317,14 @@ static int enumerate(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_,
         sd.sd_last = sd.sd_buf;
     }
     while ( sd.sd_sindex < sindex ) {
+        if (sd.sd_last == NULL) {
+            sd.sd_did = 0;
+            return AFPERR_MISC;
+        }
         len = (unsigned char)*(sd.sd_last)++;
         if ( len == 0 ) {
             sd.sd_did = 0;	/* invalidate sd struct to force re-read */
-            return( AFPERR_NOOBJ );
+            return AFPERR_NOOBJ;
         }
         sd.sd_last += len + 1;
         sd.sd_sindex++;
@@ -394,7 +403,7 @@ static int enumerate(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_,
                 }
             }
             if ((ret = getdirparams(obj, vol, dbitmap, &s_path, dir, data + header , &esz)) != AFP_OK)
-                return( ret );
+                return ret;
 
         } else {
             if ( fbitmap == 0 ) {
@@ -403,7 +412,7 @@ static int enumerate(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_,
             /* files are added to the dircache in getfilparams() -> getmetadata() */
             if (AFP_OK != ( ret = getfilparams(obj, vol, fbitmap, &s_path, curdir,
                                                data + header, &esz, 1)) ) {
-                return( ret );
+                return ret;
             }
         }
 
@@ -460,7 +469,7 @@ static int enumerate(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_,
         if (vol->v_adouble == AD_VERSION_EA && ! (vol->v_flags & AFPVOL_NOV2TOEACONV))
             (void)rmdir(".AppleDouble");
 
-        return( AFPERR_NOOBJ );
+        return AFPERR_NOOBJ;
     }
     sd.sd_sindex = sindex + actcnt;
 
@@ -477,7 +486,7 @@ static int enumerate(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_,
     memcpy( rbuf, &actcnt, sizeof( actcnt ));
     rbuf += sizeof( actcnt );
     *rbuflen = sz;
-    return( AFP_OK );
+    return AFP_OK;
 }
 
 /* ----------------------------- */
