@@ -149,6 +149,7 @@ void fce_init_udp(void)
         if (p == NULL) {
             LOG(log_error, logtype_fce, "fce_init_udp: no socket for %s:%s",
                 udp_entry->addr, udp_entry->port);
+            continue;
         }
         udp_entry->addrinfo = *p;
         memcpy(&udp_entry->addrinfo, p, sizeof(struct addrinfo));
@@ -193,79 +194,101 @@ static ssize_t build_fce_packet(const AFPObj *obj,
     unsigned char *p = iobuf;
     size_t pathlen;
     ssize_t datalen = 0;
+    size_t remaining = MAXIOBUF;
     uint16_t uint16;
     uint32_t uint32;
     uint64_t uint64;
     uint8_t packet_info = fce_ev_info;
 
     /* FCE magic */
+    if (remaining < 8) return -1;
     memcpy(p, FCE_PACKET_MAGIC, 8);
     p += 8;
     datalen += 8;
+    remaining -= 8;
 
     /* version */
+    if (remaining < 1) return -1;
     *p = obj->fce_version;
     p += 1;
     datalen += 1;
+    remaining -= 1;
 
     /* optional: options */
     if (obj->fce_version > 1) {
+        if (remaining < 1) return -1;
         if (oldpath)
             packet_info |= FCE_EV_INFO_SRCPATH;
         *p = packet_info;
         p += 1;
         datalen += 1;
+        remaining -= 1;
     }
 
     /* event */
+    if (remaining < 1) return -1;
     *p = event;
     p += 1;
     datalen += 1;
+    remaining -= 1;
 
     /* optional: padding */
     if (obj->fce_version > 1) {
+        if (remaining < 1) return -1;
         *p = 0;
         p += 1;
         datalen += 1;
+        remaining -= 1;
     }
 
     /* optional: reserved */
     if (obj->fce_version > 1) {
+        if (remaining < 8) return -1;
         memset(p, 0, 8);
         p += 8;
         datalen += 8;
+        remaining -= 8;
     }
 
     /* event ID */
+    if (remaining < sizeof(uint32)) return -1;
     uint32 = htonl(event_id);
     memcpy(p, &uint32, sizeof(uint32));
     p += sizeof(uint32);
     datalen += sizeof(uint32);
+    remaining -= sizeof(uint32);
 
     /* optional: pid */
     if (packet_info & FCE_EV_INFO_PID) {
+        if (remaining < sizeof(uint64)) return -1;
         uint64 = pid;
         uint64 = hton64(uint64);
         memcpy(p, &uint64, sizeof(uint64));
         p += sizeof(uint64);
         datalen += sizeof(uint64);
+        remaining -= sizeof(uint64);
     }
 
     /* optional: username */
     if (packet_info & FCE_EV_INFO_USER) {
-        uint16 = strlen(user);
-        uint16 = htons(uint16);
+        size_t userlen = strnlen(user, MAXPATHLEN);
+        if (userlen >= MAXPATHLEN)
+            userlen = MAXPATHLEN - 1;
+        if (remaining < sizeof(uint16) + userlen) return -1;
+        uint16 = htons((uint16_t)userlen);
         memcpy(p, &uint16, sizeof(uint16));
         p += sizeof(uint16);
         datalen += sizeof(uint16);
-        memcpy(p, user, strlen(user));
-        p += strlen(user);
-        datalen += strlen(user);
+        memcpy(p, user, userlen);
+        p += userlen;
+        datalen += userlen;
+        remaining -= userlen;
     }
 
     /* path */
     if ((pathlen = strlen(path)) >= MAXPATHLEN)
         pathlen = MAXPATHLEN - 1;
+    if (remaining < sizeof(uint16) + pathlen) return -1;
     uint16 = pathlen;
     uint16 = htons(uint16);
     memcpy(p, &uint16, sizeof(uint16));
@@ -274,11 +297,13 @@ static ssize_t build_fce_packet(const AFPObj *obj,
     memcpy(p, path, pathlen);
     p += pathlen;
     datalen += pathlen;
+    remaining -= pathlen;
 
     /* optional: source path */
-    if (packet_info & FCE_EV_INFO_SRCPATH) {
+    if (oldpath && packet_info & FCE_EV_INFO_SRCPATH) {
         if ((pathlen = strlen(oldpath)) >= MAXPATHLEN)
             pathlen = MAXPATHLEN - 1;
+        if (remaining < sizeof(uint16) + pathlen) return -1;
         uint16 = pathlen;
         uint16 = htons(uint16);
         memcpy(p, &uint16, sizeof(uint16));
@@ -479,53 +504,43 @@ static void save_close_event(const AFPObj *obj, const char *path)
     strncpy(last_close_event.path, path, MAXPATHLEN);
 }
 
-static void fce_init_ign_names(const char *ignores)
+static void fce_init_ign_paths(const char *ignores,
+                              const char ***dest_array,
+                              bool is_directory)
 {
-    int count = 0;
     char *names = strdup(ignores);
-    char *p;
+    char *saveptr = NULL;
+    int capacity = 10;  // Initial capacity, will grow if needed
     int i = 0;
 
-    while (names[i]) {
-        count++;
-        for (; names[i] && names[i] != '/'; i++)
-            ;
-        if (!names[i])
-            break;
-        i++;
+    *dest_array = calloc(capacity + 1, sizeof(char *));
+
+    for (const char *p = strtok_r(names, ",", &saveptr); p;
+         p = strtok_r(NULL, ",", &saveptr)) {
+
+        if (i >= capacity) {
+            capacity *= 2;
+            *dest_array = realloc(*dest_array, (capacity + 1) * sizeof(char *));
+            memset(*dest_array + i, 0, (capacity + 1 - i) * sizeof(char *));
+        }
+
+        if (is_directory) {
+            size_t pathlen = strnlen(p, MAXPATHLEN);
+            char *dirpath = malloc(pathlen + 1);
+            if (dirpath) {
+                strlcpy(dirpath, p, pathlen + 1);
+                (*dest_array)[i++] = dirpath;
+            }
+        } else {
+            (*dest_array)[i++] = strdup(p);
+        }
     }
 
-    skip_files = calloc(count + 1, sizeof(char *));
-
-    for (i = 0, p = strtok(names, "/"); p ; p = strtok(NULL, "/"))
-        skip_files[i++] = strdup(p);
-
-    free(names);
-}
-
-static void fce_init_ign_directories(const char *ignores)
-{
-    int count = 0;
-    char *names = strdup(ignores);
-    char *p;
-    int i = 0;
-
-    while (names[i]) {
-        count++;
-        for (; names[i] && names[i] != ','; i++)
-            ;
-        if (!names[i])
-            break;
-        i++;
+    (*dest_array)[i] = NULL;
+    if (i < capacity) {
+        *dest_array = realloc(*dest_array, (i + 1) * sizeof(char *));
     }
 
-    skip_directories = calloc(count + 1, sizeof(char *));
-
-    for (i = 0, p = strtok(names, ","); p ; p = strtok(NULL, ",")) {
-        char *tmp = strdup("/");
-        skip_directories[i++] = strdup(strcat(strcat(tmp,p), "/"));
-     }
-
     free(names);
 }
 
@@ -558,26 +573,34 @@ int fce_register(const AFPObj *obj, fce_ev_t event, const char *path, const char
 	/* do some initialization on the fly the first time */
 	if (first_event) {
 		fce_initialize_history();
-        fce_init_ign_names(obj->fce_ign_names);
+        if (obj->fce_ign_names != NULL){
+            fce_init_ign_paths(obj->fce_ign_names, &skip_files, false);
+        }
         if (obj->fce_ign_directories != NULL){
-            fce_init_ign_directories(obj->fce_ign_directories);
+            fce_init_ign_paths(obj->fce_ign_directories, &skip_directories, true);
         }
         first_event = false;
 	}
 
-	/* handle files which should not cause events (.DS_Store atc. ) */
+	/* handle files or dirs which should not cause events (.DS_Store etc. ) */
     bname = basename_safe(path);
     dirname = realpath_safe(path);
 
-    for (int i = 0; skip_files[i] != NULL; i++) {
-        if (strcmp(bname, skip_files[i]) == 0)
-			return AFP_OK;
-	}
-	if (skip_directories != NULL){
-	   for (int i = 0; skip_directories[i] != NULL; i++) {
-		    if (strstr(dirname, skip_directories[i]))
-		 	   return AFP_OK;
-       }
+    if (bname && skip_files != NULL) {
+        for (int i = 0; skip_files[i] != NULL; i++) {
+            if (strcmp(bname, skip_files[i]) == 0) {
+                LOG(log_debug, logtype_fce, "Skip file change event for file <%s>", skip_files[i]);
+                return AFP_OK;
+            }
+        }
+    }
+    if (dirname && skip_directories != NULL) {
+        for (int i = 0; skip_directories[i] != NULL; i++) {
+            if (strstr(dirname, skip_directories[i]) == dirname) {
+                LOG(log_debug, logtype_fce, "Skip file change event for directory <%s>", skip_directories[i]);
+                return AFP_OK;
+            }
+        }
     }
 
 	/* Can we ignore this event based on type or history? */
