@@ -113,7 +113,9 @@ void *get_finderinfo(const struct vol *vol, const char *upath, struct adouble *a
         if (ad_open_native_finderinfo(upath, NativeFinderInfo))
         {
             memcpy(data, NativeFinderInfo, ADEDLEN_FINDERI);
-            chk_ext = 0;
+            /* default type ? */
+            if (!(default_type(data)))
+                chk_ext = 0;
         }
     }
 #endif
@@ -303,7 +305,7 @@ int getmetadata(const AFPObj *obj,
     data = buf;
 
     if ( ((bitmap & ( (1 << FILPBIT_FINFO)|(1 << FILPBIT_LNAME)|(1 <<FILPBIT_PDINFO) ) ) && !path->m_name)
-         || (bitmap & ( (1 << FILPBIT_LNAME) ) && utf8_encoding(obj)) /* FIXME should be m_name utf8 filename */
+         || (bitmap & (1 << FILPBIT_LNAME) && utf8_encoding(obj)) /* FIXME should be m_name utf8 filename */
          || (bitmap & (1 << FILPBIT_FNUM))) {
         if (!path->id) {
             bstring fullpath;
@@ -405,7 +407,7 @@ int getmetadata(const AFPObj *obj,
 
         case FILPBIT_MDATE :
             if ( adp && (ad_getdate(adp, AD_DATE_MODIFY, &aint) == 0)) {
-                if ((st->st_mtime > AD_DATE_TO_UNIX(aint))) {
+                if (st->st_mtime > AD_DATE_TO_UNIX(aint)) {
                    aint = AD_DATE_FROM_UNIX(st->st_mtime);
                 }
             } else {
@@ -594,7 +596,7 @@ int getmetadata(const AFPObj *obj,
             break;
 
         default :
-            return( AFPERR_BITMAP );
+            return AFPERR_BITMAP;
         }
         bitmap = bitmap>>1;
         bit++;
@@ -610,7 +612,7 @@ int getmetadata(const AFPObj *obj,
         data = set_name(vol, data, dir->d_did, path->m_name, id, utf8);
     }
     *buflen = data - buf;
-    return (AFP_OK);
+    return AFP_OK;
 }
 
 /* ----------------------- */
@@ -619,8 +621,8 @@ int getfilparams(const AFPObj *obj, struct vol *vol, uint16_t bitmap, struct pat
 {
     struct adouble	ad, *adp;
     int                 opened = 0;
-    int rc;
-    int flags; /* uninitialized ok */
+    int rc = AFP_OK;
+    int flags = 0;
 
     LOG(log_debug, logtype_afpd, "getfilparams(\"%s\")", path->u_name);
 
@@ -660,7 +662,7 @@ int getfilparams(const AFPObj *obj, struct vol *vol, uint16_t bitmap, struct pat
     if (opened)
         ad_close(adp, ADFLAGS_HF | flags);
 
-    return( rc );
+    return rc;
 }
 
 /* ----------------------------- */
@@ -683,7 +685,7 @@ int afp_createfile(AFPObj *obj, char *ibuf, size_t ibuflen _U_, char *rbuf _U_,
     ibuf += sizeof( vid );
 
     if (NULL == ( vol = getvolbyvid( vid )) )
-        return( AFPERR_PARAM );
+        return AFPERR_PARAM;
 
     if (vol->v_flags & AFPVOL_RO)
         return AFPERR_VLOCK;
@@ -697,7 +699,7 @@ int afp_createfile(AFPObj *obj, char *ibuf, size_t ibuflen _U_, char *rbuf _U_,
     if (NULL == ( s_path = cname( vol, dir, &ibuf )) )
         return get_afp_errno(AFPERR_PARAM);
     if ( *s_path->m_name == '\0' )
-        return( AFPERR_BADTYPE );
+        return AFPERR_BADTYPE;
 
     upath = s_path->u_name;
     ad_init(&ad, vol);
@@ -722,17 +724,17 @@ int afp_createfile(AFPObj *obj, char *ibuf, size_t ibuflen _U_, char *rbuf _U_,
         case EROFS:
             return AFPERR_VLOCK;
         case ENOENT : /* we were already in 'did folder' so chdir() didn't fail */
-            return ( AFPERR_NOOBJ );
+            return AFPERR_NOOBJ;
         case EEXIST :
-            return( AFPERR_EXIST );
+            return AFPERR_EXIST;
         case EACCES :
-            return( AFPERR_ACCESS );
+            return AFPERR_ACCESS;
         case EDQUOT:
         case ENOSPC :
 	    LOG(log_info, logtype_afpd, "afp_createfile: DISK FULL");
-            return( AFPERR_DFULL );
+            return AFPERR_DFULL;
         default :
-            return( AFPERR_PARAM );
+            return AFPERR_PARAM;
         }
     }
     if ( ad_meta_fileno( &ad ) == -1 ) { /* Hard META / HF */
@@ -770,7 +772,7 @@ createfile_iderr:
     curdir->d_offcnt++;
     setvoltime(obj, vol );
 
-    return (retvalue);
+    return retvalue;
 }
 
 int afp_setfilparams(AFPObj *obj, char *ibuf, size_t ibuflen _U_, char *rbuf _U_, size_t *rbuflen)
@@ -787,7 +789,7 @@ int afp_setfilparams(AFPObj *obj, char *ibuf, size_t ibuflen _U_, char *rbuf _U_
     memcpy(&vid, ibuf, sizeof( vid ));
     ibuf += sizeof( vid );
     if (NULL == ( vol = getvolbyvid( vid )) ) {
-        return( AFPERR_PARAM );
+        return AFPERR_PARAM;
     }
 
     if (vol->v_flags & AFPVOL_RO)
@@ -808,11 +810,11 @@ int afp_setfilparams(AFPObj *obj, char *ibuf, size_t ibuflen _U_, char *rbuf _U_
     }
 
     if (path_isadir(s_path)) {
-        return( AFPERR_BADTYPE ); /* it's a directory */
+        return AFPERR_BADTYPE; /* it's a directory */
     }
 
     if ( s_path->st_errno != 0 ) {
-        return( AFPERR_NOOBJ );
+        return AFPERR_NOOBJ;
     }
 
     if ((intptr_t)ibuf & 1 ) {
@@ -823,7 +825,7 @@ int afp_setfilparams(AFPObj *obj, char *ibuf, size_t ibuflen _U_, char *rbuf _U_
         setvoltime(obj, vol );
     }
 
-    return( rc );
+    return rc;
 }
 
 /*
@@ -953,7 +955,7 @@ int setfilparams(const AFPObj *obj, struct vol *vol,
             memcpy( &upriv, buf, sizeof( upriv ));
             buf += sizeof( upriv );
             upriv = ntohl (upriv);
-            if ((upriv & S_IWUSR)) {
+            if (upriv & S_IWUSR) {
             	setfilunixmode(vol, path, upriv);
             }
             else {
@@ -1005,7 +1007,7 @@ int setfilparams(const AFPObj *obj, struct vol *vol,
         }
         LOG(log_debug, logtype_afpd, "setfilparams: no adouble perms, but only FILPBIT_MDATE and/or FILPBIT_UNIXPR");
         isad = 0;
-    } else if ((ad_get_MD_flags( adp ) & O_CREAT) ) {
+    } else if (ad_get_MD_flags( adp ) & O_CREAT ) {
         ad_setname(adp, path->m_name);
         cnid_t id;
         if ((id = get_id(vol, adp, &path->st, curdir->d_did, upath, strlen(upath))) == CNID_INVALID) {
@@ -1149,10 +1151,10 @@ int renamefile(struct vol *vol, struct dir *ddir, int sdir_fd, char *src, char *
     if ( unix_rename( sdir_fd, src, -1, dst ) < 0 ) {
         switch ( errno ) {
         case ENOENT :
-            return( AFPERR_NOOBJ );
+            return AFPERR_NOOBJ;
         case EPERM:
         case EACCES :
-            return( AFPERR_ACCESS );
+            return AFPERR_ACCESS;
         case EROFS:
             return AFPERR_VLOCK;
         case EXDEV :			/* Cross device move -- try copy */
@@ -1166,11 +1168,11 @@ int renamefile(struct vol *vol, struct dir *ddir, int sdir_fd, char *src, char *
     	    }
             if (AFP_OK != ( rc = copyfile(vol, vol, ddir, sdir_fd, src, dst, newname, NULL )) ) {
                 /* on error copyfile delete dest */
-                return( rc );
+                return rc;
             }
             return deletefile(vol, sdir_fd, src, 0);
         default :
-            return( AFPERR_PARAM );
+            return AFPERR_PARAM;
         }
     }
 
@@ -1205,7 +1207,7 @@ int renamefile(struct vol *vol, struct dir *ddir, int sdir_fd, char *src, char *
         ad_close( adp, ADFLAGS_HF );
     }
 
-    return( AFP_OK );
+    return AFP_OK;
 }
 
 /* ----------------
@@ -1283,10 +1285,13 @@ int afp_copyfile(AFPObj *obj, char *ibuf, size_t ibuflen _U_, char *rbuf _U_, si
 {
     struct vol	*s_vol, *d_vol;
     struct dir	*dir;
-    char	*newname, *p, *upath;
+    char	*newname;
+    char	*p;
+    char	*upath = NULL;
     struct path *s_path;
     uint32_t	sdid, ddid;
-    int         err, retvalue = AFP_OK;
+    int         err = AFP_OK;
+    int         retvalue = AFP_OK;
     uint16_t	svid, dvid;
 
     struct adouble ad, *adp;
@@ -1298,7 +1303,7 @@ int afp_copyfile(AFPObj *obj, char *ibuf, size_t ibuflen _U_, char *rbuf _U_, si
     memcpy(&svid, ibuf, sizeof( svid ));
     ibuf += sizeof( svid );
     if (NULL == ( s_vol = getvolbyvid( svid )) ) {
-        return( AFPERR_PARAM );
+        return AFPERR_PARAM;
     }
 
     memcpy(&sdid, ibuf, sizeof( sdid ));
@@ -1316,7 +1321,7 @@ int afp_copyfile(AFPObj *obj, char *ibuf, size_t ibuflen _U_, char *rbuf _U_, si
         return get_afp_errno(AFPERR_PARAM);
     }
     if ( path_isadir(s_path) ) {
-        return( AFPERR_BADTYPE );
+        return AFPERR_BADTYPE;
     }
 
     /* don't allow copies when the file is open.
@@ -1407,8 +1412,11 @@ int afp_copyfile(AFPObj *obj, char *ibuf, size_t ibuflen _U_, char *rbuf _U_, si
     setvoltime(obj, d_vol );
 
 copy_exit:
+    if (upath && err == AFP_OK) {
+        fce_register(obj, FCE_FILE_CREATE, fullpathname(upath), NULL);
+    }
     ad_close( adp, ADFLAGS_DF |ADFLAGS_HF | ADFLAGS_SETSHRMD);
-    return( retvalue );
+    return retvalue;
 }
 
 /* ----------------------------------
@@ -1472,7 +1480,7 @@ int copyfile(struct vol *s_vol,
         return AFPERR_EXIST;
     }
     size_t copybuf_len = 0;
-    uint8_t* copybuf;
+    uint8_t* copybuf = NULL;
 
     if (s_vol->v_obj->proto == AFPPROTO_DSI)
     {
@@ -1571,7 +1579,7 @@ uint16_t   bshort = 0;
 	if (!(vol->v_ignattr & ATTRBIT_NODELETE) && (bshort & htons(ATTRBIT_NODELETE))) {
 		return AFPERR_OLOCK;
 	}
-     if ((bshort & htons(ATTRBIT_DOPEN | ATTRBIT_ROPEN))) {
+     if (bshort & htons(ATTRBIT_DOPEN | ATTRBIT_ROPEN)) {
     	return AFPERR_BUSY;
 	}
 	return 0;
@@ -1690,7 +1698,7 @@ int afp_createid(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_, char *rbuf, si
     ibuf += sizeof(vid);
 
     if (NULL == ( vol = getvolbyvid( vid )) ) {
-        return( AFPERR_PARAM);
+        return AFPERR_PARAM;
     }
 
     if (vol->v_cdb == NULL || !(vol->v_cdb->cnid_db_flags & CNID_FLAG_PERSISTENT)) {
@@ -1712,7 +1720,7 @@ int afp_createid(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_, char *rbuf, si
     }
 
     if ( path_isadir(s_path) ) {
-        return( AFPERR_BADTYPE );
+        return AFPERR_BADTYPE;
     }
 
     upath = s_path->u_name;
@@ -1829,7 +1837,7 @@ int afp_resolveid(AFPObj *obj, char *ibuf, size_t ibuflen _U_, char *rbuf, size_
     ibuf += sizeof(vid);
 
     if (NULL == ( vol = getvolbyvid( vid )) ) {
-        return( AFPERR_PARAM);
+        return AFPERR_PARAM;
     }
 
     if (vol->v_cdb == NULL || !(vol->v_cdb->cnid_db_flags & CNID_FLAG_PERSISTENT)) {
@@ -1937,7 +1945,7 @@ int afp_deleteid(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_, char *rbuf _U_
     ibuf += sizeof(vid);
 
     if (NULL == ( vol = getvolbyvid( vid )) ) {
-        return( AFPERR_PARAM);
+        return AFPERR_PARAM;
     }
 
     if (vol->v_cdb == NULL || !(vol->v_cdb->cnid_db_flags & CNID_FLAG_PERSISTENT)) {
@@ -1963,7 +1971,7 @@ int afp_deleteid(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_, char *rbuf _U_
             err = AFPERR_NOOBJ;
             goto delete;
         }
-        return( AFPERR_PARAM );
+        return AFPERR_PARAM;
     }
 
     err = AFP_OK;
@@ -2083,10 +2091,10 @@ int afp_exchangefiles(AFPObj *obj, char *ibuf, size_t ibuflen _U_, char *rbuf _U
     ibuf += sizeof(vid);
 
     if (NULL == ( vol = getvolbyvid( vid )) ) {
-        return( AFPERR_PARAM);
+        return AFPERR_PARAM;
     }
 
-    if ((vol->v_flags & AFPVOL_RO))
+    if (vol->v_flags & AFPVOL_RO)
         return AFPERR_VLOCK;
 
     /* source and destination dids */
@@ -2244,7 +2252,8 @@ int afp_exchangefiles(AFPObj *obj, char *ibuf, size_t ibuflen _U_, char *rbuf _U
 
     if (AD_META_OPEN(adsp) || AD_META_OPEN(addp)) {
         struct adouble adtmp;
-        bool opened_ads, opened_add;
+        bool opened_ads = false;
+        bool opened_add = false;
 
         ad_init(&adtmp, vol);
         ad_init_offsets(&adtmp);
