@@ -11,6 +11,11 @@
 #include <ctype.h>
 #include <errno.h>
 #include <grp.h>
+#ifdef HAVE_INIPARSER_INIPARSER_H
+#include <iniparser/iniparser.h>
+#else
+#include <iniparser.h>
+#endif
 #include <inttypes.h>
 #include <netinet/in.h>
 #include <pwd.h>
@@ -37,7 +42,6 @@
 #include <atalk/fce_api.h>
 #include <atalk/ftw.h>
 #include <atalk/globals.h>
-#include <atalk/iniparser.h>
 
 #ifdef HAVE_LDAP
 #include <atalk/ldapconfig.h>
@@ -240,7 +244,7 @@ static int getvolspace(const AFPObj *obj, struct vol *vol,
          ? 0x7fffffffL : 0xffffffffL);
 
     if (( rc = ustatfs_getvolspace( vol, xbfree, xbtotal, bsize)) != AFP_OK ) {
-        return( rc );
+        return rc;
     }
 
 #ifndef NO_QUOTA_SUPPORT
@@ -270,7 +274,7 @@ getvolspace_done:
 
     *bfree = MIN(*xbfree, maxsize);
     *btotal = MIN(*xbtotal, maxsize);
-    return( AFP_OK );
+    return AFP_OK;
 }
 
 /* -----------------------
@@ -351,7 +355,7 @@ static int getvolparams(const AFPObj *obj, uint16_t bitmap, struct vol *vol, str
             if ( isad ) {
                 ad_close( &ad, ADFLAGS_HF );
             }
-            return( AFPERR_PARAM );
+            return AFPERR_PARAM;
         }
     }
 
@@ -480,7 +484,7 @@ static int getvolparams(const AFPObj *obj, uint16_t bitmap, struct vol *vol, str
             if ( isad ) {
                 ad_close( &ad, ADFLAGS_HF );
             }
-            return( AFPERR_BITMAP );
+            return AFPERR_BITMAP;
         }
         bitmap = bitmap>>1;
         bit++;
@@ -502,7 +506,7 @@ static int getvolparams(const AFPObj *obj, uint16_t bitmap, struct vol *vol, str
         ad_close(&ad, ADFLAGS_HF);
     }
     *buflen = data - buf;
-    return( AFP_OK );
+    return AFP_OK;
 }
 
 /* ------------------------- */
@@ -514,7 +518,7 @@ static int stat_vol(const AFPObj *obj, uint16_t bitmap, struct vol *vol, char *r
 
     if ( stat( vol->v_path, &st ) < 0 ) {
         *rbuflen = 0;
-        return( AFPERR_PARAM );
+        return AFPERR_PARAM;
     }
     /* save the volume device number */
     vol->v_dev = st.st_dev;
@@ -523,12 +527,12 @@ static int stat_vol(const AFPObj *obj, uint16_t bitmap, struct vol *vol, char *r
     if (( ret = getvolparams(obj, bitmap, vol, &st,
                               rbuf + sizeof( bitmap ), &buflen )) != AFP_OK ) {
         *rbuflen = 0;
-        return( ret );
+        return ret;
     }
     *rbuflen = buflen + sizeof( bitmap );
     bitmap = htons( bitmap );
     memcpy(rbuf, &bitmap, sizeof( bitmap ));
-    return( AFP_OK );
+    return AFP_OK;
 
 }
 
@@ -612,7 +616,7 @@ int afp_getsrvrparms(AFPObj *obj, char *ibuf _U_, size_t ibuflen _U_, char *rbuf
     memcpy(data, &aint, sizeof( uint32_t));
     data += sizeof( uint32_t);
     *data = vcnt;
-    return( AFP_OK );
+    return AFP_OK;
 }
 
 /* ------------------------- */
@@ -654,7 +658,7 @@ static int volume_openDB(const AFPObj *obj _U_, struct vol *volume)
 {
     int flags = 0;
 
-    if ((volume->v_flags & AFPVOL_NODEV)) {
+    if (volume->v_flags & AFPVOL_NODEV) {
         flags |= CNID_FLAG_NODEV;
     }
 
@@ -758,7 +762,7 @@ int afp_openvol(AFPObj *obj, char *ibuf, size_t ibuflen _U_, char *rbuf, size_t
         return AFPERR_ACCESS;
     }
 
-    if (( volume->v_flags & AFPVOL_OPEN  ) ) {
+    if ( volume->v_flags & AFPVOL_OPEN ) {
         /* the volume is already open */
         return stat_vol(obj, bitmap, volume, rbuf, rbuflen);
     }
@@ -819,7 +823,6 @@ int afp_openvol(AFPObj *obj, char *ibuf, size_t ibuflen _U_, char *rbuf, size_t
                        bfromcstr(volume->v_path),
                        &st)
             ) == NULL) {
-        free(vol_mname);
         LOG(log_error, logtype_afpd, "afp_openvol(%s): malloc: %s", volume->v_path, strerror(errno) );
         ret = AFPERR_MISC;
         goto openvol_err;
@@ -845,7 +848,7 @@ int afp_openvol(AFPObj *obj, char *ibuf, size_t ibuflen _U_, char *rbuf, size_t
          * fixing the trash at DID 17.
          * FIXME (RL): should it be done inside a CNID backend ? (always returning Trash DID when asked) ?
          */
-        if ((volume->v_cdb->cnid_db_flags & CNID_FLAG_PERSISTENT)) {
+        if (volume->v_cdb->cnid_db_flags & CNID_FLAG_PERSISTENT) {
 
             /* FIXME find db time stamp */
             if (cnid_getstamp(volume->v_cdb, volume->v_stamp, sizeof(volume->v_stamp)) < 0) {
@@ -858,12 +861,14 @@ int afp_openvol(AFPObj *obj, char *ibuf, size_t ibuflen _U_, char *rbuf, size_t
         }
 
         const char *msg;
-        if ((msg = atalk_iniparser_getstring(obj->iniconfig, volume->v_configname, "login message",  NULL)) != NULL)
+        char option[MAXOPTLEN];
+        snprintf(option, sizeof(option), "%s:login message", volume->v_configname);
+        if ((msg = iniparser_getstring(obj->iniconfig, option,  NULL)) != NULL)
             setmessage(msg);
 
         free(vol_mname);
         server_ipc_volumes(obj);
-        return( AFP_OK );
+        return AFP_OK;
     }
 
 openvol_err:
@@ -909,7 +914,7 @@ void close_all_vol(const AFPObj *obj)
     struct vol  *ovol;
     curdir = NULL;
     for ( ovol = getvolumes(); ovol; ovol = ovol->v_next ) {
-        if ( (ovol->v_flags & AFPVOL_OPEN) ) {
+        if ( ovol->v_flags & AFPVOL_OPEN ) {
             ovol->v_flags &= ~AFPVOL_OPEN;
             closevol(obj, ovol);
         }
@@ -926,7 +931,7 @@ int afp_closevol(AFPObj *obj, char *ibuf, size_t ibuflen _U_, char *rbuf _U_, si
     ibuf += 2;
     memcpy(&vid, ibuf, sizeof( vid ));
     if (NULL == ( vol = getvolbyvid( vid )) ) {
-        return( AFPERR_PARAM );
+        return AFPERR_PARAM;
     }
 
     (void)chdir("/");
@@ -934,7 +939,7 @@ int afp_closevol(AFPObj *obj, char *ibuf, size_t ibuflen _U_, char *rbuf _U_, si
     closevol(obj, vol);
     server_ipc_volumes(obj);
 
-    return( AFP_OK );
+    return AFP_OK;
 }
 
 /* --------------------------
@@ -1024,7 +1029,7 @@ int afp_getvolparams(AFPObj *obj, char *ibuf, size_t ibuflen _U_,char *rbuf, siz
 
     if (NULL == ( vol = getvolbyvid( vid )) ) {
         *rbuflen = 0;
-        return( AFPERR_PARAM );
+        return AFPERR_PARAM;
     }
 
     return stat_vol(obj, bitmap, vol, rbuf, rbuflen);
@@ -1048,10 +1053,10 @@ int afp_setvolparams(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_, char *rbuf
     ibuf += sizeof(bitmap);
 
     if (( vol = getvolbyvid( vid )) == NULL ) {
-        return( AFPERR_PARAM );
+        return AFPERR_PARAM;
     }
 
-    if ((vol->v_flags & AFPVOL_RO))
+    if (vol->v_flags & AFPVOL_RO)
         return AFPERR_VLOCK;
 
     /* we can only set the backup date. */
@@ -1070,5 +1075,5 @@ int afp_setvolparams(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_, char *rbuf
     ad_setdate(&ad, AD_DATE_BACKUP, aint);
     ad_flush(&ad);
     ad_close(&ad, ADFLAGS_HF);
-    return( AFP_OK );
+    return AFP_OK;
 }
