@@ -184,7 +184,7 @@ int writeconf(char *cf)
     if ( stat( path, &st ) == 0 ) {
 	if (( st.st_mode & S_IWUSR ) == 0 ) {
 	    LOG(log_info, logtype_atalkd, "%s not writable, won't rewrite", path );
-	    return( -1 );
+	    return -1;
 	}
 	 mode = st.st_mode;
     }
@@ -192,20 +192,21 @@ int writeconf(char *cf)
     if (( p = strrchr( path, '/' )) == NULL ) {
 	strcpy( newpath, _PATH_ATALKDTMP );
     } else {
-	sprintf( newpath, "%.*s/%s", (int)(p - path), path, _PATH_ATALKDTMP );
+	snprintf( newpath, sizeof(newpath), "%.*s/%s", (int)(p - path), path, _PATH_ATALKDTMP );
     }
     if (( fd = open( newpath, O_WRONLY|O_CREAT|O_TRUNC, mode )) < 0 ) {
 	LOG(log_error, logtype_atalkd, "%s: %s", newpath, strerror(errno) );
-	return( -1 );
+	return -1;
     }
     if (( newconf = fdopen( fd, "w" )) == NULL ) {
 	LOG(log_error, logtype_atalkd, "fdreopen %s: %s", newpath, strerror(errno) );
-	return( -1 );
+	return -1;
     }
 
     if (( conf = fopen( path, "r" )) == NULL && cf ) {
 	LOG(log_error, logtype_atalkd, "%s: %s", path, strerror(errno) );
-	return( -1 );
+	fclose(newconf);
+	return -1;
     }
 
     iface = interfaces->i_next;
@@ -214,7 +215,7 @@ int writeconf(char *cf)
 	if ( conf != NULL && ( argv = at_parseline( line )) == NULL ) {
 	    if ( fputs( line, newconf ) == EOF ) {
 		LOG(log_error, logtype_atalkd, "fputs: %s", strerror(errno) );
-		return( -1 );
+		return -1;
 	    }
 	    freeline( argv );
 	    continue;
@@ -250,7 +251,8 @@ int writeconf(char *cf)
                     if ( NULL ==
                       (zonename = strdup(((struct ziptab *)l->l_data)->zt_name))) {
 		        LOG(log_error, logtype_atalkd, "malloc: %s",  strerror(errno) );
-		        return( -1 );
+				fclose(newconf);
+		        return -1;
                     }
                     len = ((struct ziptab *)l->l_data)->zt_len;
                 }
@@ -272,9 +274,9 @@ int writeconf(char *cf)
 
     if ( rename( newpath, path ) < 0 ) {
 	LOG(log_error, logtype_atalkd, "rename %s to %s: %s", newpath, path, strerror(errno) );
-	return( -1 );
+	return -1;
     }
-    return( 0 );
+    return 0;
 }
 
 /*
@@ -314,7 +316,7 @@ int readconf(char *cf)
 	p = cf;
     }
     if (( conf = fopen( p, "r" )) == NULL ) {
-        return( -1 );
+        return -1;
     }
 
 #ifndef __svr4__
@@ -429,9 +431,9 @@ int readconf(char *cf)
     for ( iface = interfaces, cc = 0; iface; iface = iface->i_next, cc++ )
 	;
     if ( cc >= IFBASE ) {
-	return( 0 );
+	return 0;
     } else {
-	return( -1 );
+	return -1;
     }
 
 read_conf_err:
@@ -461,7 +463,7 @@ int router(struct interface *iface, char **av _U_)
 
     /* -router also implies -seed */
     iface->i_flags |= IFACE_RSEED | IFACE_SEED | IFACE_ISROUTER;
-    return( 1 );
+    return 1;
 }
 
 /*ARGSUSED*/
@@ -474,7 +476,7 @@ int dontroute(struct interface *iface, char **av _U_)
     }
 
     iface->i_flags |= IFACE_DONTROUTE;
-    return( 1 );
+    return 1;
 }
 
 /*ARGSUSED*/
@@ -491,7 +493,7 @@ int seed( struct interface *iface, char **av _U_)
     }
 
     iface->i_flags |= IFACE_SEED;
-    return( 1 );
+    return 1;
 }
 
 int phase(struct interface *iface, char **av)
@@ -517,7 +519,7 @@ int phase(struct interface *iface, char **av)
 	fprintf( stderr, "No phase %d.\n", n );
 	return -1;
     }
-    return( 2 );
+    return 2;
 }
 
 int net(struct interface *iface, char **av)
@@ -585,7 +587,7 @@ int net(struct interface *iface, char **av)
 	fprintf( stderr, "Must specify phase before networks.\n" );
 	return -1;
     }
-    return( 2 );
+    return 2;
 }
 
 int addr(struct interface *iface, char **av)
@@ -619,7 +621,7 @@ int addr(struct interface *iface, char **av)
 		iface->i_caddr.sat_addr.s_net;
     }
 
-    return( 2 );
+    return 2;
 }
 
 int zone(struct interface *iface, char **av)
@@ -645,11 +647,13 @@ int zone(struct interface *iface, char **av)
     if ( iface->i_flags & IFACE_SEED ) {
         if ( iface->i_rt == NULL ) {
   	    fprintf( stderr, "Must specify net-range before zones.\n" );
+	    free(zname);
 	    return -1;
         }
 
 	if (( zt = newzt( strlen( zname ), zname )) == NULL ) {
 	    perror( "newzt" );
+	    free(zname);
 	    return -1;
 	}
 	if ( iface->i_czt == NULL ) {
@@ -661,7 +665,7 @@ int zone(struct interface *iface, char **av)
     }
     free(zname);
 
-    return( 2 );
+    return 2;
 }
 
 /*
@@ -740,7 +744,7 @@ int getifconf(void)
     }
     freeifacelist(start);
     (void)close( s );
-    return( 0 );
+    return 0;
 }
 
 /*
@@ -754,7 +758,7 @@ struct interface *newiface( const char *name)
 
     if (( niface = (struct interface *)calloc(1, sizeof( struct interface )))
 	    == NULL ) {
-	return( NULL );
+	return NULL;
     }
     strlcpy( niface->i_name, name, sizeof(niface->i_name));
 #ifdef BSD4_4
@@ -763,7 +767,7 @@ struct interface *newiface( const char *name)
 #endif /* BSD4_4 */
     niface->i_addr.sat_family = AF_APPLETALK;
     niface->i_caddr.sat_family = AF_APPLETALK;
-    return( niface );
+    return niface;
 }
 
 #ifdef __svr4__
@@ -825,6 +829,6 @@ int plumb(void)
     close(fd);
     }
 
-    return( 0 );
+    return 0;
 }
 #endif /* __svr4__ */
