@@ -16,31 +16,31 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
 
-#include <unistd.h>
-#include <stdlib.h>
-#include <sys/types.h>
-#include <sys/stat.h>
 #include <dirent.h>
-#include <fcntl.h>
-#include <string.h>
 #include <errno.h>
+#include <fcntl.h>
 #include <setjmp.h>
+#include <stdlib.h>
+#include <string.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <unistd.h>
 
-#include <atalk/adouble.h>
-#include <atalk/unicode.h>
-#include <atalk/netatalk_conf.h>
-#include <atalk/volume.h>
-#include <atalk/ea.h>
-#include <atalk/util.h>
 #include <atalk/acl.h>
-#include <atalk/compat.h>
+#include <atalk/adouble.h>
 #include <atalk/cnid.h>
+#include <atalk/compat.h>
+#include <atalk/ea.h>
 #include <atalk/errchk.h>
+#include <atalk/netatalk_conf.h>
+#include <atalk/unicode.h>
+#include <atalk/util.h>
+#include <atalk/volume.h>
 
 #include "cmd_dbd.h"
-#include "dbif.h"
 #include "db_param.h"
 #include "dbd.h"
+#include "dbif.h"
 
 /* Some defines to ease code parsing */
 #define ADDIR_OK (addir_ok == 0)
@@ -60,8 +60,8 @@ static char           *special_dirs[] = {
     ".zfs",
     NULL
 };
-static struct cnid_dbd_rqst rqst;
-static struct cnid_dbd_rply rply;
+static struct cnid_dbd_rqst rqst _U_;
+static struct cnid_dbd_rply rply _U_;
 static jmp_buf jmp;
 static char pname[MAXPATHLEN] = "../";
 
@@ -82,12 +82,12 @@ static char *utompath(char *upath)
     u = upath;
     outlen = strlen(upath);
 
-    if ((vol->v_casefold & AFPVOL_UTOMUPPER))
+    if (vol->v_casefold & AFPVOL_UTOMUPPER)
         flags |= CONV_TOUPPER;
-    else if ((vol->v_casefold & AFPVOL_UTOMLOWER))
+    else if (vol->v_casefold & AFPVOL_UTOMLOWER)
         flags |= CONV_TOLOWER;
 
-    if ((vol->v_flags & AFPVOL_EILSEQ)) {
+    if (vol->v_flags & AFPVOL_EILSEQ) {
         flags |= CONV__EILSEQ;
     }
 
@@ -101,7 +101,7 @@ static char *utompath(char *upath)
         return NULL;
     }
 
-    return(m);
+    return m;
 }
 
 /*
@@ -110,9 +110,9 @@ static char *utompath(char *upath)
 */
 static const char *check_netatalk_dirs(const char *name)
 {
-    int c;
+    const int max_dirs = 2;
 
-    for (c=0; netatalk_dirs[c]; c++) {
+    for (int c = 0; c < max_dirs && netatalk_dirs[c]; c++) {
         if ((strcmp(name, netatalk_dirs[c])) == 0)
             return netatalk_dirs[c];
     }
@@ -125,9 +125,9 @@ static const char *check_netatalk_dirs(const char *name)
 */
 static const char *check_special_dirs(const char *name)
 {
-    int c;
+    const int max_dirs = 1;
 
-    for (c=0; special_dirs[c]; c++) {
+    for (int c = 0; c < max_dirs && special_dirs[c]; c++) {
         if ((strcmp(name, special_dirs[c])) == 0)
             return special_dirs[c];
     }
@@ -179,13 +179,14 @@ static int check_adfile(const char *fname, const struct stat *st, const char **n
         }
         return 0;
     }
-    
+
     if (S_ISDIR(st->st_mode))
         adflags |= ADFLAGS_DIR;
 
     adname = vol->ad_path(fname, adflags);
 
-    if ((ret = access( adname, F_OK)) != 0) {
+    int fd = open(adname, O_RDONLY | O_NOFOLLOW);
+    if (fd == -1) {
         if (errno != ENOENT) {
             dbd_log(LOGSTD, "Access error for ad-file '%s/%s': %s",
                     cwdbuf, adname, strerror(errno));
@@ -194,9 +195,11 @@ static int check_adfile(const char *fname, const struct stat *st, const char **n
         /* Missing. Log and create it */
         dbd_log(LOGSTD, "Missing AppleDouble file '%s/%s'", cwdbuf, adname);
 
-        if (dbd_flags & DBD_FLAGS_SCAN)
+        if (dbd_flags & DBD_FLAGS_SCAN) {
             /* Scan only requested, don't change anything */
+            close(fd);
             return -1;
+        }
 
         /* Create ad file */
         ad_init(&ad, vol);
@@ -204,7 +207,7 @@ static int check_adfile(const char *fname, const struct stat *st, const char **n
         if ((ret = ad_open(&ad, fname, adflags | ADFLAGS_CREATE | ADFLAGS_RDWR, 0666)) != 0) {
             dbd_log( LOGSTD, "Error creating AppleDouble file '%s/%s': %s",
                      cwdbuf, adname, strerror(errno));
-
+            close(fd);
             return -1;
         }
 
@@ -213,11 +216,12 @@ static int check_adfile(const char *fname, const struct stat *st, const char **n
         ad_flush(&ad);
         ad_close(&ad, ADFLAGS_HF);
 
-        chown(adname, st->st_uid, st->st_gid);
-        /* FIXME: should we inherit mode too here ? */
-#if 0
-        chmod(adname, st->st_mode);
-#endif
+        fd = open(adname, O_RDWR | O_NOFOLLOW);
+        if (fd != -1) {
+            if (fchown(fd, st->st_uid, st->st_gid) < 0)
+                dbd_log(LOGSTD, "Could not chown \"%s\" (%s)", adname, strerror(errno));
+            close(fd);
+        }
     } else {
         ad_init(&ad, vol);
         if (ad_open(&ad, fname, adflags | ADFLAGS_RDONLY) != 0) {
@@ -225,14 +229,15 @@ static int check_adfile(const char *fname, const struct stat *st, const char **n
             return -1;
         }
         ad_close(&ad, ADFLAGS_HF);
+        close(fd);
     }
     return 0;
 }
 
-/* 
+/*
    Remove all files with file::EA* from adouble dir
 */
-static void remove_eafiles(const char *name, struct ea *ea)
+static void remove_eafiles(const char *name, struct ea *ea _U_)
 {
     DIR *dp = NULL;
     struct dirent *ep;
@@ -274,7 +279,7 @@ exit:
         dbd_log(LOGSTD, "Couldn't chdir to '%s': %s", cwdbuf, strerror(errno));
         /* we can't proceed */
         longjmp(jmp, 1); /* this jumps back to cmd_dbd_scanvol() */
-    }    
+    }
 }
 
 /*
@@ -298,7 +303,7 @@ static int check_eafiles(const char *fname)
     }
 
     /* Check all EAs */
-    while (count < ea.ea_count) {        
+    while (count < ea.ea_count) {
         dbd_log(LOGDEBUG, "EA: %s", (*ea.ea_entries)[count].ea_name);
         remove = 0;
 
@@ -334,45 +339,56 @@ static int check_eafiles(const char *fname)
 /*
   Check for .AppleDouble folder and .Parent, create if missing
 */
-static int check_addir(int volroot)
+static int check_addir(int volroot _U_)
 {
-    int addir_ok, adpar_ok;
+    int addir_fd = -1;
+    int parent_fd = -1;
     struct stat st;
     struct adouble ad;
     char *mname = NULL;
+    const char *ad_parent_path;
 
     if (vol->v_adouble == AD_VERSION_EA)
         return 0;
 
     /* Check for ad-dir */
-    if ( (addir_ok = access(ADv2_DIRNAME, F_OK)) != 0) {
+    addir_fd = open(ADv2_DIRNAME, O_RDONLY);
+    if (addir_fd == -1) {
         if (errno != ENOENT) {
-            dbd_log(LOGSTD, "Access error in directory %s: %s", cwdbuf, strerror(errno));
+            dbd_log(LOGSTD, "Open error for directory %s/%s: %s", cwdbuf, ADv2_DIRNAME, strerror(errno));
             return -1;
         }
         dbd_log(LOGSTD, "Missing %s for '%s'", ADv2_DIRNAME, cwdbuf);
     }
 
     /* Check for ".Parent" */
-    if ( (adpar_ok = access(vol->ad_path(".", ADFLAGS_DIR), F_OK)) != 0) {
+    ad_parent_path = vol->ad_path(".", ADFLAGS_DIR);
+    parent_fd = open(ad_parent_path, O_RDONLY);
+    if (parent_fd == -1) {
         if (errno != ENOENT) {
-            dbd_log(LOGSTD, "Access error on '%s/%s': %s",
-                    cwdbuf, vol->ad_path(".", ADFLAGS_DIR), strerror(errno));
+            dbd_log(LOGSTD, "Open error on '%s/%s': %s",
+                    cwdbuf, ad_parent_path, strerror(errno));
+            if (addir_fd != -1)
+                close(addir_fd);
             return -1;
         }
         dbd_log(LOGSTD, "Missing .AppleDouble/.Parent for '%s'", cwdbuf);
     }
 
     /* Is one missing ? */
-    if ((addir_ok != 0) || (adpar_ok != 0)) {
+    if ((addir_fd == -1) || (parent_fd == -1)) {
         /* Yes, but are we only scanning ? */
         if (dbd_flags & DBD_FLAGS_SCAN) {
             /* Yes:  missing .Parent is not a problem, but missing ad-dir
                causes later checking of ad-files to fail. So we have to return appropriately */
-            if (addir_ok != 0)
+            if (addir_fd == -1) {
+                if (parent_fd != -1)
+                    close(parent_fd);
                 return -1;
-            else  /* (adpar_ok != 0) */
+            } else { /* (parent_fd == -1) */
+                close(addir_fd);
                 return 0;
+            }
         }
 
         /* Create ad dir and set name */
@@ -380,6 +396,10 @@ static int check_addir(int volroot)
 
         if (ad_open(&ad, ".", ADFLAGS_HF | ADFLAGS_DIR | ADFLAGS_CREATE | ADFLAGS_RDWR, 0777) != 0) {
             dbd_log( LOGSTD, "Error creating AppleDouble dir in %s: %s", cwdbuf, strerror(errno));
+            if (addir_fd != -1)
+                close(addir_fd);
+            if (parent_fd != -1)
+                close(parent_fd);
             return -1;
         }
 
@@ -394,12 +414,40 @@ static int check_addir(int volroot)
         /* Inherit owner/group from "." to ".AppleDouble" and ".Parent" */
         if ((lstat(".", &st)) != 0) {
             dbd_log( LOGSTD, "Couldn't stat %s: %s", cwdbuf, strerror(errno));
+            if (addir_fd != -1)
+                close(addir_fd);
+            if (parent_fd != -1)
+                close(parent_fd);
             return -1;
         }
-        chown(ADv2_DIRNAME, st.st_uid, st.st_gid);
-        chown(vol->ad_path(".", ADFLAGS_DIR), st.st_uid, st.st_gid);
+
+        /* If directories were created, we need their new file descriptors */
+        if (addir_fd == -1) {
+            addir_fd = open(ADv2_DIRNAME, O_RDONLY);
+            if (addir_fd != -1) {
+                if (fchown(addir_fd, st.st_uid, st.st_gid) < 0)
+                    dbd_log(LOGSTD, "fchown failed on fd for \"%s\"", ADv2_DIRNAME);
+            } else {
+                dbd_log(LOGSTD, "Couldn't open newly created directory \"%s\"", ADv2_DIRNAME);
+            }
+        }
+
+        if (parent_fd == -1) {
+            parent_fd = open(ad_parent_path, O_RDONLY);
+            if (parent_fd != -1) {
+                if (fchown(parent_fd, st.st_uid, st.st_gid) < 0)
+                    dbd_log(LOGSTD, "fchown failed on fd for \"%s\"", ad_parent_path);
+            } else {
+                dbd_log(LOGSTD, "Couldn't open newly created file \"%s\"", ad_parent_path);
+            }
+        }
     }
 
+    if (addir_fd != -1)
+        close(addir_fd);
+    if (parent_fd != -1)
+        close(parent_fd);
+
     return 0;
 }
 
@@ -427,7 +475,7 @@ static int check_eafile_in_adouble(const char *name)
 
             /* Get string before "::EA" from EA filename */
             namep[0] = 0;
-            strlcpy(pname + 3, namedup, sizeof(pname)); /* Prepends "../" */
+            strlcpy(pname + 3, namedup, strlen(pname)); /* Prepends "../" */
 
             if ((access( pname, F_OK)) == 0) {
                 ret = 1;
@@ -516,7 +564,7 @@ static int read_addir(void)
             continue;
 
         /* Check for data file */
-        strcpy(pname + 3, ep->d_name);
+        strlcpy(pname + 3, ep->d_name, sizeof(pname) - 3);
         if ((access( pname, F_OK)) != 0) {
             if (errno != ENOENT) {
                 dbd_log(LOGSTD, "Access error for file '%s/%s': %s",
@@ -571,7 +619,7 @@ static cnid_t check_cnid(const char *name, cnid_t did, struct stat *st, int adfi
     if (ADFILE_OK) {
         ad_init(&ad, vol);
         if (ad_open(&ad, name, adflags | ADFLAGS_RDWR) != 0) {
-            
+
             if (vol->v_adouble != AD_VERSION_EA) {
                 dbd_log( LOGSTD, "Error opening AppleDouble file for '%s/%s': %s", cwdbuf, name, strerror(errno));
                 return CNID_INVALID;
@@ -706,7 +754,7 @@ static int dbd_readdir(int volroot, cnid_t did)
                      cwdbuf, ep->d_name, strerror(errno));
             continue;
         }
-        
+
         switch (st.st_mode & S_IFMT) {
         case S_IFREG:
         case S_IFDIR:
@@ -733,7 +781,7 @@ static int dbd_readdir(int volroot, cnid_t did)
 
         statcount++;
         if ((statcount % 10000) == 0) {
-            if (dbd_flags & DBD_FLAGS_STATS)            
+            if (dbd_flags & DBD_FLAGS_STATS)
                 dbd_log(LOGSTD, "Scanned: %10llu, time: %10llu s",
                         statcount, (unsigned long long)(time(NULL) - t));
         }
@@ -777,8 +825,8 @@ static int dbd_readdir(int volroot, cnid_t did)
           Recursion
         **************************************************************************/
         if (S_ISDIR(st.st_mode) && cnid) { /* If we have no cnid for it we can't enter recursion */
-            strcat(cwdbuf, "/");
-            strcat(cwdbuf, name);
+            strlcat(cwdbuf, "/", sizeof(cwdbuf));
+            strlcat(cwdbuf, name, sizeof(cwdbuf));
             dbd_log( LOGDEBUG, "Entering directory: %s", cwdbuf);
             if (-1 == (cwd = open(".", O_RDONLY))) {
                 dbd_log( LOGSTD, "Can't open directory '%s': %s", cwdbuf, strerror(errno));
@@ -792,7 +840,8 @@ static int dbd_readdir(int volroot, cnid_t did)
 
             ret = dbd_readdir(0, cnid);
 
-            fchdir(cwd);
+            if (fchdir(cwd) < 0)
+                dbd_log(LOGSTD, "Cant chdir to directory '%i': %s", cwd, strerror(errno));
             close(cwd);
             *(strrchr(cwdbuf, '/')) = 0;
             if (ret < 0)
@@ -849,8 +898,11 @@ int cmd_dbd_scanvol(struct vol *vol_in, dbd_flags_t flags)
         EC_EXIT_STATUS(0); /* Got signal, jump from dbd_readdir */
     }
 
-    strcpy(cwdbuf, vol->v_path);
-    chdir(vol->v_path);
+    strlcpy(cwdbuf, vol->v_path, sizeof(cwdbuf));
+    if (chdir(vol->v_path) < 0) {
+        dbd_log(LOGSTD, "Can't chdir to '%s': %s", vol->v_path, strerror(errno));
+        EC_FAIL;
+    }
 
     if ((vol->v_adouble == AD_VERSION_EA) && (dbd_flags & DBD_FLAGS_V2TOEA)) {
         if (lstat(".", &st) != 0)
