@@ -258,8 +258,8 @@ static struct server *test_usockfn(const char *path)
             }
         }
 
-        sprintf(buf1, "%i", sv[1]);
-        sprintf(buf2, "%i", rqstfd);
+        snprintf(buf1, sizeof(buf1), "%i", sv[1]);
+        snprintf(buf2, sizeof(buf2), "%i", rqstfd);
 
         if (up->count == MAXSPAWN) {
             /* there's a pb with the db inform child, it will delete the db */
@@ -471,27 +471,49 @@ int main(int argc, char *argv[])
             debug = 1;
             break;
         case 'F':
+            if (obj.cmdlineconfigfile != NULL) {
+                free((void *)obj.cmdlineconfigfile);
+            }
             obj.cmdlineconfigfile = strdup(optarg);
             break;
         case 'v':
         case 'V':
             printf("cnid_metad (Netatalk %s)\n", VERSION);
-            return -1;
+            if (obj.cmdlineconfigfile != NULL) {
+                free((void *)obj.cmdlineconfigfile);
+            }
+            return 0;
         default:
             printf("cnid_metad [-dvV] [-F alternate configfile ]\n");
+            if (obj.cmdlineconfigfile != NULL) {
+                free((void *)obj.cmdlineconfigfile);
+            }
             return -1;
         }
     }
 
-    if (!debug && daemonize(0, 0) != 0)
+    if (!debug && daemonize() != 0) {
+        if (obj.cmdlineconfigfile != NULL) {
+            free((void *)obj.cmdlineconfigfile);
+        }
         exit(EXITERR_SYS);
+    }
 
-    if (afp_config_parse(&obj, "cnid_metad") != 0)
+    if (afp_config_parse(&obj, "cnid_metad") != 0) {
+        if (obj.cmdlineconfigfile != NULL) {
+            free((void *)obj.cmdlineconfigfile);
+        }
         daemon_exit(1);
+    }
+
+    if (obj.cmdlineconfigfile != NULL) {
+        free((void *)obj.cmdlineconfigfile);
+        obj.cmdlineconfigfile = NULL;
+    }
 
     (void)setlimits();
 
-    host = atalk_iniparser_getstrdup(obj.iniconfig, INISEC_GLOBAL, "cnid listen", "localhost:4700");
+    host = INIPARSER_GETSTRDUP(obj.iniconfig, INISEC_GLOBAL, "cnid listen", "localhost:4700");
     if ((port = strrchr(host, ':')))
         *port++ = 0;
     else
@@ -501,6 +523,10 @@ int main(int argc, char *argv[])
 
     LOG(log_note, logtype_afpd, "CNID Server listening on %s:%s", host, port);
 
+    if (host) {
+        free(host);
+    }
+
     /* switch uid/gid */
     if (uid || gid) {
         LOG(log_debug, logtype_cnid, "Setting uid/gid to %i/%i", uid, gid);
