@@ -127,6 +127,10 @@ static int get_lock(int cmd, const char *dbpath)
     case LOCK_EXCL:
     case LOCK_SHRD:
         if (lockfd == -1) {
+            if (dbpath == NULL) {
+                LOG(log_error, logtype_cnid, "get_lock: dbpath is NULL");
+                return -1;
+            }
             if ( (strlen(dbpath) + strlen(&LOCKFILENAME[1])) > (PATH_MAX - 1) ) {
                 LOG(log_error, logtype_cnid, ".AppleDB pathname too long");
                 return -1;
@@ -231,7 +235,9 @@ static int delete_db(void)
 
 EC_CLEANUP:
     if (cwd != -1) {
-        fchdir(cwd);
+        if (fchdir(cwd) < 0) {
+            LOG(log_error, logtype_default, "Can't fchdir(%d): %s", cwd, strerror(errno));
+        }
         close(cwd);
     }
     EC_EXIT;
@@ -435,6 +441,11 @@ static void switch_to_user(char *dir)
 {
     struct stat st;
 
+    if (dir == NULL) {
+        LOG(log_error, logtype_cnid, "switch_to_user: dir is NULL");
+        exit(1);
+    }
+
     if (chdir(dir) < 0) {
         LOG(log_error, logtype_cnid, "chdir to %s failed: %s", dir, strerror(errno));
         exit(1);
@@ -494,22 +505,23 @@ static uid_t uid_from_name(const char *name)
 int main(int argc, char *argv[])
 {
     EC_INIT;
-    int delete_bdb = 0;
     int ctrlfd = -1, clntfd = -1;
     AFPObj obj = { 0 };
     char *volpath = NULL;
     char *username = NULL;
 
-    while (( ret = getopt( argc, argv, ":dF:l:p:t:u:vV")) != -1 ) {
+    while (( ret = getopt( argc, argv, ":F:l:p:t:u:vV")) != -1 ) {
         switch (ret) {
-        case 'd':
-            /* this is now just ignored, as we do it automatically anyway */
-            delete_bdb = 1;
-            break;
         case 'F':
+            if (obj.cmdlineconfigfile) {
+                free((void *)obj.cmdlineconfigfile);
+            }
             obj.cmdlineconfigfile = strdup(optarg);
             break;
         case 'p':
+            if (volpath) {
+                free((void *)volpath);
+            }
             volpath = strdup(optarg);
             break;
         case 'l':
@@ -519,10 +531,22 @@ int main(int argc, char *argv[])
             ctrlfd = atoi(optarg);
             break;
         case 'u':
+            if (username) {
+                free((void *)username);
+            }
             username = strdup(optarg);
             break;
         case 'v':
         case 'V':
+            if (obj.cmdlineconfigfile) {
+                free((void *)obj.cmdlineconfigfile);
+            }
+            if (volpath) {
+                free((void *)volpath);
+            }
+            if (username) {
+                free((void *)username);
+            }
             printf("cnid_dbd (Netatalk %s)\n", VERSION);
             return -1;
         case ':':
@@ -532,6 +556,15 @@ int main(int argc, char *argv[])
 
     if (ctrlfd == -1 || clntfd == -1 || !volpath) {
         LOG(log_error, logtype_cnid, "main: bad IPC fds");
+        if (obj.cmdlineconfigfile) {
+            free((void *)obj.cmdlineconfigfile);
+        }
+        if (volpath) {
+            free((void *)volpath);
+        }
+        if (username) {
+            free((void *)username);
+        }
         exit(EXIT_FAILURE);
     }
 
@@ -592,6 +625,16 @@ close_db:
         ret = -1;
 
 EC_CLEANUP:
+    if (obj.cmdlineconfigfile) {
+        free((void *)obj.cmdlineconfigfile);
+    }
+    if (volpath) {
+        free((void *)volpath);
+    }
+    if (username) {
+        free((void *)username);
+    }
+
     if (ret != 0)
         exit(1);
 
