@@ -132,11 +132,7 @@ error:
  * echo off means password.
  */
 static int PAM_conv (int num_msg,
-#if !defined(__svr4__)
                      const struct pam_message **msg,
-#else
-                     struct pam_message **msg,
-#endif
                      struct pam_response **resp,
                      void *appdata_ptr _U_) {
     int count = 0;
@@ -359,7 +355,7 @@ static int pam_login(void *obj, struct passwd **uam_pwd,
     if ((unsigned long) ibuf & 1) /* pad to even boundary */
         ++ibuf;
 
-    return (login(obj, username, ulen, uam_pwd, ibuf, ibuflen, rbuf, rbuflen));
+    return login(obj, username, ulen, uam_pwd, ibuf, ibuflen, rbuf, rbuflen);
 }
 
 /* ----------------------------- */
@@ -394,7 +390,7 @@ static int pam_login_ext(void *obj, char *uname, struct passwd **uam_pwd,
     memcpy(username, uname +2, len );
     username[ len ] = '\0';
 
-    return (login(obj, username, ulen, uam_pwd, ibuf, ibuflen, rbuf, rbuflen));
+    return login(obj, username, ulen, uam_pwd, ibuf, ibuflen, rbuf, rbuflen);
 }
 
 /* -------------------------------- */
@@ -449,6 +445,7 @@ static int logincont1(void *obj _U_, char *ibuf, size_t ibuflen, char *rbuf, siz
     K_MD5hash = calloc(1, K_hash_len = gcry_md_get_algo_dlen(GCRY_MD_MD5));
     if (K_MD5hash == NULL) {
         ret = AFPERR_MISC;
+        free(K_bin);
         goto error_noctx;
     }
     gcry_md_hash_buffer(GCRY_MD_MD5, K_MD5hash, K_bin, PRIMEBITS/8);
@@ -558,8 +555,15 @@ static int loginasroot(const char *adminauthuser, const char **hostname, int sta
     /* solaris craps out if PAM_TTY and PAM_RHOST aren't set. */
     pam_set_item(pamh, PAM_TTY, "afpd");
     pam_set_item(pamh, PAM_RHOST, *hostname);
-    if ((PAM_error = pam_authenticate(pamh, 0)) != PAM_SUCCESS)
+    if ((PAM_error = pam_authenticate(pamh, 0)) != PAM_SUCCESS) {
+        LOG(log_info, logtype_uams, "DHX2 loginasroot: error authenticating with PAM");
         goto exit;
+    }
+
+    if ((PAM_error = pam_acct_mgmt(pamh, 0)) != PAM_SUCCESS) {
+        LOG(log_info, logtype_uams, "DHX2 loginasroot: error validating PAM account");
+        goto exit;
+    }
 
     LOG(log_warning, logtype_uams, "DHX2: Authenticated as \"%s\"", adminauthuser);
 
@@ -756,13 +760,13 @@ static int changepw_1(void *obj, char *uname,
 
     /* Remember it now, use it in changepw_3 */
     PAM_username = uname;
-    return( dhx2_setup(obj, ibuf, ibuflen, rbuf, rbuflen) );
+    return dhx2_setup(obj, ibuf, ibuflen, rbuf, rbuflen);
 }
 
 static int changepw_2(void *obj,
                       char *ibuf, size_t ibuflen, char *rbuf, size_t *rbuflen)
 {
-    return( logincont1(obj, ibuf, ibuflen, rbuf, rbuflen) );
+    return logincont1(obj, ibuf, ibuflen, rbuf, rbuflen);
 }
 
 static int changepw_3(void *obj _U_,
@@ -856,18 +860,34 @@ static int changepw_3(void *obj _U_,
     uam_afpserver_option(obj, UAM_OPTION_CLIENTNAME, (void *) &hostname, NULL);
     pam_set_item(lpamh, PAM_RHOST, hostname);
     uid = geteuid();
-    seteuid(0);
+    if (seteuid(0) < 0) {
+      LOG(log_error, logtype_uams, "DHX2 Chgpwd: could not seteuid(%i)", 0);
+    }
     PAM_error = pam_authenticate(lpamh,0);
     if (PAM_error != PAM_SUCCESS) {
         LOG(log_info, logtype_uams, "DHX2 Chgpwd: error authenticating with PAM");
-        seteuid(uid);
+        if (seteuid(uid) < 0) {
+            LOG(log_error, logtype_uams, "DHX2 Chgpwd: could not seteuid(%i)", uid);
+        }
+        pam_end(lpamh, PAM_error);
+        ret = AFPERR_NOTAUTH;
+        goto error_ctx;
+    }
+    PAM_error = pam_acct_mgmt(lpamh, 0);
+    if (PAM_error != PAM_SUCCESS) {
+        LOG(log_info, logtype_uams, "DHX2 Chgpwd: error validating PAM account");
+        if (seteuid(uid) < 0) {
+            LOG(log_error, logtype_uams, "DHX2 Chgpwd: could not seteuid(%i)", uid);
+        }
         pam_end(lpamh, PAM_error);
         ret = AFPERR_NOTAUTH;
         goto error_ctx;
     }
     PAM_password = ibuf;
     PAM_error = pam_chauthtok(lpamh, 0);
-    seteuid(uid); /* un-root ourselves. */
+    if (seteuid(uid) < 0) {
+      LOG(log_error, logtype_uams, "DHX2 Chgpwd: could not seteuid(%i)", uid);
+    }
     memset(ibuf, 0, 512);
     if (PAM_error != PAM_SUCCESS) {
         LOG(log_info, logtype_uams, "DHX2 Chgpwd: error changing pw with PAM");
