@@ -66,11 +66,7 @@ static unsigned char *PAM_password;
  * echo off means password.
  */
 static int PAM_conv (int num_msg,
-#if !defined(__svr4__)
                      const struct pam_message **msg,
-#else
-                     struct pam_message **msg,
-#endif
                      struct pam_response **resp,
                      void *appdata_ptr _U_) {
   int count = 0;
@@ -356,7 +352,7 @@ static int pam_login(void *obj, struct passwd **uam_pwd,
     if ((unsigned long) ibuf & 1) /* pad to even boundary */
       ++ibuf;
 
-    return (login(obj, username, ulen, uam_pwd, ibuf, ibuflen, rbuf, rbuflen));
+    return login(obj, username, ulen, uam_pwd, ibuf, ibuflen, rbuf, rbuflen);
 }
 
 /* ----------------------------- */
@@ -392,7 +388,7 @@ static int pam_login_ext(void *obj, char *uname, struct passwd **uam_pwd,
     memcpy(username, uname +2, len );
     username[ len ] = '\0';
 
-    return (login(obj, username, ulen, uam_pwd, ibuf, ibuflen, rbuf, rbuflen));
+    return login(obj, username, ulen, uam_pwd, ibuf, ibuflen, rbuf, rbuflen);
 }
 
 /* -------------------------------- */
@@ -692,10 +688,22 @@ static int pam_changepw(void *obj, unsigned char *username,
 
     /* we might need to do this as root */
     uid = geteuid();
-    seteuid(0);
+    if (seteuid(0) < 0) {
+      LOG(log_error, logtype_uams, "pam_changepw: could not seteuid(%i)", 0);
+    }
     PAM_error = pam_authenticate(lpamh, 0);
     if (PAM_error != PAM_SUCCESS) {
-      seteuid(uid);
+      if (seteuid(uid) < 0) {
+        LOG(log_error, logtype_uams, "pam_changepw: could not seteuid(%i)", uid);
+      }
+      pam_end(lpamh, PAM_error);
+      return AFPERR_NOTAUTH;
+    }
+    PAM_error = pam_acct_mgmt(lpamh, 0);
+    if (PAM_error != PAM_SUCCESS) {
+      if (seteuid(uid) < 0) {
+        LOG(log_error, logtype_uams, "pam_changepw: could not seteuid(%i)", uid);
+      }
       pam_end(lpamh, PAM_error);
       return AFPERR_NOTAUTH;
     }
@@ -711,7 +719,9 @@ static int pam_changepw(void *obj, unsigned char *username,
 
     /* this really does need to be done as root */
     PAM_error = pam_chauthtok(lpamh, 0);
-    seteuid(uid); /* un-root ourselves. */
+    if (seteuid(uid) < 0) {
+      LOG(log_error, logtype_uams, "pam_changepw: could not seteuid(%i)", uid);
+    }
     memset(ibuf, 0, PASSWDLEN);
     if (PAM_error != PAM_SUCCESS) {
       pam_end(lpamh, PAM_error);
