@@ -30,7 +30,6 @@
 
 #include <atalk/afp.h>
 #include <atalk/logger.h>
-#include <atalk/standards.h>
 #include <atalk/uam.h>
 
 #define KEYSIZE 16
@@ -213,13 +212,13 @@ static int passwd_login(void *obj, struct passwd **uam_pwd,
 	return AFPERR_MISC;
 
     if (ibuflen < 2) {
-	return( AFPERR_PARAM );
+	return AFPERR_PARAM;
     }
 
     len = (unsigned char) *ibuf++;
     ibuflen--;
     if (!len || len > ibuflen || len > ulen ) {
-	return( AFPERR_PARAM );
+	return AFPERR_PARAM;
     }
     memcpy(username, ibuf, len );
     ibuf += len;
@@ -230,7 +229,7 @@ static int passwd_login(void *obj, struct passwd **uam_pwd,
 	++ibuf;
 	ibuflen--;
     }
-    return (pwd_login(obj, username, ulen, uam_pwd, ibuf, ibuflen, rbuf, rbuflen));
+    return pwd_login(obj, username, ulen, uam_pwd, ibuf, ibuflen, rbuf, rbuflen);
 
 }
 
@@ -260,11 +259,11 @@ static int passwd_login_ext(void *obj, char *uname, struct passwd **uam_pwd,
     memcpy(&temp16, uname, sizeof(temp16));
     len = ntohs(temp16);
     if (!len || len > ulen ) {
-	return( AFPERR_PARAM );
+	return AFPERR_PARAM;
     }
     memcpy(username, uname +2, len );
     username[ len ] = '\0';
-    return (pwd_login(obj, username, ulen, uam_pwd, ibuf, ibuflen, rbuf, rbuflen));
+    return pwd_login(obj, username, ulen, uam_pwd, ibuf, ibuflen, rbuf, rbuflen);
 }
 
 static int passwd_logincont(void *obj, struct passwd **uam_pwd,
@@ -346,16 +345,20 @@ static int passwd_logincont(void *obj, struct passwd **uam_pwd,
     gcry_mpi_release(bn3);
 
     rbuf[PASSWDLEN] = '\0';
-    p = crypt( rbuf, dhxpwd->pw_passwd );
-    memset(rbuf, 0, PASSWDLEN);
-    if ( strcmp( p, dhxpwd->pw_passwd ) == 0 ) {
-      *uam_pwd = dhxpwd;
-      err = AFP_OK;
+#ifdef HAVE_CRYPT_CHECKPASS
+    if (crypt_checkpass(rbuf, dhxpwd->pw_passwd) == 0) {
+#else
+    p = crypt(rbuf, dhxpwd->pw_passwd);
+    if (strcmp(p, dhxpwd->pw_passwd) == 0) {
+#endif
+        *uam_pwd = dhxpwd;
+        err = AFP_OK;
     }
+    memset(rbuf, 0, PASSWDLEN);
 #ifdef SHADOWPW
     if (( sp = getspnam( dhxpwd->pw_name )) == NULL ) {
 	LOG(log_info, logtype_uams, "no shadow passwd entry for %s", dhxpwd->pw_name);
-	return (AFPERR_NOTAUTH);
+	return AFPERR_NOTAUTH;
     }
 
     /* check for expired password */
