@@ -68,12 +68,6 @@
 #define STRCMP(a,b,c) (strcmp(a,c) b 0)
 #define ZERO_STRUCT(a) memset(&(a), 0, sizeof(a))
 #define ZERO_STRUCTP(a) memset((a), 0, sizeof(a))
-#ifndef MAX
-#define MAX(a,b) ((a) > (b) ? a : b)
-#endif
-#ifndef MIN
-#define MIN(a,b) ((a) < (b) ? a : b)
-#endif
 
 #ifdef WORDS_BIGENDIAN
 #define hton64(x)       (x)
@@ -135,11 +129,7 @@ extern void mod_close    (void *);
 #define mod_open(a)      dlopen(a, RTLD_NOW)
 #endif /* __NetBSD__ */
 
-#ifndef DLSYM_PREPEND_UNDERSCORE
 #define mod_symbol(a, b) dlsym(a, b)
-#else /* ! DLSYM_PREPEND_UNDERSCORE */
-extern void *mod_symbol  (void *, const char *);
-#endif /* ! DLSYM_PREPEND_UNDERSCORE */
 #define mod_error()      dlerror()
 #define mod_close(a)     dlclose(a)
 #endif /* ! HAVE_DLFCN_H */
@@ -212,11 +202,12 @@ extern const char *getcwdpath(void);
 extern const char *fullpathname(const char *);
 extern char *stripped_slashes_basename(char *p);
 extern void randombytes(void *buf, int n);
-extern int daemonize(int nochdir, int noclose);
+extern int daemonize(void);
 extern int run_cmd(const char *cmd, char **cmd_argv);
 extern char *realpath_safe(const char *path);
 extern const char *basename_safe(const char *path);
 extern char *strtok_quote (char *s, const char *delim);
+extern const char *tmpdir(void);
 
 extern int ochdir(const char *dir, int options);
 extern int ostat(const char *path, struct stat *buf, int options);
