@@ -308,7 +308,7 @@ static int ad_flush_hf(struct adouble *ad)
             if (adf_pwrite(ad->ad_mdp, ad->ad_data, len, 0) != len) {
                 if (errno == 0)
                     errno = EIO;
-                return( -1 );
+                return -1;
             }
             break;
         case AD_VERSION_EA:
@@ -399,7 +399,7 @@ static int ad_flush_rf(struct adouble *ad)
 
     LOG(log_debug, logtype_ad, "ad_flush_rf(%s)", adflags2logstr(ad->ad_adflags));
 
-    if ((ad->ad_rfp->adf_flags & O_RDWR)) {
+    if (ad->ad_rfp->adf_flags & O_RDWR) {
         if (ad_getentryoff(ad, ADEID_RFORK)) {
             if (ad->ad_rlen > 0xffffffff)
                 ad_setentrylen(ad, ADEID_RFORK, 0xffffffff);
