@@ -298,8 +298,16 @@ int i;
 		return NULL;
 	}
 
-	if (len > 0) bstr__memcpy (b->data, blk, (size_t) len);
-	b->data[len] = (unsigned char) '\0';
+	if (len > 0) {
+		bstr__memcpy (b->data, blk, (size_t) len);
+	}
+
+	if (b->mlen > len) {
+		b->data[len] = (unsigned char) '\0';
+	} else {
+		bstr__free (b);
+		return NULL;
+	}
 
 	return b;
 }
@@ -1068,11 +1076,12 @@ int bdelete (bstring b, int pos, int len) {
  *  been bdestroyed is undefined.
  */
 int bdestroy (bstring b) {
-	if (b == NULL || b->slen < 0 || b->mlen <= 0 || b->mlen < b->slen ||
-	    b->data == NULL)
+	if (b == NULL) {
 		return BSTR_ERR;
-
-	bstr__free (b->data);
+	}
+	if (b->data != NULL) {
+		bstr__free (b->data);
+	}
 
 	/* In case there is any stale usage, there is one more chance to
 	   notice this error. */
@@ -1964,7 +1973,7 @@ int c, d, e;
 	return d == 0 && c < 0;
 }
 
-/*  int bgetsa (bstring b, bNgetc getcPtr, void * parm, char terminator)
+/*  int bgetstreama (bstring b, bNgetc getcPtr, void * parm, char terminator)
  *
  *  Use an fgetc-like single character stream reading function (getcPtr) to
  *  obtain a sequence of characters which are concatenated to the end of the
@@ -1977,7 +1986,7 @@ int c, d, e;
  *  an empty partial result, 1 is returned.  If no characters are read, or
  *  there is some other detectable error, BSTR_ERR is returned.
  */
-int bgetsa (bstring b, bNgetc getcPtr, void * parm, char terminator) {
+int bgetstreama (bstring b, bNgetc getcPtr, void * parm, char terminator) {
 int c, d, e;
 
 	if (b == NULL || b->mlen <= 0 || b->slen < 0 || b->mlen < b->slen ||
@@ -2016,7 +2025,7 @@ int c, d, e;
 bstring bgetstream (bNgetc getcPtr, void * parm, char terminator) {
 bstring buff;
 
-	if (0 > bgetsa (buff = bfromcstr (""), getcPtr, parm, terminator) ||
+	if (0 > bgetstreama (buff = bfromcstr (""), getcPtr, parm, terminator) ||
 	    0 >= buff->slen) {
 		bdestroy (buff);
 		buff = NULL;
@@ -2432,7 +2441,7 @@ int i, c, v;
  *  NULL is returned, otherwise a bstring with the correct result is returned.
  */
 bstring bjoin (const struct bstrList * bl, const_bstring sep) {
-	if (sep != NULL && (sep->slen < 0 || sep->data == NULL)) return NULL;
+	if (sep == NULL || sep->slen < 0 || sep->data == NULL) return NULL;
 	return bjoinblk (bl, sep->data, sep->slen);
 }
 
@@ -2543,6 +2552,7 @@ int i, p, ret;
 			}
 			buff->slen = 0;
 		}
+		bdestroy (buff);
 		return BSTR_OK;
 	} else {
 		ret = p = i = 0;
