@@ -13,11 +13,7 @@
 #include <arpa/inet.h>
 #include <errno.h>
 #include <net/if.h>
-
-#ifdef HAVE_NETDB_H
 #include <netdb.h>
-#endif /* HAVE_NETDB_H */
-
 #include <netinet/in.h>
 #include <netinet/tcp.h>
 #include <signal.h>
@@ -31,8 +27,6 @@
 #include <sys/types.h>
 #include <unistd.h>
 
-
-
 #include <atalk/logger.h>
 
 #ifdef __svr4__
@@ -451,7 +445,11 @@ int dsi_tcp_init(DSI *dsi, const char *hostname, const char *inaddress, const ch
 
     if (!address) {
         hints.ai_flags |= AI_PASSIVE;
+#if defined(__OpenBSD__) /* no IPv4/v6 dual stack on OpenBSD */
+        hints.ai_family = AF_UNSPEC;
+#else
         hints.ai_family = AF_INET6;
+#endif
     } else {
         hints.ai_flags |= AI_NUMERICHOST;
         hints.ai_family = AF_UNSPEC;
