@@ -135,7 +135,7 @@ charset_t add_charset(const char* name)
 
     for (c1=0; c1<=max_charset_t;c1++) {
         if ( strcasecmp(name, charset_name(c1)) == 0)
-            return (c1);
+            return c1;
     }
 
     if ( cur_charset_t >= MAX_CHARSETS )  {
@@ -169,7 +169,7 @@ charset_t add_charset(const char* name)
     max_charset_t++;
 
     LOG(log_debug9, logtype_default, "Added charset %s with handle %u", name, cur_charset_t);
-    return (cur_charset_t);
+    return cur_charset_t;
 }
 
 /**
@@ -221,7 +221,7 @@ static size_t add_null(charset_t to, char *buf, size_t bytesleft, size_t len)
         buf[len]   = 0;
     else {
         errno = E2BIG;
-        return (size_t)(-1);
+        return (size_t) -1;
     }
 
     return len;
@@ -283,7 +283,7 @@ static size_t convert_string_internal(charset_t from, charset_t to,
             break;
         }
         LOG(log_debug, logtype_default,"Conversion error: %s",reason);
-        return (size_t)-1;
+        return (size_t) -1;
     }
 
     /* Terminate the string */
@@ -312,11 +312,11 @@ size_t convert_string(charset_t from, charset_t to,
     u = buffer2;
     if (charsets[to] && (charsets[to]->flags & CHARSET_DECOMPOSED) ) {
         if ( (size_t)-1 == (i_len = decompose_w(buffer, o_len, u, &i_len)) )
-            return (size_t)-1;
+            return (size_t) -1;
     }
     else if (!charsets[from] || (charsets[from]->flags & CHARSET_DECOMPOSED)) {
         if ( (size_t)-1 == (i_len = precompose_w(buffer, o_len, u, &i_len)) )
-            return (size_t)-1;
+            return (size_t) -1;
     }
     else {
         u = buffer;
@@ -355,7 +355,7 @@ static size_t convert_string_allocate_internal(charset_t from, charset_t to,
     *dest = NULL;
 
     if (src == NULL || srclen == (size_t)-1)
-        return (size_t)-1;
+        return (size_t) -1;
 
     lazy_initialize_conv();
 
@@ -374,7 +374,7 @@ convert:
     if (!outbuf) {
         LOG(log_debug, logtype_default,"convert_string_allocate: realloc failed!");
         SAFE_FREE(ob);
-        return (size_t)-1;
+        return (size_t) -1;
     } else {
         ob = outbuf;
     }
@@ -398,7 +398,7 @@ convert:
         }
         LOG(log_debug, logtype_default,"Conversion error: %s(%s)",reason,inbuf);
         SAFE_FREE(ob);
-        return (size_t)-1;
+        return (size_t) -1;
     }
 
 
@@ -421,7 +421,7 @@ convert:
     if (destlen && !*dest) {
         LOG(log_debug, logtype_default, "convert_string_allocate: out of memory!");
         SAFE_FREE(ob);
-        return (size_t)-1;
+        return (size_t) -1;
     }
 
     return destlen;
@@ -451,11 +451,11 @@ size_t convert_string_allocate(charset_t from, charset_t to,
     u = buffer2;
     if (charsets[to] && (charsets[to]->flags & CHARSET_DECOMPOSED) ) {
         if ( (size_t)-1 == (i_len = decompose_w(buffer, o_len, u, &i_len)) )
-            return (size_t)-1;
+            return (size_t) -1;
     }
     else if ( !charsets[from] || (charsets[from]->flags & CHARSET_DECOMPOSED) ) {
         if ( (size_t)-1 == (i_len = precompose_w(buffer, o_len, u, &i_len)) )
-            return (size_t)-1;
+            return (size_t) -1;
     }
     else {
         u = buffer;
@@ -617,16 +617,16 @@ size_t charset_precompose ( charset_t ch, char * src, size_t inlen, char * dst,
 
     if ( (size_t)-1 == (ilen = precompose_w((ucs2_t *)buffer, len, u, &ilen)) ) {
         free (buffer);
-        return (size_t)(-1);
+        return (size_t) -1;
     }
 
     if ((size_t)(-1) == (len = convert_string_internal( CH_UCS2, ch, (char*)u, ilen, dst, outlen)) ) {
         free (buffer);
-        return (size_t)(-1);
+        return (size_t) -1;
     }
 
     free(buffer);
-    return (len);
+    return len;
 }
 
 size_t charset_decompose ( charset_t ch, char * src, size_t inlen, char * dst, size_t outlen)
@@ -643,16 +643,16 @@ size_t charset_decompose ( charset_t ch, char * src, size_t inlen, char * dst, s
 
     if ( (size_t)-1 == (ilen = decompose_w((ucs2_t *)buffer, len, u, &ilen)) ) {
         free (buffer);
-        return (size_t)(-1);
+        return (size_t) -1;
     }
 
     if ((size_t)(-1) == (len = convert_string_internal( CH_UCS2, ch, (char*)u, ilen, dst, outlen)) ) {
         free (buffer);
-        return (size_t)(-1);
+        return (size_t) -1;
     }
 
     free(buffer);
-    return (len);
+    return len;
 }
 
 size_t utf8_precompose ( char * src, size_t inlen, char * dst, size_t outlen)
@@ -709,7 +709,7 @@ static size_t pull_charset_flags (charset_t from_set, charset_t to_set, charset_
     char* outbuf = dest;
     atalk_iconv_t descriptor;
     atalk_iconv_t descriptor_cap;
-    char escch;                 /* 150210: uninitialized OK, depends on j */
+    char escch = 0;
 
     if (srclen == (size_t)-1)
         srclen = strlen(src) + 1;
@@ -719,7 +719,7 @@ static size_t pull_charset_flags (charset_t from_set, charset_t to_set, charset_
 
     if (descriptor == (atalk_iconv_t)-1 || descriptor == (atalk_iconv_t)0) {
         errno = EINVAL;
-        return (size_t)-1;
+        return (size_t) -1;
     }
 
     i_len=srclen;
@@ -756,11 +756,11 @@ static size_t pull_charset_flags (charset_t from_set, charset_t to_set, charset_
             atalk_iconv(descriptor, &inbuf, &i_len, &outbuf, &o_len) == (size_t)-1) {
             if (errno == EILSEQ || errno == EINVAL) {
                 errno = EILSEQ;
-                if ((option & CONV_IGNORE)) {
+                if (option & CONV_IGNORE) {
                     *flags |= CONV_REQMANGLE;
                     return destlen - o_len;
                 }
-                if ((option & CONV__EILSEQ)) {
+                if (option & CONV__EILSEQ) {
                     if (o_len < 2) {
                         errno = E2BIG;
                         goto end;
@@ -782,7 +782,7 @@ static size_t pull_charset_flags (charset_t from_set, charset_t to_set, charset_
             i_len = j, j = 0;
 
             if (escch == ':') {
-                if ((option & CONV_UNESCAPEHEX)) {
+                if (option & CONV_UNESCAPEHEX) {
                     /* treat it as a CAP hex encoded char */
                     char h[MAXPATHLEN];
                     size_t hlen = 0;
@@ -807,7 +807,7 @@ static size_t pull_charset_flags (charset_t from_set, charset_t to_set, charset_
                     } else {
                         /* We have an invalid :xx sequence */
                         errno = EILSEQ;
-                        if ((option & CONV_IGNORE)) {
+                        if (option & CONV_IGNORE) {
                             *flags |= CONV_REQMANGLE;
                             return destlen - o_len;
                         }
@@ -928,11 +928,11 @@ static size_t push_charset_flags (charset_t to_set, charset_t cap_set, char* src
         while (i_len > 0 &&
                atalk_iconv(descriptor, &inbuf, &i_len, &outbuf, &o_len) == (size_t)-1) {
             if (errno == EILSEQ) {
-                if ((option & CONV_IGNORE)) {
+                if (option & CONV_IGNORE) {
                     *flags |= CONV_REQMANGLE;
                     return destlen - o_len;
                 }
-                if ((option & CONV_ESCAPEHEX)) {
+                if (option & CONV_ESCAPEHEX) {
                     const size_t bufsiz = o_len / 3 + 1;
                     char *buf = malloc(bufsiz);
                     size_t buflen;
@@ -994,9 +994,10 @@ size_t convert_charset ( charset_t from_set, charset_t to_set, charset_t cap_cha
     lazy_initialize_conv();
 
     /* convert from_set to UCS2 */
+    errno = 0;
     if ((size_t)(-1) == ( o_len = pull_charset_flags( from_set, to_set, cap_charset, src, src_len,
                                                       (char *) buffer, sizeof(buffer) -2, flags)) ) {
-        LOG(log_error, logtype_default, "Conversion failed ( %s to CH_UCS2 )", charset_name(from_set));
+        LOG(log_error, logtype_default, "Conversion failed ( %s to CH_UCS2 ), errno %i, %s", charset_name(from_set), errno, src);
         return (size_t) -1;
     }
 
@@ -1008,11 +1009,11 @@ size_t convert_charset ( charset_t from_set, charset_t to_set, charset_t cap_cha
     u = buffer2;
     if (CHECK_FLAGS(flags, CONV_DECOMPOSE) || (charsets[to_set] && (charsets[to_set]->flags & CHARSET_DECOMPOSED)) ) {
         if ( (size_t)-1 == (i_len = decompose_w(buffer, o_len, u, &i_len)) )
-            return (size_t)(-1);
+            return (size_t) -1;
     }
     else if (CHECK_FLAGS(flags, CONV_PRECOMPOSE) || !charsets[from_set] || (charsets[from_set]->flags & CHARSET_DECOMPOSED)) {
         if ( (size_t)-1 == (i_len = precompose_w(buffer, o_len, u, &i_len)) )
-            return (size_t)(-1);
+            return (size_t) -1;
     }
     else {
         u = buffer;
