@@ -45,6 +45,7 @@
 #include <atalk/byteorder.h>
 #include <atalk/logger.h>
 #include <atalk/unicode.h>
+#include <atalk/util.h>
 
 /**
  * @file
@@ -160,11 +161,11 @@ int atalk_register_charset(struct charset_functions *funcs)
 static void lazy_initialize_iconv(void)
 {
 	static int initialized = 0;
-	int i;
+	int charset_count = 2;
 
 	if (!initialized) {
 		initialized = 1;
-		for(i = 0; builtin_functions[i].name; i++)
+		for(int i = 0; i < charset_count && builtin_functions[i].name; i++)
 			atalk_register_charset(&builtin_functions[i]);
 
 		/* register additional charsets */
