@@ -37,14 +37,13 @@
 #include <stdlib.h>
 #include <string.h>
 
-#if HAVE_SYS_PARAM_H
-# include <sys/param.h>
-#endif
-
+#include <sys/param.h>
 #include <sys/stat.h>
 #include <unistd.h>
 
 #include <atalk/ftw.h>
+#include <atalk/globals.h>
+#include <atalk/util.h>
 
 #ifndef HAVE_MEMPCPY
 #define mempcpy(D, S, N) ((void *) ((char *) memcpy (D, S, N) + (N)))
@@ -78,8 +77,6 @@
 # define internal_function /* empty */
 # undef dirent64
 # define dirent64 dirent
-# undef MAX
-# define MAX(a, b) ((a) > (b) ? (a) : (b))
 #endif
 
 #ifndef __set_errno
@@ -205,7 +202,7 @@ static void mytdestroy (void *vroot, __free_fn_t freefct)
 static char *mystpcpy(char *a, const char *b)
 {
     strcpy(a, b);
-    return (a + strlen(a));
+    return a + strlen(a);
 }
 
 static char *xgetcwd(void)
@@ -292,15 +289,38 @@ open_dir_stream (int *dfdp, struct ftw_data *data, struct dir_data *dirp)
             DIR *st = data->dirstreams[data->actdir]->stream;
             struct dirent64 *d;
             size_t actsize = 0;
+            const size_t MAX_BUFFER_SIZE = 1024 * 1024; /* 1MB buffer limit */
 
             while ((d = __readdir64 (st)) != NULL)
             {
                 size_t this_len = NAMLEN (d);
-                if (actsize + this_len + 2 >= bufsize)
+                if (this_len > UTF8FILELEN_EARLY) {
+                    this_len = UTF8FILELEN_EARLY;
+                }
+
+                /* Check if we need more space with overflow protection */
+                if (actsize > bufsize - this_len - 2)
                 {
+                    size_t new_bufsize;
                     char *newp;
-                    bufsize += MAX (1024, 2 * this_len);
-                    newp = (char *) realloc (buf, bufsize);
+
+                    /* Protection against overflow in size calculation */
+                    if (bufsize > MAX_BUFFER_SIZE / 2) {
+                        new_bufsize = MAX_BUFFER_SIZE;
+                    } else {
+                        new_bufsize = bufsize + MIN(MAX(1024, 2 * this_len),
+                                                   MAX_BUFFER_SIZE - bufsize);
+                    }
+
+                    if (new_bufsize > MAX_BUFFER_SIZE) {
+                        new_bufsize = MAX_BUFFER_SIZE;
+                    }
+
+                    if (actsize > new_bufsize - this_len - 2) {
+                        continue;
+                    }
+
+                    newp = (char *) realloc (buf, new_bufsize);
                     if (newp == NULL)
                     {
                         /* No more memory.  */
@@ -310,23 +330,38 @@ open_dir_stream (int *dfdp, struct ftw_data *data, struct dir_data *dirp)
                         return -1;
                     }
                     buf = newp;
+                    bufsize = new_bufsize;
                 }
 
-                *((char *) __mempcpy (buf + actsize, d->d_name, this_len))
-                    = '\0';
-                actsize += this_len + 1;
+                /* Consistent boundary check that accounts for NULL terminator */
+                if (actsize <= bufsize - this_len - 1) {
+                    *((char *) __mempcpy (buf + actsize, d->d_name, this_len)) = '\0';
+                    actsize += this_len + 1;
+                }
             }
 
-            /* Terminate the list with an additional NUL byte.  */
-            buf[actsize++] = '\0';
+            /* Terminate the list with an additional NULL byte.  */
+            if (actsize < bufsize) {
+                buf[actsize++] = '\0';
+
+                /* Shrink the buffer to what we actually need.  */
+                char *new_buf = malloc(actsize);
+                if (new_buf != NULL) {
+                    memcpy(new_buf, buf, actsize);
+                    free(buf);
+                    data->dirstreams[data->actdir]->content = new_buf;
+                } else {
+                    data->dirstreams[data->actdir]->content = NULL;
+                    free(buf);
+                    result = -1;
+                }
+            } else {
+                free(buf);
+                result = -1;
+            }
 
-            /* Shrink the buffer to what we actually need.  */
-            data->dirstreams[data->actdir]->content = realloc (buf, actsize);
             if (data->dirstreams[data->actdir]->content == NULL)
             {
-                int save_err = errno;
-                free (buf);
-                __set_errno (save_err);
                 result = -1;
             }
             else
