@@ -107,12 +107,12 @@ EC_CLEANUP:
 /*!
  * Daemonize
  *
- * Fork, exit parent, setsid(), optionally chdir("/"), optionally close all fds
+ * Fork, exit parent, setsid(), chdir("/"), close all fds
  *
  * returns -1 on failure, but you can't do much except exit in that case
  * since we may already have forked
  */
-int daemonize(int nochdir, int noclose)
+int daemonize(void)
 {
     switch (fork()) {
     case 0:
@@ -135,16 +135,16 @@ int daemonize(int nochdir, int noclose)
         _exit(0);
     }
 
-    if (!nochdir)
-        chdir("/");
-
-    if (!noclose) {
-        closeall(0);
-        open("/dev/null",O_RDWR);
-        dup(0);
-        dup(0);
+    if (chdir("/") < 0) {
+        LOG(log_error, logtype_default, "Can't chdir(/): %s", strerror(errno));
+        return -1;
     }
 
+    closeall(0);
+    open("/dev/null",O_RDWR);
+    dup(0);
+    dup(0);
+
     return 0;
 }
 
@@ -226,7 +226,108 @@ char *stripped_slashes_basename(char *p)
     int i = strlen(p) - 1;
     while (i > 0 && p[i] == '/')
         p[i--] = 0;
-    return (strrchr(p, '/') ? strrchr(p, '/') + 1 : p);
+    return strrchr(p, '/') ? strrchr(p, '/') + 1 : p;
+}
+
+/****************************************************************************
+ * Find a suitable temporary directory for Netatalk.
+ * Creates a subdirectory for current gid if it doesn't exist.
+ * The result should be copied immediately
+ * as it may be overwritten by a subsequent call.
+ ****************************************************************************/
+
+const char *tmpdir(void)
+{
+    static char netatalk_tmpdir[MAXPATHLEN + 1];
+    char *systmp;
+    struct stat st;
+    mode_t oldmask;
+    int tmpfd, dirfd;
+    char dirname[64];
+
+    if ((systmp = getenv("TMPDIR")))
+        ;
+    else
+        systmp = "/tmp";
+
+    if ((tmpfd = open(systmp, O_RDONLY | O_DIRECTORY)) == -1) {
+        LOG(log_error, logtype_default, "tmpdir: cannot open %s: %s",
+            systmp, strerror(errno));
+        return systmp;
+    }
+
+    snprintf(dirname, sizeof(dirname), "netatalk-%u", getpid());
+    snprintf(netatalk_tmpdir, MAXPATHLEN, "%s/%s", systmp, dirname);
+
+    oldmask = umask(0077);
+
+    if (mkdirat(tmpfd, dirname, 0700) != 0) {
+        if (errno != EEXIST) {
+            LOG(log_error, logtype_default, "tmpdir: failed to create %s: %s",
+                netatalk_tmpdir, strerror(errno));
+            umask(oldmask);
+            close(tmpfd);
+            return systmp;
+        }
+    } else {
+        LOG(log_debug, logtype_default, "tmpdir: created directory %s", netatalk_tmpdir);
+        umask(oldmask);
+        close(tmpfd);
+        return netatalk_tmpdir;
+    }
+
+    if (fstatat(tmpfd, dirname, &st, 0) != 0) {
+        LOG(log_error, logtype_default, "tmpdir: error accessing %s: %s",
+            netatalk_tmpdir, strerror(errno));
+        umask(oldmask);
+        close(tmpfd);
+        return systmp;
+    }
+
+    umask(oldmask);
+
+    if ((dirfd = openat(tmpfd, dirname, O_RDONLY | O_DIRECTORY)) == -1) {
+        LOG(log_error, logtype_default, "tmpdir: cannot open %s: %s",
+            netatalk_tmpdir, strerror(errno));
+        close(tmpfd);
+        return systmp;
+    }
+
+    if (fstat(dirfd, &st) != 0) {
+        LOG(log_error, logtype_default, "tmpdir: fstat failed on %s: %s",
+            netatalk_tmpdir, strerror(errno));
+        close(dirfd);
+        close(tmpfd);
+        return systmp;
+    }
+
+    if (!S_ISDIR(st.st_mode)) {
+        LOG(log_error, logtype_default, "tmpdir: %s exists but is not a directory",
+            netatalk_tmpdir);
+        close(dirfd);
+        close(tmpfd);
+        return systmp;
+    }
+
+    if ((st.st_mode & 0777) != 0700) {
+        LOG(log_warning, logtype_default, "tmpdir: fixing permissions on %s", netatalk_tmpdir);
+        if (fchmod(dirfd, 0700) != 0) {
+            LOG(log_error, logtype_default, "tmpdir: failed to chmod %s: %s",
+                netatalk_tmpdir, strerror(errno));
+        }
+    }
+
+    if (st.st_uid != getuid()) {
+        LOG(log_warning, logtype_default, "tmpdir: %s not owned by current user",
+            netatalk_tmpdir);
+        close(dirfd);
+        close(tmpfd);
+        return systmp;
+    }
+
+    close(dirfd);
+    close(tmpfd);
+    return netatalk_tmpdir;
 }
 
 /*********************************************************************************
@@ -292,24 +393,17 @@ int ochmod(char *path, mode_t mode, const struct stat *st, int options)
 /*
  * @brief ostat/fsstatat multiplexer
  *
- * ostatat mulitplexes ostat and fstatat. If we don't HAVE_ATFUNCS, dirfd is ignored.
+ * ostatat mulitplexes ostat and fstatat.
  *
- * @param dirfd   (r) Only used if HAVE_ATFUNCS, ignored else, -1 gives AT_FDCWD
+ * @param dirfd   (r) -1 gives AT_FDCWD
  * @param path    (r) pathname
  * @param st      (rw) pointer to struct stat
  */
 int ostatat(int dirfd _U_, const char *path, struct stat *st, int options)
 {
-#ifdef HAVE_ATFUNCS
     if (dirfd == -1)
         dirfd = AT_FDCWD;
     return fstatat(dirfd, path, st, (options & O_NOFOLLOW) ? AT_SYMLINK_NOFOLLOW : 0);
-#else
-    return ostat(path, st, options);
-#endif
-
-    /* DEADC0DE */
-    return -1;
 }
 
 /*!
@@ -426,10 +520,10 @@ int gmem(gid_t gid, int ngroups, gid_t *groups)
 
     for ( i = 0; i < ngroups; i++ ) {
         if ( groups[ i ] == gid ) {
-            return( 1 );
+            return 1;
         }
     }
-    return( 0 );
+    return 0;
 }
 
 /*
@@ -487,10 +581,16 @@ char *strtok_quote(char *s, const char *delim)
     if (s == NULL)
         s = olds;
 
+    /* Return NULL if no string to parse */
+    if (s == NULL)
+        return NULL;
+
     /* Scan leading delimiters.  */
     s += strspn (s, delim);
-    if (*s == '\0')
+    if (*s == '\0') {
+        olds = NULL;
         return NULL;
+    }
 
     /* Find the end of the token.  */
     token = s;
