@@ -16,26 +16,26 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
 
-#include <unistd.h>
-#include <stdint.h>
+#include <arpa/inet.h>
+#include <dirent.h>
 #include <errno.h>
+#include <fcntl.h>
+#include <stdint.h>
 #include <stdlib.h>
 #include <string.h>
-#include <sys/types.h>
 #include <sys/stat.h>
-#include <fcntl.h>
-#include <dirent.h>
-#include <arpa/inet.h>
+#include <sys/types.h>
+#include <unistd.h>
 
 #include <atalk/adouble.h>
-#include <atalk/ea.h>
 #include <atalk/afp.h>
-#include <atalk/logger.h>
-#include <atalk/volume.h>
-#include <atalk/vfs.h>
-#include <atalk/util.h>
-#include <atalk/unix.h>
 #include <atalk/compat.h>
+#include <atalk/ea.h>
+#include <atalk/logger.h>
+#include <atalk/unix.h>
+#include <atalk/util.h>
+#include <atalk/vfs.h>
+#include <atalk/volume.h>
 
 /*
  * Store Extended Attributes inside .AppleDouble folders as follows:
@@ -47,7 +47,7 @@
  * - store EAs in files "fileWithEAs::EA::testEA1" and "fileWithEAs::EA::testEA2"
  */
 
-/* 
+/*
  * Build mode for EA header from file mode
  */
 static inline mode_t ea_header_mode(mode_t mode)
@@ -59,7 +59,7 @@ static inline mode_t ea_header_mode(mode_t mode)
     return mode;
 }
 
-/* 
+/*
  * Build mode for EA file from file mode
  */
 static inline mode_t ea_mode(mode_t mode)
@@ -85,7 +85,7 @@ static char *mtoupath(const struct vol *vol, const char *mpath)
         return NULL;
 
     if ( *mpath == '\0' ) {
-        return( "." );
+        return ".";
     }
 
     m = mpath;
@@ -101,7 +101,7 @@ static char *mtoupath(const struct vol *vol, const char *mpath)
         return NULL;
     }
 
-    return( upath );
+    return upath;
 }
 
 
@@ -276,7 +276,7 @@ static int pack_header(struct ea * restrict ea)
 
     LOG(log_debug, logtype_afpd, "pack_header('%s'): ea_count: %u, ea_size: %u",
         ea->filename, ea->ea_count, ea->ea_size);
-    
+
     return 0;
 }
 
@@ -457,8 +457,8 @@ static int write_ea(const struct ea * restrict ea,
                     const char * restrict ibuf,
                     size_t attrsize)
 {
-    int fd = -1, ret = AFP_OK;
-    struct stat st;
+    int fd = -1;
+    int ret = AFP_OK;
     char *eaname;
 
     if ((eaname = ea_path(ea, attruname, 1)) == NULL) {
@@ -468,37 +468,33 @@ static int write_ea(const struct ea * restrict ea,
 
     LOG(log_maxdebug, logtype_afpd, "write_ea('%s')", eaname);
 
-    /* Check if it exists, remove if yes*/
-    if ((stat(eaname, &st)) == 0) {
-        if ((unlink(eaname)) != 0) {
-            if (errno == EACCES)
-                return AFPERR_ACCESS;
-            else
-                return AFPERR_MISC;
-        }
+    if ((fd = open(eaname, O_RDWR | O_CREAT, 0666 & ~ea->vol->v_umask)) == -1) {
+        LOG(log_error, logtype_afpd, "write_ea: open error: %s", eaname);
+        return AFPERR_MISC;
     }
 
-    if ((fd = open(eaname, O_RDWR | O_CREAT | O_EXCL, 0666 & ~ea->vol->v_umask)) == -1) {
-        LOG(log_error, logtype_afpd, "write_ea: open race condition: %s", eaname);
-        return -1;
-    }
-
-    /* lock it */
     if ((write_lock(fd, 0, SEEK_SET, 0)) != 0) {
-        LOG(log_error, logtype_afpd, "write_ea: open race condition: %s", eaname);
-        ret = -1;
+        LOG(log_error, logtype_afpd, "write_ea: lock error: %s", eaname);
+        ret = AFPERR_MISC;
+        goto exit;
+    }
+
+    if (ftruncate(fd, 0) == -1) {
+        LOG(log_error, logtype_afpd, "write_ea('%s'): ftruncate: %s", eaname, strerror(errno));
+        ret = AFPERR_MISC;
         goto exit;
     }
 
     if (write(fd, ibuf, attrsize) != (ssize_t)attrsize) {
         LOG(log_error, logtype_afpd, "write_ea('%s'): write: %s", eaname, strerror(errno));
-        ret = -1;
+        ret = AFPERR_MISC;
         goto exit;
     }
 
 exit:
-    if (fd != -1)
+    if (fd != -1) {
         close(fd); /* and unlock */
+    }
     return ret;
 }
 
@@ -535,11 +531,10 @@ static int ea_delentry(struct ea * restrict ea, const char * restrict attruname)
         /* search matching EA */
         if ((*ea->ea_entries)[count].ea_name &&
             strcmp(attruname, (*ea->ea_entries)[count].ea_name) == 0) {
-            free((*ea->ea_entries)[count].ea_name);
-            (*ea->ea_entries)[count].ea_name = NULL;
-
             LOG(log_debug, logtype_afpd, "ea_delentry('%s'): deleted no %u/%u",
                 attruname, count + 1, ea->ea_count);
+            free((*ea->ea_entries)[count].ea_name);
+            (*ea->ea_entries)[count].ea_name = NULL;
 
             break;
         }
@@ -668,7 +663,7 @@ int ea_open(const struct vol * restrict vol,
     struct stat st;
 
     /* Enforce usage rules! */
-    if ( ! (eaflags & (EA_RDONLY | EA_RDWR))) {
+    if (!(eaflags & (EA_RDONLY | EA_RDWR))) {
         LOG(log_error, logtype_afpd, "ea_open: called without EA_RDONLY | EA_RDWR", uname);
         return -1;
     }
@@ -680,11 +675,11 @@ int ea_open(const struct vol * restrict vol,
     ea->ea_flags = eaflags;
     ea->dirfd = -1;             /* no *at (cf openat) semantics by default */
 
-    /* Dont care for errors, e.g. when removing the file is already gone */
+    /* Don't care for errors, e.g. when removing the file is already gone */
     if (!stat(uname, &st) && S_ISDIR(st.st_mode))
-        ea->ea_flags |=  EA_DIR;
+        ea->ea_flags |= EA_DIR;
 
-    if ( ! (ea->filename = strdup(uname))) {
+    if (!(ea->filename = strdup(uname))) {
         LOG(log_error, logtype_afpd, "ea_open: OOM");
         return -1;
     }
@@ -692,94 +687,83 @@ int ea_open(const struct vol * restrict vol,
     eaname = ea_path(ea, NULL, 0);
     LOG(log_maxdebug, logtype_afpd, "ea_open: ea_path: %s", eaname);
 
-    /* Check if it exists, if not create it if EA_CREATE is in eaflags */
-    if ((stat(eaname, &st)) != 0) {
-        if (errno == ENOENT) {
+    /* Open the file, create if it doesn't exist and EA_CREATE is in eaflags */
+    int open_flags = (ea->ea_flags & EA_RDWR) ? O_RDWR : O_RDONLY;
+    if (eaflags & EA_CREATE) {
+        open_flags |= O_CREAT;
+    }
 
-            /* It doesnt exist */
-
-            if ( ! (eaflags & EA_CREATE)) {
-                /* creation was not requested, so return with error */
-                ret = -2;
-                goto exit;
-            }
-
-            /* Now create a header file */
-
-            /* malloc buffer for minimal on disk data */
-            ea->ea_data = malloc(EA_HEADER_SIZE);
-            if (! ea->ea_data) {
-                LOG(log_error, logtype_afpd, "ea_open: OOM");
-                ret = -1;
-                goto exit;
-            }
-
-            /* create it */
-            ea->ea_fd = create_ea_header(eaname, ea);
-            if (ea->ea_fd == -1) {
-                ret = -1;
-                goto exit;
-            }
-
-            return 0;
-
-        } else {/* errno != ENOENT */
+    ea->ea_fd = open(eaname, open_flags, 0666 & ~ea->vol->v_umask);
+    if (ea->ea_fd == -1) {
+        if (errno == ENOENT && !(eaflags & EA_CREATE)) {
+            ret = -2;
+        } else {
+            LOG(log_error, logtype_afpd, "ea_open('%s'): error: %s", eaname, strerror(errno));
             ret = -1;
-            goto exit;
         }
-    }
-
-    /* header file exists, so read and parse it */
-
-    /* malloc buffer where we read disk file into */
-    if (st.st_size < EA_HEADER_SIZE) {
-        LOG(log_error, logtype_afpd, "ea_open('%s'): bogus EA header file", eaname);
-        ret = -1;
-        goto exit;
-    }
-    ea->ea_size = st.st_size;
-    ea->ea_data = malloc(st.st_size);
-    if (! ea->ea_data) {
-        LOG(log_error, logtype_afpd, "ea_open: OOM");
-        ret = -1;
         goto exit;
     }
 
-    /* Now lock, open and read header file from disk */
-    if ((ea->ea_fd = open(eaname, (ea->ea_flags & EA_RDWR) ? O_RDWR : O_RDONLY)) == -1) {
-        LOG(log_error, logtype_afpd, "ea_open('%s'): error: %s", eaname, strerror(errno));
-        ret = -1;
-        goto exit;
-    }
-
-    /* lock it */
+    /* Lock the file */
     if (ea->ea_flags & EA_RDONLY) {
         /* read lock */
         if ((read_lock(ea->ea_fd, 0, SEEK_SET, 0)) != 0) {
-            LOG(log_error, logtype_afpd, "ea_open: lock error on  header: %s", eaname);
+            LOG(log_error, logtype_afpd, "ea_open: lock error on header: %s", eaname);
             ret = -1;
             goto exit;
         }
     } else {  /* EA_RDWR */
         /* write lock */
         if ((write_lock(ea->ea_fd, 0, SEEK_SET, 0)) != 0) {
-            LOG(log_error, logtype_afpd, "ea_open: lock error on  header: %s", eaname);
+            LOG(log_error, logtype_afpd, "ea_open: lock error on header: %s", eaname);
             ret = -1;
             goto exit;
         }
     }
 
-    /* read it */
-    if (read(ea->ea_fd, ea->ea_data, ea->ea_size) != (ssize_t)ea->ea_size) {
-        LOG(log_error, logtype_afpd, "ea_open: short read on header: %s", eaname);
+    /* Check if the file is newly created */
+    if (fstat(ea->ea_fd, &st) == -1) {
+        LOG(log_error, logtype_afpd, "ea_open('%s'): fstat error: %s", eaname, strerror(errno));
         ret = -1;
         goto exit;
     }
 
-    if ((unpack_header(ea)) != 0) {
-        LOG(log_error, logtype_afpd, "ea_open: error unpacking header for: %s", eaname);
-        ret = -1;
-        goto exit;
+    if (st.st_size == 0) {
+        /* Initialize a new header */
+        ea->ea_data = malloc(EA_HEADER_SIZE);
+        if (!ea->ea_data) {
+            LOG(log_error, logtype_afpd, "ea_open: OOM");
+            ret = -1;
+            goto exit;
+        }
+        ea->ea_size = EA_HEADER_SIZE;
+        ea->ea_inited = EA_INITED;
+        memset(ea->ea_data, 0, EA_HEADER_SIZE);
+        uint32_t uint32 = htonl(EA_MAGIC);
+        memcpy(ea->ea_data, &uint32, sizeof(uint32_t));
+        uint16_t uint16 = htons(EA_VERSION);
+        memcpy(ea->ea_data + EA_MAGIC_LEN, &uint16, sizeof(uint16_t));
+    } else {
+        /* Read and parse existing header */
+        ea->ea_size = st.st_size;
+        ea->ea_data = malloc(st.st_size);
+        if (!ea->ea_data) {
+            LOG(log_error, logtype_afpd, "ea_open: OOM");
+            ret = -1;
+            goto exit;
+        }
+
+        if (read(ea->ea_fd, ea->ea_data, ea->ea_size) != (ssize_t)ea->ea_size) {
+            LOG(log_error, logtype_afpd, "ea_open: short read on header: %s", eaname);
+            ret = -1;
+            goto exit;
+        }
+
+        if ((unpack_header(ea)) != 0) {
+            LOG(log_error, logtype_afpd, "ea_open: error unpacking header for: %s", eaname);
+            ret = -1;
+            goto exit;
+        }
     }
 
 exit:
@@ -795,7 +779,7 @@ exit:
             free(ea->ea_data);
             ea->ea_data = NULL;
         }
-        if (ea->ea_fd) {
+        if (ea->ea_fd != -1) {
             close(ea->ea_fd);
             ea->ea_fd = -1;
         }
@@ -885,7 +869,7 @@ exit:
  */
 int ea_close(struct ea * restrict ea)
 {
-    int ret = 0; 
+    int ret = 0;
     unsigned int count = 0;
     char *eaname;
     struct stat st;
@@ -973,7 +957,7 @@ exit:
         ea->ea_fd = -1;
     }
 
-    return 0;
+    return ret;
 }
 
 
@@ -1173,7 +1157,7 @@ int list_eas(VFS_FUNC_ARGS_EA_LIST)
     while (count < ea.ea_count) {
         /* Convert name to CH_UTF8_MAC and directly store in in the reply buffer */
         if ( ( len = convert_string(vol->v_volcharset,
-                                    CH_UTF8_MAC, 
+                                    CH_UTF8_MAC,
                                     (*ea.ea_entries)[count].ea_name,
                                     (*ea.ea_entries)[count].ea_namelen,
                                     buf + attrbuflen,
@@ -1391,7 +1375,7 @@ int ea_renamefile(VFS_FUNC_ARGS_RENAMEFILE)
     struct adouble ad;
 
     LOG(log_debug, logtype_afpd, "ea_renamefile('%s'/'%s')", src, dst);
-            
+
 
     /* Open EA stuff */
     if ((ea_openat(vol, dirfd, src, EA_RDWR, &srcea)) != 0) {
@@ -1407,7 +1391,7 @@ int ea_renamefile(VFS_FUNC_ARGS_RENAMEFILE)
     if ((ea_open(vol, dst, EA_RDWR | EA_CREATE, &dstea)) != 0) {
         if (errno == ENOENT) {
             /* Possibly the .AppleDouble folder didn't exist, we create it and try again */
-            ad_init(&ad, vol); 
+            ad_init(&ad, vol);
             if ((ad_open(&ad, dst, ADFLAGS_HF | ADFLAGS_RDWR | ADFLAGS_CREATE, 0666)) != 0) {
                 LOG(log_error, logtype_afpd, "ea_renamefile('%s/%s'): ad_open error: '%s'", src, dst, dst);
                 ret = AFPERR_MISC;
