@@ -109,15 +109,15 @@ static int validupath_adouble(VFS_FUNC_ARGS_VALIDUPATH)
 /* ----------------- */
 static int RF_chown_adouble(VFS_FUNC_ARGS_CHOWN)
 {
-    struct stat st;
-    const char *ad_p;
+    const char *ad_p = vol->ad_path(path, ADFLAGS_HF);
 
-    ad_p = vol->ad_path(path, ADFLAGS_HF );
+    if (chown(ad_p, uid, gid) < 0) {
+        if (errno == ENOENT)
+            return 0; /* Ignore if file doesn't exist */
+        return -1;
+    }
 
-    if ( stat( ad_p, &st ) < 0 )
-        return 0; /* ignore */
-
-    return chown( ad_p, uid, gid );
+    return 0;
 }
 
 /* ----------------- */
@@ -302,14 +302,14 @@ static int RF_renamefile_adouble(VFS_FUNC_ARGS_RENAMEFILE)
 }
 
 static int RF_copyfile_adouble(VFS_FUNC_ARGS_COPYFILE)
-/* const struct vol *vol, int sfd, const char *src, const char *dst */
 {
     EC_INIT;
-    bstring s = NULL, d = NULL;
-    char *dup1 = NULL;
-    char *dup2 = NULL;
-    char *dup3 = NULL;
-    char *dup4 = NULL;
+    bstring s = NULL;
+    bstring d = NULL;
+    char src_name[MAXPATHLEN + 1];
+    char dst_name[MAXPATHLEN + 1];
+    char src_dir[MAXPATHLEN + 1];
+    char dst_dir[MAXPATHLEN + 1];
     const char *name = NULL;
     const char *dir = NULL;
 
@@ -328,21 +328,21 @@ static int RF_copyfile_adouble(VFS_FUNC_ARGS_COPYFILE)
         /* get basename */
 
         /* build src path to AppleDouble file*/
-        EC_NULL(dup1 = strdup(src));
-        EC_NULL(name = basename(strdup(dup1)));
+        strlcpy(src_name, src, sizeof(src_name));
+        strlcpy(src_dir, src, sizeof(src_dir));
+        EC_NULL(name = basename(src_name));
+        EC_NULL(dir = dirname(src_dir));
 
-        EC_NULL(dup2 = strdup(src));
-        EC_NULL(dir = dirname(dup2));
         EC_NULL(s = bfromcstr(dir));
         EC_ZERO(bcatcstr(s, "/.AppleDouble/"));
         EC_ZERO(bcatcstr(s, name));
 
         /* build dst path to AppleDouble file*/
-        EC_NULL(dup4 = strdup(dst));
-        EC_NULL(name = basename(strdup(dup4)));
+        strlcpy(dst_name, dst, sizeof(dst_name));
+        strlcpy(dst_dir, dst, sizeof(dst_dir));
+        EC_NULL(name = basename(dst_name));
+        EC_NULL(dir = dirname(dst_dir));
 
-        EC_NULL(dup3 = strdup(dst));
-        EC_NULL(dir = dirname(dup3));
         EC_NULL(d = bfromcstr(dir));
         EC_ZERO(bcatcstr(d, "/.AppleDouble/"));
         EC_ZERO(bcatcstr(d, name));
@@ -356,11 +356,6 @@ static int RF_copyfile_adouble(VFS_FUNC_ARGS_COPYFILE)
 EC_CLEANUP:
     bdestroy(s);
     bdestroy(d);
-    if (dup1) free(dup1);
-    if (dup2) free(dup2);
-    if (dup3) free(dup3);
-    if (dup4) free(dup4);
-
     EC_EXIT;
 }
 
@@ -558,22 +553,23 @@ static int RF_copyfile_ea(VFS_FUNC_ARGS_COPYFILE)
 #endif
 
     EC_INIT;
-    bstring s = NULL, d = NULL;
-    char *dup1 = NULL;
-    char *dup2 = NULL;
-    char *dup3 = NULL;
-    char *dup4 = NULL;
+    bstring s = NULL;
+    bstring d = NULL;
+    char src_name[MAXPATHLEN + 1];
+    char dst_name[MAXPATHLEN + 1];
+    char src_dir[MAXPATHLEN + 1];
+    char dst_dir[MAXPATHLEN + 1];
     const char *name = NULL;
     const char *dir = NULL;
 
     /* get basename */
 
     /* build src path to ._ file*/
-    EC_NULL(dup1 = strdup(src));
-    EC_NULL(name = basename(strdup(dup1)));
+    strlcpy(src_name, src, sizeof(src_name));
+    strlcpy(src_dir, src, sizeof(src_dir));
 
-    EC_NULL(dup2 = strdup(src));
-    EC_NULL(dir = dirname(dup2));
+    EC_NULL(name = basename(src_name));
+    EC_NULL(dir = dirname(src_dir));
     EC_NULL(s = bfromcstr(dir));
 #ifdef __APPLE__
     EC_ZERO(bcatcstr(s, "/"));
@@ -585,11 +581,11 @@ static int RF_copyfile_ea(VFS_FUNC_ARGS_COPYFILE)
 #endif
 
     /* build dst path to ._file*/
-    EC_NULL(dup4 = strdup(dst));
-    EC_NULL(name = basename(strdup(dup4)));
+    strlcpy(dst_name, dst, sizeof(dst_name));
+    strlcpy(dst_dir, dst, sizeof(dst_dir));
 
-    EC_NULL(dup3 = strdup(dst));
-    EC_NULL(dir = dirname(dup3));
+    EC_NULL(name = basename(dst_name));
+    EC_NULL(dir = dirname(dst_dir));
     EC_NULL(d = bfromcstr(dir));
 #ifdef __APPLE__
     EC_ZERO(bcatcstr(d, "/"));
@@ -615,10 +611,6 @@ static int RF_copyfile_ea(VFS_FUNC_ARGS_COPYFILE)
 EC_CLEANUP:
     bdestroy(s);
     bdestroy(d);
-    free(dup1);
-    free(dup2);
-    free(dup3);
-    free(dup4);
     EC_EXIT;
 }
 
