@@ -506,7 +506,7 @@ int dt;
 	}
 
 	/* FIXME afp_errno in file.c */
-	if ((get_vol_attrib(vol) & VOLPBIT_ATTR_FILEID) ) {
+	if (get_vol_attrib(vol) & VOLPBIT_ATTR_FILEID) {
 		ret = FPCreateID(Conn,vol, DIRDID_ROOT, name1);
 		if (ret != ntohl(AFPERR_NOOBJ)) {
 			test_failed();
@@ -594,7 +594,7 @@ int  dt;
 
 	FAIL (ntohl(AFPERR_ACCESS) != FPCopyFile(Conn, vol, DIRDID_ROOT, vol, DIRDID_ROOT, name1, "", name))
 
-	if ((get_vol_attrib(vol) & VOLPBIT_ATTR_FILEID) ) {
+	if (get_vol_attrib(vol) & VOLPBIT_ATTR_FILEID) {
 		ret = FPCreateID(Conn,vol, DIRDID_ROOT, name1);
 		if (ret != ntohl(AFPERR_ACCESS)) {
 			test_failed();
@@ -703,7 +703,7 @@ int  dt;
 	}
 
 	FAIL (ntohl(AFPERR_BADTYPE) != FPCopyFile(Conn, vol, DIRDID_ROOT, vol, DIRDID_ROOT, name1, "", name))
-	if ((get_vol_attrib(vol) & VOLPBIT_ATTR_FILEID) ) {
+	if (get_vol_attrib(vol) & VOLPBIT_ATTR_FILEID) {
 		FAIL (ntohl(AFPERR_BADTYPE) != FPCreateID(Conn,vol, DIRDID_ROOT, name1))
 	}
 
@@ -799,7 +799,7 @@ int  dt;
 		test_failed();
 	}
 
-	if ((get_vol_attrib(vol) & VOLPBIT_ATTR_FILEID) ) {
+	if (get_vol_attrib(vol) & VOLPBIT_ATTR_FILEID) {
 		FAIL (ntohl(AFPERR_BADTYPE) != FPCreateID(Conn,vol, dir, ""))
 	}
 
@@ -901,7 +901,7 @@ int  dt;
 	FAIL (err != FPCopyFile(Conn, vol, dir, vol, DIRDID_ROOT, name1, "", name))
 
 	/* FIXME afp_errno in file.c */
-	if ((get_vol_attrib(vol) & VOLPBIT_ATTR_FILEID) ) {
+	if (get_vol_attrib(vol) & VOLPBIT_ATTR_FILEID) {
 		if (err != FPCreateID(Conn,vol, dir, name1)) {
 			test_failed();
 		}
@@ -928,7 +928,7 @@ char *name1 = "newtest170.txt";
 int  ofs =  3 * sizeof( uint16_t );
 struct afp_filedir_parms filedir;
 int fork;
-int dir;
+int dir = DIRDID_ROOT_PARENT;
 unsigned int ret;
 uint16_t vol = VolID;
 DSI *dsi;
@@ -975,7 +975,7 @@ int  dt;
 	FAIL (FPDelete(Conn, vol,  DIRDID_ROOT , name))
 
 	/* -------------------- */
-	if ((get_vol_attrib(vol) & VOLPBIT_ATTR_FILEID) ) {
+	if (get_vol_attrib(vol) & VOLPBIT_ATTR_FILEID) {
 		ret = FPCreateID(Conn,vol, DIRDID_ROOT_PARENT, "");
 		FAIL (htonl(AFPERR_NOOBJ) != ret && htonl(AFPERR_PARAM) != ret )
 	}
@@ -1085,7 +1085,7 @@ int  ofs =  3 * sizeof( uint16_t );
 struct afp_filedir_parms filedir;
 int tdir = DIRDID_ROOT_PARENT;
 int fork;
-int dir;
+int dir = DIRDID_ROOT_PARENT;
 unsigned int ret;
 uint16_t vol = VolID;
 DSI *dsi;
@@ -1130,7 +1130,7 @@ int  dt;
 	FAIL (FPDelete(Conn, vol,  DIRDID_ROOT , name))
 
 	/* -------------------- */
-	if ((get_vol_attrib(vol) & VOLPBIT_ATTR_FILEID) ) {
+	if (get_vol_attrib(vol) & VOLPBIT_ATTR_FILEID) {
 		ret = FPCreateID(Conn,vol, tdir, tname);
 		if (htonl(AFPERR_NOOBJ) != ret && htonl(AFPERR_PARAM) != ret ) {
 			test_failed();
@@ -1223,7 +1223,7 @@ int  ofs =  3 * sizeof( uint16_t );
 struct afp_filedir_parms filedir;
 int tdir = 0;
 int fork;
-int dir;
+int dir = DIRDID_ROOT_PARENT;
 unsigned int ret;
 uint16_t vol = VolID;
 DSI *dsi;
@@ -1268,7 +1268,7 @@ int  dt;
 	FAIL (FPDelete(Conn, vol,  DIRDID_ROOT , name))
 
 	/* -------------------- */
-	if ((get_vol_attrib(vol) & VOLPBIT_ATTR_FILEID) ) {
+	if (get_vol_attrib(vol) & VOLPBIT_ATTR_FILEID) {
 		ret = FPCreateID(Conn,vol, tdir, tname);
 		FAIL (htonl(AFPERR_PARAM) != ret)
 	}
@@ -1367,7 +1367,7 @@ int  ofs =  3 * sizeof( uint16_t );
 struct afp_filedir_parms filedir;
 int tdir;
 int fork;
-int dir;
+int dir = DIRDID_ROOT_PARENT;
 uint16_t vol2;
 unsigned int ret;
 uint16_t vol = VolID;
@@ -1439,7 +1439,7 @@ int  dt;
 	FAIL (FPDelete(Conn, vol,  DIRDID_ROOT , name))
 
 	/* -------------------- */
-	if ((get_vol_attrib(vol) & VOLPBIT_ATTR_FILEID) ) {
+	if (get_vol_attrib(vol) & VOLPBIT_ATTR_FILEID) {
 		ret = FPCreateID(Conn,vol, tdir, tname);
 		if (htonl(AFPERR_NOOBJ) != ret && htonl(AFPERR_PARAM) != ret ) {
 			test_failed();
@@ -1545,7 +1545,7 @@ void Error_test()
 	test102();
 	test103();
 	test105();
-// FIXME: Because of an afpd crash, test data cleanup fails
+/* causes afpd crash in dircache_search_by_did() */
 #if 0
 	test170();
 	test171();
