@@ -12,12 +12,12 @@ int ret;
 	ENTER_TEST
 
 	if (0xffff == (dir = FPOpenDT(Conn,vol))) {
-		nottested();
+		test_nottested();
 		goto test_exit;
 	}
 	ret = FPCloseDT(Conn, dir +1);
 	if (not_valid(ret, AFPERR_PARAM, 0)) {
-		failed();
+		test_failed();
 	}
 	FAIL (FPCloseDT(Conn, dir))
 test_exit:
@@ -27,8 +27,6 @@ test_exit:
 /* ----------- */
 void FPCloseDT_test()
 {
-    fprintf(stdout,"===================\n");
-    fprintf(stdout,"FPCloseDT page 128\n");
-    fprintf(stdout,"-------------------\n");
+    ENTER_TESTSET
 	test201();
 }
