@@ -10,8 +10,8 @@ int fork = 0;
 char *name1 = "t51 file";
 char *name2 = "t51 other file.txt";
 char *name3 = "t51 dir";
-int  dir;
-int  did;
+int  dir = 0;
+int  did = 0;
 char *rodir = "t51 read only access";
 int rdir = 0;
 uint16_t vol = VolID;
