@@ -58,7 +58,6 @@ struct sigaction action;
     	test_nottested();
 		goto test_exit;
     }
-    dsi3->protocol = DSI_TCPIP;
 	dsi3->socket = sock;
 	ret = FPopenLoginExt(conn2, vers, uam, User, Password);
 	if (ret) {
@@ -160,15 +159,17 @@ test_exit:
 STATIC void test338()
 {
 char *name = "t338 file";
-uint16_t vol, vol2;
+uint16_t vol = 0;
 unsigned int ret;
 char *token = NULL;
 uint32_t len;
 CONN *loc_conn1 = NULL;
 CONN *loc_conn2 = NULL;
-DSI *loc_dsi1, *loc_dsi2;
-int sock1, sock2;
-int fork = 0, fork1;
+DSI *loc_dsi1;
+DSI *loc_dsi2;
+int sock1;
+int sock2;
+int fork = 0;
 struct sigaction action;
 char *id0="testsuite-test338-0";
 char *id1="testsuite-test338-1";
@@ -200,7 +201,6 @@ uint32_t time= 12345;
         test_nottested();
 		goto test_exit;
     }
-    loc_dsi1->protocol = DSI_TCPIP;
     loc_dsi1->socket = sock1;
     ret = FPopenLoginExt(loc_conn1, vers, uam, User, Password);
     if (ret) {
@@ -257,7 +257,6 @@ uint32_t time= 12345;
         goto fin;
     }
 
-    loc_dsi2->protocol = DSI_TCPIP;
     loc_dsi2->socket = sock2;
     ret = FPopenLoginExt(loc_conn2, vers, uam, User, Password);
     if (ret) {
@@ -296,7 +295,7 @@ char *name = "t339 file";
 char *ndir = "t339 dir";
 char *no_user_uam = "No User Authent";
 
-uint16_t vol1, vol2;
+uint16_t vol1;
 unsigned int ret;
 char *token = NULL;
 uint32_t len;
@@ -341,7 +340,6 @@ struct afp_filedir_parms filedir;
 		goto test_exit;
     }
 
-    loc_dsi1->protocol = DSI_TCPIP;
     loc_dsi1->socket = sock1;
     ret = FPopenLoginExt(loc_conn1, vers, no_user_uam, "", "");
     if (ret) {
@@ -411,7 +409,6 @@ struct afp_filedir_parms filedir;
         goto fin;
     }
 
-    loc_dsi2->protocol = DSI_TCPIP;
     loc_dsi2->socket = sock2;
     ret = FPopenLoginExt(loc_conn2, vers, no_user_uam, "", "");
     if (ret) {
@@ -423,7 +420,7 @@ struct afp_filedir_parms filedir;
     action.sa_handler = pipe_handler;
     sigemptyset(&action.sa_mask);
     action.sa_flags = SA_RESTART;
-    if ((sigaction(SIGPIPE, &action, NULL) < 0)) {
+    if (sigaction(SIGPIPE, &action, NULL) < 0) {
 		test_nottested();
 		goto fin;
     }
@@ -441,7 +438,7 @@ struct afp_filedir_parms filedir;
     action.sa_handler = SIG_DFL;
     sigemptyset(&action.sa_mask);
     action.sa_flags = SA_RESTART;
-    if ((sigaction(SIGPIPE, &action, NULL) < 0)) {
+    if (sigaction(SIGPIPE, &action, NULL) < 0) {
 		test_nottested();
     }
 fin:
@@ -471,8 +468,10 @@ uint32_t len;
 CONN *loc_conn1 = NULL;
 CONN *loc_conn2 = NULL;
 DSI *dsi;
-DSI *loc_dsi1, *loc_dsi2;
-int sock1, sock2;
+DSI *loc_dsi1;
+DSI *loc_dsi2;
+int sock1;
+int sock2;
 int fork = 0;
 struct sigaction action;
 char *id0="testsuite-test370-0";
@@ -510,7 +509,6 @@ struct afp_filedir_parms filedir;
 		goto test_exit;
     }
 
-    loc_dsi1->protocol = DSI_TCPIP;
     loc_dsi1->socket = sock1;
     ret = FPopenLoginExt(loc_conn1, vers, uam, User, Password);
     if (ret) {
@@ -580,7 +578,6 @@ struct afp_filedir_parms filedir;
         goto fin;
     }
 
-    loc_dsi2->protocol = DSI_TCPIP;
     loc_dsi2->socket = sock2;
     ret = FPopenLoginExt(loc_conn2, vers, no_user_uam, "", "");
     if (ret) {
@@ -592,7 +589,7 @@ struct afp_filedir_parms filedir;
     action.sa_handler = pipe_handler;
     sigemptyset(&action.sa_mask);
     action.sa_flags = SA_RESTART;
-    if ((sigaction(SIGPIPE, &action, NULL) < 0)) {
+    if (sigaction(SIGPIPE, &action, NULL) < 0) {
 		test_nottested();
 		goto fin;
     }
@@ -602,7 +599,7 @@ struct afp_filedir_parms filedir;
     action.sa_handler = SIG_DFL;
     sigemptyset(&action.sa_mask);
     action.sa_flags = SA_RESTART;
-    if ((sigaction(SIGPIPE, &action, NULL) < 0)) {
+    if (sigaction(SIGPIPE, &action, NULL) < 0) {
 		test_nottested();
     }
 
