@@ -14,6 +14,12 @@ char   u_null[] = { 0, 0, 0, 0 };
 
 	ENTER_TEST
 
+	// Not supported with the mysql backend
+	if (Exclude) {
+		test_skipped(T_EXCLUDE);
+		goto test_exit;
+	}
+
 	dt = FPOpenDT(Conn,vol);
 
 	ret = FPGetIcon(Conn,  dt, "ttxt", "3DMF", 1, 256);
@@ -38,6 +44,8 @@ char   u_null[] = { 0, 0, 0, 0 };
 	}
 
 	FPCloseDT(Conn,dt);
+
+test_exit:
 	exit_test("FPGetIcon:test115: get Icon call");
 }
 
