@@ -367,7 +367,7 @@ int offset;
 int quantum;
 struct sigaction action;
 struct itimerval    it;
-CONN *myconn;
+CONN *myconn = { 0 };
 
 	dsi = &Conn->dsi;
 	sock = -1;
@@ -414,7 +414,6 @@ CONN *myconn;
     	test_nottested();
     	goto fin;
     }
-    dsi2->protocol = DSI_TCPIP;
 	dsi2->socket = sock;
 	ret = FPopenLogin(myconn, vers, uam, User, Password);
 	if (ret) {
@@ -507,12 +506,15 @@ fin:
 		test_failed();
 		sleep(5);
 	}
-	else {
+	else if (myconn) {
 		if (fork1) FPCloseFork(myconn,fork1);
 		if (fork) FPCloseFork(myconn,fork);
 	}
-	free(myconn);
-	myconn = NULL;
+
+	if (myconn) {
+		free(myconn);
+		myconn = NULL;
+	}
 
 	FAIL (FPDelete(Conn, vol,  DIRDID_ROOT, name1))
 	FAIL (FPDelete(Conn, vol,  DIRDID_ROOT, name))
@@ -523,7 +525,7 @@ fin:
     action.sa_handler = SIG_DFL;
     sigemptyset(&action.sa_mask);
     action.sa_flags = SA_RESTART;
-    if ((sigaction(SIGALRM, &action, NULL) < 0)) {
+    if (sigaction(SIGALRM, &action, NULL) < 0) {
 		test_nottested();
     }
 	sleep(1);
