@@ -5,7 +5,7 @@
 /* ------------------------- */
 STATIC void test98()
 {
-int  dir;
+int  dir = 0;
 char *name = "t98 error setfildirparams";
 char *name1 = "t98 error setfildirparams file";
 char *ndir = "t98 no access";
@@ -593,7 +593,7 @@ DSI *dsi;
 
 	ENTER_TEST
 
-	if ((get_vol_attrib(vol) & VOLPBIT_ATTR_UNIXPRIV)) {
+	if (get_vol_attrib(vol) & VOLPBIT_ATTR_UNIXPRIV) {
 		test_skipped(T_NO_UNIX_PREV);
 		goto test_exit;
 	}
