@@ -44,7 +44,7 @@ uint32_t time= 12345;
     action.sa_handler = pipe_handler;
     sigemptyset(&action.sa_mask);
     action.sa_flags = SA_RESTART;
-    if ((sigaction(SIGPIPE, &action, NULL) < 0)) {
+    if (sigaction(SIGPIPE, &action, NULL) < 0) {
 		test_nottested();
 		goto test_exit;
     }
@@ -67,7 +67,6 @@ uint32_t time= 12345;
             test_nottested();
             goto fin;
         }
-        Conn->dsi.protocol = DSI_TCPIP;
         if (Conn->afp_version < 30)
             ret = FPopenLogin(Conn, vers, uam, User, Password);
         else
@@ -98,7 +97,7 @@ fin:
     action.sa_handler = SIG_DFL;
     sigemptyset(&action.sa_mask);
     action.sa_flags = SA_RESTART;
-    if ((sigaction(SIGPIPE, &action, NULL) < 0)) {
+    if (sigaction(SIGPIPE, &action, NULL) < 0) {
 		test_nottested();
     }
 test_exit:
@@ -134,7 +133,7 @@ uint32_t time= 12345;
     action.sa_handler = pipe_handler;
     sigemptyset(&action.sa_mask);
     action.sa_flags = SA_RESTART;
-    if ((sigaction(SIGPIPE, &action, NULL) < 0)) {
+    if (sigaction(SIGPIPE, &action, NULL) < 0) {
 		test_nottested();
 		goto test_exit;
     }
@@ -156,7 +155,6 @@ uint32_t time= 12345;
             test_nottested();
             goto fin;
         }
-        Conn->dsi.protocol = DSI_TCPIP;
         if (Conn->afp_version < 30)
             ret = FPopenLogin(Conn, vers, uam, User, Password);
         else
@@ -185,7 +183,7 @@ fin:
     action.sa_handler = SIG_DFL;
     sigemptyset(&action.sa_mask);
     action.sa_flags = SA_RESTART;
-    if ((sigaction(SIGPIPE, &action, NULL) < 0)) {
+    if (sigaction(SIGPIPE, &action, NULL) < 0) {
 		test_nottested();
     }
 test_exit:
@@ -221,7 +219,7 @@ int sock;
     action.sa_handler = pipe_handler;
     sigemptyset(&action.sa_mask);
     action.sa_flags = SA_RESTART;
-    if ((sigaction(SIGPIPE, &action, NULL) < 0)) {
+    if (sigaction(SIGPIPE, &action, NULL) < 0) {
 		test_nottested();
 		goto test_exit;
     }
@@ -236,7 +234,7 @@ fin:
     action.sa_handler = SIG_DFL;
     sigemptyset(&action.sa_mask);
     action.sa_flags = SA_RESTART;
-    if ((sigaction(SIGPIPE, &action, NULL) < 0)) {
+    if (sigaction(SIGPIPE, &action, NULL) < 0) {
 		test_nottested();
     }
 test_exit:
