@@ -16,8 +16,8 @@ int ret;
 
 	ENTER_TEST
 
-	if (!Mac && Path[0] == '\0') {
-        test_skipped(T_MAC_PATH);
+	if (Path[0] == '\0') {
+        test_skipped(T_PATH);
 		goto test_exit;
 	}
 
@@ -30,33 +30,29 @@ int ret;
 		test_nottested();
 		goto test_exit;
 	}
-	if (!Mac) {
-		sprintf(temp,"%s/%s", Path, name);
-		if (!Quiet) {
-			fprintf(stdout,"unlink data fork\n");
-		}
-		if (unlink(temp) <0) {
-			if (!Quiet) {
-				fprintf(stdout,"\tFAILED unlink(%s) %s\n", temp, strerror(errno));
-			}
-			test_failed();
-			goto fin;
-		}
 
-		sprintf(temp,"%s/.AppleDouble/%s", Path, name);
-		if (!Quiet) {
-			fprintf(stdout,"chmod 444 resource fork\n");
-		}
-		if (chmod(temp, 0444) <0) {
-			if (!Quiet) {
-				fprintf(stdout,"\tFAILED chmod(%s) %s\n", temp, strerror(errno));
-			}
-			test_failed();
-			goto fin;
-		}
+	sprintf(temp,"%s/%s", Path, name);
+	if (!Quiet) {
+		fprintf(stdout,"unlink data fork\n");
 	}
-	else {
-		FAIL (FPDelete(Conn, vol,  DIRDID_ROOT , name))
+	if (unlink(temp) <0) {
+		if (!Quiet) {
+			fprintf(stdout,"\tFAILED unlink(%s) %s\n", temp, strerror(errno));
+		}
+		test_failed();
+		goto fin;
+	}
+
+	sprintf(temp,"%s/.AppleDouble/%s", Path, name);
+	if (!Quiet) {
+		fprintf(stdout,"chmod 444 resource fork\n");
+	}
+	if (chmod(temp, 0444) <0) {
+		if (!Quiet) {
+			fprintf(stdout,"\tFAILED chmod(%s) %s\n", temp, strerror(errno));
+		}
+		test_failed();
+		goto fin;
 	}
 
 	ret = FPCreateFile(Conn, vol,  0, DIRDID_ROOT , name);
@@ -71,9 +67,8 @@ int ret;
 
 fin:
 	FPDelete(Conn, vol,  DIRDID_ROOT , name);
-	if (!Mac) {
-		unlink(temp);
-	}
+	unlink(temp);
+
 test_exit:
 	exit_test("FPCreateFile:test325: recreate a file with dangling symlink and no right");
 }
