@@ -39,7 +39,7 @@ DSI        *Dsi;
 /* Default values for options */
 char    *Server = "localhost";
 int     Proto = 0;
-int     Port = 548;
+int     Port = DSI_AFPOVERTCP_PORT;
 char    *Password = "";
 char    *Vol = "";
 char    *User;
@@ -58,6 +58,9 @@ int PassCount = 0;
 int FailCount = 0;
 int SkipCount = 0;
 int NotTestedCount = 0;
+char FailedTests[1024][256] = {{0}};
+char NotTestedTests[1024][256] = {{0}};
+char SkippedTests[1024][256] = {{0}};
 
 /* =============================== */
 static void list_tests(void)
@@ -133,6 +136,10 @@ int main( int ac, char **av )
 int cc;
 int ret;
 
+    if (ac == 1) {
+        usage(av[0]);
+    }
+
     while (( cc = getopt( ac, av, "1234567lVvf:h:p:s:u:w:" )) != EOF ) {
         switch ( cc ) {
         case '1':
@@ -235,7 +242,6 @@ int ret;
         if ( sock < 0) {
 	    	return 2;
         }
-     	Dsi->protocol = DSI_TCPIP;
 	    Dsi->socket = sock;
     }
     else {
