@@ -16,46 +16,51 @@ int	Bigendian = 0;
 #define kTextEncodingUTF8 0x08000103
 
 /* -------------------------------------------- */
-int OpenClientSocket(char* host,int port)
+int OpenClientSocket(char* host, int port)
 {
-int sock;
-struct sockaddr_in server;
-struct hostent* hp;
-int attr;
+    int sock = -1;
+    struct addrinfo hints;
+    struct addrinfo *res;
+    struct addrinfo *ressave;
+    char portstr[6];
+    int attr;
 
-	server.sin_family=AF_INET;
-	server.sin_port=htons((unsigned short)port);
+    memset(&hints, 0, sizeof(hints));
+    hints.ai_family = AF_UNSPEC;
+    hints.ai_socktype = SOCK_STREAM;
 
-	hp=gethostbyname(host);
- 	if(!hp) {
-    unsigned long int addr=inet_addr(host);
-    	if(addr!= (unsigned)-1)
-       		hp=gethostbyaddr((char*)addr,sizeof(addr),AF_INET);
+    snprintf(portstr, sizeof(portstr), "%d", port);
 
-    	if(!hp) {
-       		fprintf(stdout,"Unknown host '%s' for server \n.",host);
-       		return(-1);
-      	}
-   	}
+    if (getaddrinfo(host, portstr, &hints, &res) != 0) {
+        fprintf(stdout, "Unknown host '%s' for server.\n", host);
+        return -1;
+    }
 
- 	memcpy((char*)&server.sin_addr,(char*)hp->h_addr,sizeof(server.sin_addr));
+    ressave = res;
+    while (res) {
+        sock = socket(res->ai_family, res->ai_socktype, 0);
+        if (sock >= 0) {
+            attr = 1;
+            setsockopt(sock, IPPROTO_TCP, TCP_NODELAY, &attr, sizeof(attr));
 
- 	sock=socket(PF_INET,SOCK_STREAM,0);
- 	if(sock==-1) {
-    	fprintf(stdout,"Failed to create client sockets.\n");
-    	return(-1);
-   	}
-    attr = 1;
-    setsockopt(sock, IPPROTO_TCP, TCP_NODELAY, &attr, sizeof(attr));
+            if (connect(sock, res->ai_addr, res->ai_addrlen) == 0)
+                break;  // Success
 
- 	if(connect(sock ,(struct sockaddr*)&server,sizeof(server))==-1) {
-    	close(sock);
-    	sock=-1;
-    	fprintf(stdout,"Failed to connect socket.\n");
-   	}
+            close(sock);
+            sock = -1;
+        }
+        res = res->ai_next;
+    }
 
-	 return(sock);
+    freeaddrinfo(ressave);
+
+    if (sock < 0) {
+        fprintf(stdout, "Failed to connect socket.\n");
+    }
+
+    return sock;
 }
+
 /* -------------------------------------------- */
 int CloseClientSocket(int fd)
 {
@@ -355,7 +360,7 @@ int ofs;
 }
 
 /* ------------------------- */
-static int SendCmdVolDidCname(CONN *conn, int cmd, uint16_t vol, int did , char *name)
+static unsigned int SendCmdVolDidCname(CONN *conn, int cmd, uint16_t vol, int did , char *name)
 {
 int ofs;
 DSI *dsi;
@@ -381,13 +386,13 @@ DSI *dsi;
 	/* ------------------ */
 	my_dsi_cmd_receive(dsi);
 
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* -----------------------------------------------
    Open a new session
 */
-int DSIOpenSession(CONN *conn)
+unsigned int DSIOpenSession(CONN *conn)
 {
 DSI *dsi;
 uint32_t i = 0;
@@ -428,7 +433,7 @@ uint32_t i = 0;
 /* -----------------------------------------------
    GetStatus
 */
-int DSIGetStatus(CONN *conn)
+unsigned int DSIGetStatus(CONN *conn)
 {
 DSI *dsi;
 
@@ -450,7 +455,7 @@ DSI *dsi;
    Close Session
    no reply
 */
-int DSICloseSession(CONN *conn)
+unsigned int DSICloseSession(CONN *conn)
 {
 DSI *dsi;
 
@@ -470,7 +475,7 @@ DSI *dsi;
 	spec violation in netatalk
 	FPlogout ==> dsiclose
 */
-int AFPopenLogin(CONN *conn, char *vers, char *uam, char *usr, char *pwd)
+unsigned int AFPopenLogin(CONN *conn, char *vers, char *uam, char *usr, char *pwd)
 {
 uint8_t len;
 int ofs;
@@ -513,11 +518,11 @@ DSI *dsi = &conn->dsi;
    	my_dsi_stream_send(dsi, dsi->commands, dsi->datalen);
 	/* ------------------ */
 	my_dsi_cmd_receive(dsi);
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* ---------------------------- */
-int AFPopenLoginExt(CONN *conn, char *vers, char *uam, char *usr, char *pwd)
+unsigned int AFPopenLoginExt(CONN *conn, char *vers, char *uam, char *usr, char *pwd)
 {
 uint8_t len;
 uint16_t len16;
@@ -588,11 +593,11 @@ DSI *dsi;
    	my_dsi_stream_send(dsi, dsi->commands, dsi->datalen);
 	/* ------------------ */
 	my_dsi_cmd_receive(dsi);
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* --------------------------- */
-int AFPChangePW(CONN *conn, char *uam, char *usr, char *opwd, char *pwd)
+unsigned int AFPChangePW(CONN *conn, char *uam, char *usr, char *opwd, char *pwd)
 {
 uint8_t len;
 int ofs;
@@ -637,10 +642,10 @@ DSI *dsi;
    	my_dsi_stream_send(dsi, dsi->commands, dsi->datalen);
 	/* ------------------ */
 	my_dsi_cmd_receive(dsi);
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 /* ------------------------------- */
-int AFPLogOut(CONN *conn)
+unsigned int AFPLogOut(CONN *conn)
 {
     DSI *dsi;
     int ret;
@@ -650,11 +655,11 @@ int AFPLogOut(CONN *conn)
 	ret = my_dsi_full_receive(dsi, dsi->commands, DSI_CMDSIZ);
     DSICloseSession(conn);
 
-    return (dsi->header.dsi_code);
+    return dsi->header.dsi_code;
 }
 
 /* ------------------------------- */
-int AFPzzz(CONN *conn, int flag)
+unsigned int AFPzzz(CONN *conn, int flag)
 {
     int 		ofs = 0;
     DSI			*dsi = &conn->dsi;
@@ -675,33 +680,33 @@ int AFPzzz(CONN *conn, int flag)
    	my_dsi_stream_send(dsi, dsi->commands, dsi->datalen);
 	/* ------------------ */
 	my_dsi_cmd_receive(dsi);
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* ------------------------------- */
-int AFPGetSrvrInfo(CONN *conn)
+unsigned int AFPGetSrvrInfo(CONN *conn)
 {
 DSI *dsi;
 
 	dsi = &conn->dsi;
 	SendCmd(dsi,AFP_GETSRVINFO);
 	my_dsi_cmd_receive(dsi);
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* ------------------------------- */
-int AFPGetSrvrParms(CONN *conn)
+unsigned int AFPGetSrvrParms(CONN *conn)
 {
 DSI *dsi;
 
 	dsi = &conn->dsi;
 	SendCmd(dsi,AFP_GETSRVPARAM);
 	my_dsi_data_receive(dsi);
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* ------------------------------- */
-int AFPGetSrvrMsg(CONN *conn, uint16_t type, uint16_t bitmap)
+unsigned int AFPGetSrvrMsg(CONN *conn, uint16_t type, uint16_t bitmap)
 {
 int ofs;
 DSI *dsi;
@@ -725,44 +730,44 @@ DSI *dsi;
    	my_dsi_stream_send(dsi, dsi->commands, dsi->datalen);
 
 	my_dsi_cmd_receive(dsi);
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* -------------------------------  */
-int AFPCloseVol(CONN *conn, uint16_t vol)
+unsigned int AFPCloseVol(CONN *conn, uint16_t vol)
 {
 DSI *dsi;
 
 	dsi = &conn->dsi;
 	SendCmdWithU16(dsi, AFP_CLOSEVOL, vol);
 	my_dsi_cmd_receive(dsi);
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* -------------------------------  */
-int AFPCloseDT(CONN *conn, uint16_t vol)
+unsigned int AFPCloseDT(CONN *conn, uint16_t vol)
 {
 DSI *dsi;
 
 	dsi = &conn->dsi;
 	SendCmdWithU16(dsi, AFP_CLOSEDT, vol);
 	my_dsi_cmd_receive(dsi);
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* ------------------------------- */
-int AFPCloseFork(CONN *conn, uint16_t fork)
+unsigned int AFPCloseFork(CONN *conn, uint16_t fork)
 {
 DSI *dsi;
 
 	dsi = &conn->dsi;
 	SendCmdWithU16(dsi, AFP_CLOSEFORK, fork);
 	my_dsi_cmd_receive(dsi);
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* ------------------------------- */
-int AFPByteLock(CONN *conn, uint16_t fork, int end, int mode, int offset, int size )
+unsigned int AFPByteLock(CONN *conn, uint16_t fork, int end, int mode, int offset, int size )
 {
 int ofs;
 DSI *dsi;
@@ -790,7 +795,7 @@ DSI *dsi;
    	my_dsi_stream_send(dsi, dsi->commands, dsi->datalen);
 
 	my_dsi_cmd_receive(dsi);
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* ---------------------------- */
@@ -836,7 +841,7 @@ static int set_off_t(off_t offset, uint8_t *rbuf, int is64)
 }
 
 /* ------------------------------- */
-int AFPByteLock_ext(CONN *conn, uint16_t fork, int end, int mode, off_t offset, off_t size )
+unsigned int AFPByteLock_ext(CONN *conn, uint16_t fork, int end, int mode, off_t offset, off_t size )
 {
 int ofs;
 DSI *dsi;
@@ -860,7 +865,7 @@ DSI *dsi;
    	my_dsi_stream_send(dsi, dsi->commands, dsi->datalen);
 
 	my_dsi_cmd_receive(dsi);
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* ------------------------------- */
@@ -894,25 +899,25 @@ int is64 = bitmap & ((1 << FILPBIT_EXTDFLEN) | (1 << FILPBIT_EXTRFLEN));
 }
 
 /* ------------------------------- */
-int AFPFlush(CONN *conn, uint16_t vol)
+unsigned int AFPFlush(CONN *conn, uint16_t vol)
 {
 DSI *dsi;
 
 	dsi = &conn->dsi;
 	SendCmdWithU16(dsi, AFP_FLUSH, vol);
 	my_dsi_cmd_receive(dsi);
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* -------------------------------  */
-int AFPFlushFork(CONN *conn, uint16_t vol)
+unsigned int AFPFlushFork(CONN *conn, uint16_t vol)
 {
 DSI *dsi;
 
 	dsi = &conn->dsi;
 	SendCmdWithU16(dsi, AFP_FLUSHFORK, vol);
 	my_dsi_cmd_receive(dsi);
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* -------------------------------  */
@@ -953,7 +958,7 @@ DSI *dsi;
 		ofs += sizeof(result);
 		result = ntohs(result);
 		/* XXXX need to fully parse this stuff */
-		if ((result & (1<<VOLPBIT_ATTR))) {
+		if (result & (1<<VOLPBIT_ATTR)) {
 		    /* volume attribute  */
 		    memcpy(&result, dsi->commands, sizeof(result));
 		    ofs += sizeof(result);
@@ -962,7 +967,7 @@ DSI *dsi;
 		memcpy(&result, dsi->commands +ofs, sizeof(result));
 		volID = result;
 	}
-	return(volID);
+	return volID;
 }
 
 /* -------------------------------  */
@@ -1138,7 +1143,7 @@ int afp_volume_pack(unsigned char *b, struct afp_volume_parms *parms, uint16_t b
         bitmap = bitmap>>1;
         bit++;
     }
-    return (b -beg);
+    return b -beg;
 }
 
 /* -------------------------------------- */
@@ -1155,7 +1160,7 @@ void afp_filedir_unpack(struct afp_filedir_parms *filedir, unsigned char *b, uin
 	unsigned char *beg = b;
 
     isdir = filedir->isdir;
-	bitmap = (isdir)?rdbitmap:rfbitmap;
+	bitmap = isdir?rdbitmap:rfbitmap;
 	while (bitmap != 0) {
 		while (( bitmap & 1 ) == 0 ) {
 			bitmap = bitmap>>1;
@@ -1284,7 +1289,7 @@ int afp_filedir_pack(unsigned char *b, struct afp_filedir_parms *filedir, uint16
 	unsigned char *u_ofs = NULL;
 
     isdir = filedir->isdir;
-	bitmap = (isdir)?rdbitmap:rfbitmap;
+	bitmap = isdir?rdbitmap:rfbitmap;
 	while (bitmap != 0) {
 		while (( bitmap & 1 ) == 0 ) {
 			bitmap = bitmap>>1;
@@ -1405,11 +1410,11 @@ int afp_filedir_pack(unsigned char *b, struct afp_filedir_parms *filedir, uint16
         	b += sizeof(tp);
         }
     }
-    return (b -beg);
+    return b -beg;
 }
 
 /* -------------------------------  */
-int AFPGetVolParam(CONN *conn, uint16_t vol, uint16_t bitmap)
+unsigned int AFPGetVolParam(CONN *conn, uint16_t vol, uint16_t bitmap)
 {
 int ofs;
 DSI *dsi;
@@ -1433,11 +1438,11 @@ DSI *dsi;
    	my_dsi_stream_send(dsi, dsi->commands, dsi->datalen);
 	/* ------------------ */
 	my_dsi_cmd_receive(dsi);
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* -------------------------------  */
-int AFPSetVolParam(CONN *conn, uint16_t vol, uint16_t bitmap, struct afp_volume_parms *parms)
+unsigned int AFPSetVolParam(CONN *conn, uint16_t vol, uint16_t bitmap, struct afp_volume_parms *parms)
 {
 int ofs;
 DSI *dsi;
@@ -1463,7 +1468,7 @@ uint16_t tp;
    	my_dsi_stream_send(dsi, dsi->commands, dsi->datalen);
 	/* ------------------ */
 	my_dsi_cmd_receive(dsi);
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* ---------------------
@@ -1548,11 +1553,11 @@ DSI *dsi;
    	my_dsi_stream_send(dsi, dsi->commands, dsi->datalen);
 	/* ------------------ */
 	my_dsi_cmd_receive(dsi);
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* ------------------------------- */
-int AFPWriteHeader(DSI *dsi, uint16_t fork, int offset, int size, char *data, char whence)
+unsigned int AFPWriteHeader(DSI *dsi, uint16_t fork, int offset, int size, char *data, char whence)
 {
 int ofs;
 int rsize;
@@ -1589,7 +1594,7 @@ uint32_t temp;
 }
 
 /* ------------------------------- */
-int AFPWriteFooter(DSI *dsi, uint16_t fork, int offset, int size, char *data, char whence)
+unsigned int AFPWriteFooter(DSI *dsi, uint16_t fork, int offset, int size, char *data, char whence)
 {
 uint32_t last;
 
@@ -1610,7 +1615,7 @@ uint32_t last;
 }
 
 /* ------------------------------- */
-int AFPWrite(CONN *conn, uint16_t fork, int offset, int size, char *data, char whence)
+unsigned int AFPWrite(CONN *conn, uint16_t fork, int offset, int size, char *data, char whence)
 {
 DSI *dsi;
 
@@ -1620,7 +1625,7 @@ DSI *dsi;
 }
 
 /* ------------------------------- */
-int AFPWrite_ext(CONN *conn, uint16_t fork, off_t offset, off_t size, char *data, char whence)
+unsigned int AFPWrite_ext(CONN *conn, uint16_t fork, off_t offset, off_t size, char *data, char whence)
 {
 int ofs;
 DSI *dsi;
@@ -1667,7 +1672,7 @@ unsigned char *ptr;
 }
 
 /* ------------------------------- */
-int AFPWrite_ext_async(CONN *conn, uint16_t fork, off_t offset, off_t size, char *data, char whence)
+unsigned int AFPWrite_ext_async(CONN *conn, uint16_t fork, off_t offset, off_t size, char *data, char whence)
 {
     int ofs;
     DSI *dsi = &conn->dsi;
@@ -1753,19 +1758,19 @@ unsigned int AFPDelete(CONN *conn, uint16_t vol, int did , char *name)
 }
 
 /* ------------------------------- */
-int AFPGetComment(CONN *conn, uint16_t vol, int did , char *name)
+unsigned int AFPGetComment(CONN *conn, uint16_t vol, int did , char *name)
 {
 	return  SendCmdVolDidCname(conn,AFP_GETCMT , vol, did , name);
 }
 
 /* ------------------------------- */
-int AFPRemoveComment(CONN *conn, uint16_t vol, int did , char *name)
+unsigned int AFPRemoveComment(CONN *conn, uint16_t vol, int did , char *name)
 {
 	return  SendCmdVolDidCname(conn,AFP_RMVCMT , vol, did , name);
 }
 
 /* ------------------------------- */
-int AFPAddComment(CONN *conn, uint16_t vol, int did , char *name, char *cmt)
+unsigned int AFPAddComment(CONN *conn, uint16_t vol, int did , char *name, char *cmt)
 {
 int ofs;
 int len;
@@ -1785,7 +1790,7 @@ DSI *dsi;
 	ofs += sizeof(did);
 
     ofs = FPset_name(conn, ofs, name);
-	if ((ofs & 1))
+	if (ofs & 1)
 	    ofs++;
 	len = strlen(cmt);
 	dsi->commands[ofs++] = len;
@@ -1798,12 +1803,12 @@ DSI *dsi;
 	/* ------------------ */
 	my_dsi_cmd_receive(dsi);
 
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 
 }
 
 /* ------------------------------- */
-int AFPGetSessionToken(CONN *conn, int type, uint32_t time, int len, char *token)
+unsigned int AFPGetSessionToken(CONN *conn, int type, uint32_t time, int len, char *token)
 {
 int ofs;
 uint16_t tp = htons(type);
@@ -1837,11 +1842,11 @@ DSI *dsi;
 	/* ------------------ */
 	my_dsi_data_receive(dsi);
 
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* ------------------------------- */
-int AFPDisconnectOldSession(CONN *conn, uint16_t type, int len, char *token)
+unsigned int AFPDisconnectOldSession(CONN *conn, uint16_t type, int len, char *token)
 {
 int ofs;
 uint16_t tp = htons(type);
@@ -1869,11 +1874,11 @@ DSI *dsi;
 	/* ------------------ */
 	my_dsi_data_receive(dsi);
 
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* ------------------------------- */
-int AFPGetUserInfo(CONN *conn, char flag, int id, uint16_t bitmap)
+unsigned int AFPGetUserInfo(CONN *conn, char flag, int id, uint16_t bitmap)
 {
 int ofs;
 uint16_t type = htons(bitmap);
@@ -1900,11 +1905,11 @@ DSI *dsi;
 	/* ------------------ */
 	my_dsi_cmd_receive(dsi);
 
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* ------------------------------- */
-int AFPMapID(CONN *conn, char fn, int id)
+unsigned int AFPMapID(CONN *conn, char fn, int id)
 {
 int ofs;
 DSI *dsi;
@@ -1927,11 +1932,11 @@ DSI *dsi;
 	/* ------------------ */
 	my_dsi_cmd_receive(dsi);
 
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* ------------------------------- */
-int AFPMapName(CONN *conn, char fn, char *name )
+unsigned int AFPMapName(CONN *conn, char fn, char *name )
 {
 int ofs;
 uint16_t len,l;
@@ -1967,11 +1972,11 @@ DSI *dsi;
 	/* ------------------ */
 	my_dsi_cmd_receive(dsi);
 
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* ------------------------------- */
-int AFPBadPacket(CONN *conn, char fn, char *name )
+unsigned int AFPBadPacket(CONN *conn, char fn, char *name )
 {
 int ofs;
 uint16_t l;
@@ -1995,11 +2000,11 @@ DSI *dsi;
 	/* ------------------ */
 	my_dsi_cmd_receive(dsi);
 
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* ------------------------------- */
-int AFPReadHeader(DSI *dsi, uint16_t fork, int offset, int size, char *data)
+unsigned int AFPReadHeader(DSI *dsi, uint16_t fork, int offset, int size, char *data)
 {
 int ofs;
 uint32_t  temp;
@@ -2029,7 +2034,7 @@ uint32_t  temp;
 }
 
 /* ------------------------------- */
-int AFPReadFooter(DSI *dsi, uint16_t fork, int offset, int size, char *data)
+unsigned int AFPReadFooter(DSI *dsi, uint16_t fork, int offset, int size, char *data)
 {
 int rsize;
 
@@ -2042,7 +2047,7 @@ int rsize;
 }
 
 /* ------------------------------- */
-int AFPRead(CONN *conn, uint16_t fork, int offset, int size, char *data)
+unsigned int AFPRead(CONN *conn, uint16_t fork, int offset, int size, char *data)
 {
 DSI *dsi;
 
@@ -2055,7 +2060,7 @@ DSI *dsi;
 /* ----------------------
  * Assume size < 2GB
 */
-int AFPRead_ext(CONN *conn, uint16_t fork, off_t offset, off_t size, char *data)
+unsigned int AFPRead_ext(CONN *conn, uint16_t fork, off_t offset, off_t size, char *data)
 {
 int ofs;
 int rsize;
@@ -2100,7 +2105,7 @@ DSI *dsi;
 	return dsi->header.dsi_code?dsi->header.dsi_code:(rsize +dsi->cmdlen== size)?0:-1;
 }
 
-int AFPRead_ext_async(CONN *conn, uint16_t fork, off_t offset, off_t size, char *data)
+unsigned int AFPRead_ext_async(CONN *conn, uint16_t fork, off_t offset, off_t size, char *data)
 {
     int ofs;
     int rsize;
@@ -2126,10 +2131,10 @@ int AFPRead_ext_async(CONN *conn, uint16_t fork, off_t offset, off_t size, char
 }
 
 /* -------------------------------- */
-int  AFPCreateDir(CONN *conn, uint16_t vol, int did , char *name)
+unsigned int  AFPCreateDir(CONN *conn, uint16_t vol, int did , char *name)
 {
 int ofs;
-int dir = 0;
+unsigned int dir = 0;
 DSI *dsi;
 
 	dsi = &conn->dsi;
@@ -2160,11 +2165,11 @@ DSI *dsi;
 			fprintf(stdout,"directory ID 0x%x\n", ntohl(dir));
 		}
 	}
-	return(dir);
+	return dir;
 }
 
 /* ------------------------------- */
-int AFPGetForkParam(CONN *conn, uint16_t fork, uint16_t bitmap)
+unsigned int AFPGetForkParam(CONN *conn, uint16_t fork, uint16_t bitmap)
 {
 int ofs;
 DSI *dsi;
@@ -2193,7 +2198,7 @@ DSI *dsi;
 
 /* -------------------------------
 */
-int AFPGetAPPL(CONN *conn, uint16_t dt, char *name, uint16_t index, uint16_t f_bitmap)
+unsigned int AFPGetAPPL(CONN *conn, uint16_t dt, char *name, uint16_t index, uint16_t f_bitmap)
 {
 int ofs;
 uint16_t bitmap;
@@ -2225,12 +2230,12 @@ DSI *dsi;
    	my_dsi_stream_send(dsi, dsi->commands, dsi->datalen);
 	/* ------------------ */
 	my_dsi_data_receive(dsi);
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* -------------------------------
 */
-int AFPAddAPPL(CONN *conn, uint16_t dt, int did, char *creator, uint32_t tag, char *name)
+unsigned int AFPAddAPPL(CONN *conn, uint16_t dt, int did, char *creator, uint32_t tag, char *name)
 {
 int ofs;
 DSI *dsi;
@@ -2260,12 +2265,12 @@ DSI *dsi;
    	my_dsi_stream_send(dsi, dsi->commands, dsi->datalen);
 	/* ------------------ */
 	my_dsi_data_receive(dsi);
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* -------------------------------
 */
-int AFPRemoveAPPL(CONN *conn, uint16_t dt, int did, char *creator, char *name)
+unsigned int AFPRemoveAPPL(CONN *conn, uint16_t dt, int did, char *creator, char *name)
 {
 int ofs;
 DSI *dsi;
@@ -2293,12 +2298,12 @@ DSI *dsi;
    	my_dsi_stream_send(dsi, dsi->commands, dsi->datalen);
 	/* ------------------ */
 	my_dsi_data_receive(dsi);
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* -------------------------------
 */
-int AFPCatSearch(CONN *conn, uint16_t vol, uint32_t  nbe, char *pos, uint16_t f_bitmap,uint16_t d_bitmap,
+unsigned int AFPCatSearch(CONN *conn, uint16_t vol, uint32_t  nbe, char *pos, uint16_t f_bitmap,uint16_t d_bitmap,
 uint32_t rbitmap, struct afp_filedir_parms *filedir, struct afp_filedir_parms *filedir2)
 {
 int ofs;
@@ -2353,12 +2358,12 @@ uint16_t bitmap;
    	my_dsi_stream_send(dsi, dsi->commands, dsi->datalen);
 	/* ------------------ */
 	my_dsi_data_receive(dsi);
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* -------------------------------
 */
-int AFPCatSearchExt(CONN *conn, uint16_t vol, uint32_t  nbe, char *pos, uint16_t f_bitmap,uint16_t d_bitmap,
+unsigned int AFPCatSearchExt(CONN *conn, uint16_t vol, uint32_t  nbe, char *pos, uint16_t f_bitmap,uint16_t d_bitmap,
 uint32_t rbitmap, struct afp_filedir_parms *filedir, struct afp_filedir_parms *filedir2)
 {
 int ofs;
@@ -2416,12 +2421,12 @@ uint16_t i;
    	my_dsi_stream_send(dsi, dsi->commands, dsi->datalen);
 	/* ------------------ */
 	my_dsi_data_receive(dsi);
-	return(dsi->header.dsi_code);
+	return dsi->header.dsi_code;
 }
 
 /* -------------------------------
 */
-int AFPGetACL(CONN *conn, uint16_t vol, int did, uint16_t bitmap, char *name)
+unsigned int AFPGetACL(CONN *conn, uint16_t vol, int did, uint16_t bitmap, char *name)
 {
 int ofs;
 DSI *dsi;
@@ -2453,12 +2458,12 @@ DSI *dsi;
         my_dsi_stream_send(dsi, dsi->commands, dsi->datalen);
         /* ------------------ */
         my_dsi_data_receive(dsi);
-        return(dsi->header.dsi_code);
+        return dsi->header.dsi_code;
 }
 
 /* --------------------------------
 */
-int AFPGetExtAttr(CONN *conn, uint16_t vol, int did, uint16_t bitmap, int maxsize, char* pathname, char* attrname)
+unsigned int AFPGetExtAttr(CONN *conn, uint16_t vol, int did, uint16_t bitmap, int maxsize, char* pathname, char* attrname)
 {
 int ofs;
 DSI *dsi;
@@ -2515,13 +2520,13 @@ uint16_t len;
         my_dsi_stream_send(dsi, dsi->commands, dsi->datalen);
         /* ------------------ */
         my_dsi_data_receive(dsi);
-        return(dsi->header.dsi_code);
+        return dsi->header.dsi_code;
 }
 
 
 /* --------------------------------
 */
-int AFPListExtAttr(CONN *conn, uint16_t vol, int did, uint16_t bitmap, int maxsize, char* pathname)
+unsigned int AFPListExtAttr(CONN *conn, uint16_t vol, int did, uint16_t bitmap, int maxsize, char* pathname)
 {
 int ofs;
 DSI *dsi;
@@ -2530,7 +2535,7 @@ DSI *dsi;
 
 	SendInit(dsi);
 	ofs = 0;
-	dsi->commands[ofs++] = AFP_LISTEXTATTRS;
+	dsi->commands[ofs++] = AFP_LISTEXTATTR;
 	dsi->commands[ofs++] = 0;
 
         memcpy(dsi->commands +ofs, &vol, sizeof(vol));
@@ -2559,12 +2564,12 @@ DSI *dsi;
         my_dsi_stream_send(dsi, dsi->commands, dsi->datalen);
         /* ------------------ */
         my_dsi_data_receive(dsi);
-        return(dsi->header.dsi_code);
+        return dsi->header.dsi_code;
 }
 
 /* --------------------------------
 */
-int AFPSetExtAttr(CONN *conn, uint16_t vol, int did, uint16_t bitmap, char* pathname, char* attrname, char* data)
+unsigned int AFPSetExtAttr(CONN *conn, uint16_t vol, int did, uint16_t bitmap, char* pathname, char* attrname, char* data)
 {
 int ofs;
 DSI *dsi;
@@ -2620,10 +2625,10 @@ uint32_t datalen;
         my_dsi_stream_send(dsi, dsi->commands, dsi->datalen);
         /* ------------------ */
         my_dsi_data_receive(dsi);
-        return(dsi->header.dsi_code);
+        return dsi->header.dsi_code;
 }
 
-int AFPRemoveExtAttr(CONN *conn, uint16_t vol, int did, uint16_t bitmap, char* pathname, char* attrname)
+unsigned int AFPRemoveExtAttr(CONN *conn, uint16_t vol, int did, uint16_t bitmap, char* pathname, char* attrname)
 {
 int ofs;
 DSI *dsi;
@@ -2633,7 +2638,7 @@ uint16_t len;
 
 	SendInit(dsi);
 	ofs = 0;
-	dsi->commands[ofs++] = AFP_REMOVEEXTATTR;
+	dsi->commands[ofs++] = AFP_REMOVEATTR;
 	dsi->commands[ofs++] = 0;
 
         memcpy(dsi->commands +ofs, &vol, sizeof(vol));
@@ -2665,5 +2670,5 @@ uint16_t len;
         my_dsi_stream_send(dsi, dsi->commands, dsi->datalen);
         /* ------------------ */
         my_dsi_data_receive(dsi);
-        return(dsi->header.dsi_code);
+        return dsi->header.dsi_code;
 }
