@@ -730,52 +730,52 @@ static char temp[4096];
 static char temp1[4096];
 
 	temp[0] = 0;
-	if ((BITERR_NOOBJ & bitmap)) {
+	if (BITERR_NOOBJ & bitmap) {
 	    sprintf(temp, "%d %s ", AFPERR_NOOBJ, afp_error(htonl(AFPERR_NOOBJ)));
 	}
-	if ((BITERR_NODIR & bitmap)) {
+	if (BITERR_NODIR & bitmap) {
 	    sprintf(temp1, "%d %s ", AFPERR_NODIR, afp_error(htonl(AFPERR_NODIR)));
 		strcat(temp, temp1);
 	}
 
-	if ((BITERR_PARAM & bitmap)) {
+	if (BITERR_PARAM & bitmap) {
 	    sprintf(temp1, "%d %s ", AFPERR_PARAM, afp_error(htonl(AFPERR_PARAM)));
 		strcat(temp, temp1);
 	}
 
-	if ((BITERR_BUSY & bitmap)) {
+	if (BITERR_BUSY & bitmap) {
 	    sprintf(temp1, "%d %s ", AFPERR_BUSY, afp_error(htonl(AFPERR_BUSY)));
 		strcat(temp, temp1);
 	}
-	if ((BITERR_BADTYPE & bitmap)) {
+	if (BITERR_BADTYPE & bitmap) {
 	    sprintf(temp1, "%d %s ", AFPERR_BADTYPE, afp_error(htonl(AFPERR_BADTYPE)));
 		strcat(temp, temp1);
 	}
-	if ((BITERR_NOITEM & bitmap)) {
+	if (BITERR_NOITEM & bitmap) {
 	    sprintf(temp1, "%d %s ", AFPERR_NOITEM, afp_error(htonl(AFPERR_NOITEM)));
 		strcat(temp, temp1);
 	}
-	if ((BITERR_DENYCONF & bitmap)) {
+	if (BITERR_DENYCONF & bitmap) {
 	    sprintf(temp1, "%d %s ", AFPERR_DENYCONF, afp_error(htonl(AFPERR_DENYCONF)));
 		strcat(temp, temp1);
 	}
-	if ((BITERR_NFILE & bitmap)) {
+	if (BITERR_NFILE & bitmap) {
 	    sprintf(temp1, "%d %s ", AFPERR_NFILE, afp_error(htonl(AFPERR_NFILE)));
 		strcat(temp, temp1);
 	}
-	if ((BITERR_ACCESS & bitmap)) {
+	if (BITERR_ACCESS & bitmap) {
 	    sprintf(temp1, "%d %s ", AFPERR_ACCESS, afp_error(htonl(AFPERR_ACCESS)));
 		strcat(temp, temp1);
 	}
-	if ((BITERR_NOID & bitmap)) {
+	if (BITERR_NOID & bitmap) {
 	    sprintf(temp1, "%d %s ", AFPERR_NOID, afp_error(htonl(AFPERR_NOID)));
 		strcat(temp, temp1);
 	}
-	if ((BITERR_BITMAP & bitmap)) {
+	if (BITERR_BITMAP & bitmap) {
 	    sprintf(temp1, "%d %s ", AFPERR_BITMAP, afp_error(htonl(AFPERR_BITMAP)));
 		strcat(temp, temp1);
 	}
-	if ((BITERR_MISC & bitmap)) {
+	if (BITERR_MISC & bitmap) {
 	    sprintf(temp1, "%d %s ", AFPERR_MISC, afp_error(htonl(AFPERR_MISC)));
 		strcat(temp, temp1);
 	}
@@ -811,7 +811,7 @@ void test_skipped(int why)
 		s = "second user";
 		break;
 	case T_PATH:
-		s = "volume path";
+		s = "has to be run on localhost with -c volume path";
 		break;
 	case T_AFP2:
 		s = "AFP 2.x";
@@ -831,11 +831,6 @@ void test_skipped(int why)
 	case T_AFP32:
 		s = "AFP 3.2 or higher";
 		break;
-/*
-	case T_MAC_PATH:
-		s = "Mac OS server or volume path";
-		break;
-*/
 	case T_UNIX_PREV:
 		s ="volume with UNIX privileges";
 		break;
@@ -867,13 +862,13 @@ void test_skipped(int why)
 		s = "volume with ACL support";
 		break;
 	case T_EA:
-		s = "volume with extendend attribute support";
+		s = "volume with filesystem Extended Attributes support";
 		break;
 	case T_ADEA:
-		s = "Netatalk 3+ and volume with 'appledouble = ea'";
+		s = "volume must not use AppleDouble metadata";
 		break;
 	case T_ADV2:
-		s = "volume with 'appledouble = v2'";
+		s = "volume must use AppleDouble metadata";
 		break;
 	case T_NOSYML:
 		s = "volume without option 'follow symlinks'";
@@ -942,7 +937,7 @@ void exit_test(char *name)
 
 	switch (CurTestResult) {
 	case 0:
-		PassCount += 1;
+		PassCount++;
 		if (Color) {
 			s = ANSI_BGREEN "PASSED" ANSI_NORMAL;
 		} else {
@@ -950,7 +945,9 @@ void exit_test(char *name)
 		}
 		break;
 	case 1:
-		FailCount += 1;
+		strlcpy(FailedTests[FailCount], name, 255);
+		FailedTests[FailCount][255] = '\0';
+		FailCount++;
 		if (Color) {
 			s = ANSI_BRED "FAILED" ANSI_NORMAL;
 		} else {
@@ -961,7 +958,9 @@ void exit_test(char *name)
         fflush(stdout);
 		return;
 	case 2:
-		NotTestedCount += 1;
+		strlcpy(NotTestedTests[NotTestedCount], name, 255);
+		NotTestedTests[NotTestedCount][255] = '\0';
+		NotTestedCount++;
 		if (Color) {
 			s = ANSI_BYELLOW "NOT TESTED" ANSI_NORMAL;
 		} else {
@@ -969,7 +968,9 @@ void exit_test(char *name)
 		}
 		break;
 	case 3:
-		SkipCount += 1;
+		strlcpy(SkippedTests[SkipCount], name, 255);
+		SkippedTests[SkipCount][255] = '\0';
+		SkipCount++;
 		s = skipped_msg_buf;
 		break;
 	}
