@@ -44,6 +44,9 @@ int PassCount = 0;
 int FailCount = 0;
 int SkipCount = 0;
 int NotTestedCount = 0;
+char FailedTests[1024][256] = {{0}};
+char NotTestedTests[1024][256] = {{0}};
+char SkippedTests[1024][256] = {{0}};
 
 /* Configure the tests */
 #define DIRNUM 10                                 /* 10^3 nested dirs */
@@ -56,7 +59,7 @@ static uint16_t vol;
 static DSI *dsi;
 static char    *Server = "localhost";
 static int     Proto = 0;
-static int     Port = 548;
+static int     Port = DSI_AFPOVERTCP_PORT;
 static char    *Password = "";
 static int     Iterations = 1;
 static int     Iterations_save;
@@ -153,7 +156,10 @@ static void displayresults(void)
         for (i=0, sum=0; i < Iterations_save; i++)
             sum += (*results)[i][test];
         avg = sum / (Iterations_save - divsub);
-        fprintf(stderr, "%s%6llu ms", resultstrings[test], avg);
+        if (avg < 1) {
+            fprintf(stderr, "\tFATAL ERROR: invalid result\n");
+            exit(1);
+        }
         if ((test == TEST_WRITE100MB) || (test == TEST_READ100MB)) {
             thrput = (rwsize / 1000) / avg;
             fprintf(stderr, " for %lu MB (avg. %llu MB/s)", rwsize / (1024 * 1024), thrput);
@@ -664,6 +670,10 @@ int main(int ac, char **av)
     static char *vers = "AFP3.4";
     static char *uam = "Cleartxt Passwrd";
 
+    if (ac == 1) {
+        usage(av[0]);
+    }
+
     while (( cc = getopt( ac, av, "1234567bGgVvF:f:h:n:p:s:u:w:" )) != EOF ) {
         switch ( cc ) {
         case '3':
@@ -803,7 +813,6 @@ int main(int ac, char **av)
         if ( sock < 0) {
             return 2;
         }
-        dsi->protocol = DSI_TCPIP;
         dsi->socket = sock;
     }
     Conn->afp_version = Version;
