@@ -27,7 +27,6 @@
         test_failed(); \
     }
 
-#define EXPECT_FAIL(a, b) do { int _experr;  _experr = (a); if (htonl(_experr) != (b)) { test_failed(); } } while(0);
 #define FAILEXIT(a, label) if ((a)) { test_failed(); goto label;}
 #define STATIC
 
@@ -86,7 +85,9 @@ extern int not_valid_bitmap(unsigned int ret, unsigned int bitmap, int afpd_erro
 #define T_PATH       2
 #define T_AFP3       3
 #define T_AFP3_CONN2 4
-/* #define T_MAC_PATH   5 */
+#if 0
+#define T_MAC_PATH   5
+#endif
 #define T_UNIX_PREV  6
 #define T_UTF8       7
 #define T_VOL2       8
