@@ -16,6 +16,9 @@ int FailCount = 0;
 int SkipCount = 0;
 int NotTestedCount = 0;
 
+char FailedTests[1024][256] = {{0}};
+char NotTestedTests[1024][256] = {{0}};
+char SkippedTests[1024][256] = {{0}};
 
 #define FN(a) a ## _test
 #define EXT_FN(a) extern void FN(a) (void)
@@ -45,6 +48,7 @@ EXT_FN(FPFlushFork);
 EXT_FN(FPGetACL);
 EXT_FN(FPGetAPPL);
 EXT_FN(FPGetComment);
+EXT_FN(FPGetExtAttr);
 EXT_FN(FPGetFileDirParms);
 EXT_FN(FPGetSessionToken);
 EXT_FN(FPGetSrvrInfo);
@@ -133,6 +137,7 @@ FN_N(FPFlushFork)
 FN_N(FPGetACL)
 FN_N(FPGetAPPL)
 FN_N(FPGetComment)
+FN_N(FPGetExtAttr)
 FN_N(FPGetFileDirParms)
 FN_N(FPGetForkParms)
 FN_N(FPGetIcon)
@@ -305,7 +310,7 @@ char Data[300000] = "";
 char    *Server = "localhost";
 char    *Server2;
 int     Proto = 0;
-int     Port = 548;
+int     Port = DSI_AFPOVERTCP_PORT;
 char    *Password = "";
 char    *Vol = "";
 char    *Vol2 = "";
@@ -327,7 +332,7 @@ void usage( char * av0 )
 {
     fprintf( stdout, "usage:\t%s [-1234567aCiLlmnVvXx] [-h host] [-H host2] [-p port] [-s vol] [-c vol path] [-S vol2] "
 	"[-u user] [-d user2] [-w password] [-F testsuite] [-f test]\n", av0 );
-    fprintf( stdout,"\t-a\tvolume is appledouble = v2 instead of default appledouble = ea\n");
+    fprintf( stdout,"\t-a\tvolume is using AppleDouble metadata and not EA\n");
     fprintf( stdout,"\t-L\tserver without working fcntl locking, skip tests using it\n");
     fprintf( stdout,"\t-m\tserver is a Mac\n");
     fprintf( stdout,"\t-h\tserver host name (default localhost)\n");
@@ -364,6 +369,10 @@ int main( int ac, char **av )
 int cc;
 int ret;
 
+    if (ac == 1) {
+        usage(av[0]);
+    }
+
     while (( cc = getopt( ac, av, "1234567aCiLlmVvXxc:d:f:H:h:p:S:s:u:w:" )) != EOF ) {
         switch ( cc ) {
         case '1':
@@ -505,7 +514,6 @@ int ret;
         if ( sock < 0) {
 	    	return 2;
         }
-     	Dsi->protocol = DSI_TCPIP;
 	    Dsi->socket = sock;
     }
     else {
@@ -543,7 +551,6 @@ int ret;
 	        if ( sock < 0) {
 		    	return 1;
         	}
-	     	Dsi2->protocol = DSI_TCPIP;
 		    Dsi2->socket = sock;
 	    }
     	else {
@@ -576,13 +583,32 @@ int ret;
 		FPLogOut(Conn2);
 	}
 
-    fprintf(stdout,"===================\n");
-    fprintf(stdout,"TEST RESULT SUMMARY\n");
-    fprintf(stdout,"-------------------\n");
+    fprintf(stdout, "=====================\n");
+    fprintf(stdout, " TEST RESULT SUMMARY\n");
+    fprintf(stdout, "---------------------\n");
 	fprintf(stdout, "  Passed:     %d\n", PassCount);
-	fprintf(stdout, "  Failed:     %d\n", FailCount);
 	fprintf(stdout, "  Skipped:    %d\n", SkipCount);
+	fprintf(stdout, "  Failed:     %d\n", FailCount);
 	fprintf(stdout, "  Not tested: %d\n", NotTestedCount);
 
+	if (SkipCount) {
+		fprintf(stdout, "\n  Skipped tests (precondition not met):\n");
+		for (int i = 0; i < SkipCount; i++) {
+			fprintf(stdout, "    %s\n", SkippedTests[i]);
+		}
+	}
+	if (FailCount) {
+		fprintf(stdout, "\n  Failed tests:\n");
+		for (int i = 0; i < FailCount; i++) {
+			fprintf(stdout, "    %s\n", FailedTests[i]);
+		}
+	}
+	if (NotTestedCount) {
+		fprintf(stdout, "\n  Not tested tests (setup step failed):\n");
+		for (int i = 0; i < NotTestedCount; i++) {
+			fprintf(stdout, "    %s\n", NotTestedTests[i]);
+		}
+	}
+
 	return ExitCode;
 }
