@@ -33,7 +33,7 @@ struct timeval Timer_end;
 /* ------------------------------- */
 static char    *Server = "localhost";
 static int     Proto = 0;
-static int     Port = 548;
+static int     Port = DSI_AFPOVERTCP_PORT;
 static char    *Password = "";
 char    *Vol = "";
 char    *Vol2 = "";
@@ -63,6 +63,9 @@ int PassCount = 0;
 int FailCount = 0;
 int SkipCount = 0;
 int NotTestedCount = 0;
+char FailedTests[1024][256] = {{0}};
+char NotTestedTests[1024][256] = {{0}};
+char SkippedTests[1024][256] = {{0}};
 
 struct vfs {
 	unsigned int (*getfiledirparams)(CONN *, uint16_t , int , char *, uint16_t, uint16_t);
@@ -115,22 +118,25 @@ static char *Vol_heap[MAXVOL];
 uint16_t local_openvol(CONN *conn, char *vol)
 {
 uint16_t i;
-struct stat st;
+int fd;
 
 	if (!Quiet) {
 		fprintf(stdout,"---------------------\n");
 		fprintf(stdout,"Open Vol %s \n\n", vol);
 	}
 
-	if (stat(vol, &st)) {
+	fd = open(vol, O_RDONLY | O_DIRECTORY);
+	if (fd < 0) {
 		return 0xffff;
 	}
 
-	for (i= 0; i< MAXVOL; i++) {
+	for (i = 0; i < MAXVOL; i++) {
 		if (Vol_heap[i] == NULL) {
-			if (chdir(vol)) {
+			if (fchdir(fd) < 0) {
+				close(fd);
 				break;
 			}
+			close(fd);
 			Vol_heap[i] = strdup(vol);
 			Dir_heap[i][2] = strdup(vol);
 			return i;
@@ -169,6 +175,7 @@ static int local_chdir(uint16_t vol, int did)
 unsigned int local_createdir(CONN *conn, uint16_t vol, int did , char *name)
 {
 unsigned int i;
+int dirfd;
 
 	if (!Quiet) {
 		fprintf(stdout,"---------------------\n");
@@ -179,14 +186,29 @@ unsigned int i;
 	if (local_chdir(vol, did) < 0) {
 		return 0;
 	}
+
 	for (i= 3; i< MAXDIR; i++) {
 		if (Dir_heap[vol][i] == NULL) {
-			if (mkdir(name, 0777)) {
+			if (mkdir(name, 0777) != 0) {
 				return ntohl(AFPERR_NOOBJ);
 			}
-			if (chdir (name) || NULL ==  getcwd(temp, sizeof(temp))) {
+
+			dirfd = open(name, O_RDONLY | O_DIRECTORY);
+			if (dirfd < 0) {
 				return 0;
 			}
+
+			if (fchdir(dirfd) != 0) {
+				close(dirfd);
+				return 0;
+			}
+
+			if (getcwd(temp, sizeof(temp)) == NULL) {
+				close(dirfd);
+				return 0;
+			}
+
+			close(dirfd);
 			Dir_heap[vol][i] = strdup(temp);
 			return htonl(i);
 		}
@@ -240,7 +262,7 @@ int fd;
 
 	if (!Quiet) {
 		fprintf(stdout,"---------------------\n");
-		fprintf(stdout,"Create File %s Vol %d did : 0x%x <%s>\n\n", (type )?"HARD":"SOFT", vol, ntohl(did), name);
+		fprintf(stdout,"Create File %s Vol %d did : 0x%x <%s>\n\n", type?"HARD":"SOFT", vol, ntohl(did), name);
 	}
 	did = ntohl(did);
 	if (local_chdir(vol, did) < 0) {
@@ -1145,6 +1167,7 @@ void (*fn)(void) = NULL;
 #endif
 
     token = strtok(tp, ",");
+	free(tp);
 
 #ifdef BROKEN_DL
 	fn = test_to_run(token);
@@ -1300,6 +1323,10 @@ int main( int ac, char **av )
 {
 int cc;
 
+    if (ac == 1) {
+        usage(av[0]);
+    }
+
     while (( cc = getopt( ac, av, "1234567aeDiLnVvyc:d:F:f:h:o:p:q:R:r:S:s:u:w:" )) != EOF ) {
         switch ( cc ) {
         case '1':
@@ -1443,7 +1470,6 @@ int cc;
         	if ( sock < 0) {
 	    		return 2;
 	        }
-    	 	Dsi->protocol = DSI_TCPIP;
 	    	Dsi->socket = sock;
 	    }
 
